﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Honeywell.Mobility.DataCollection;

namespace BarcodeReader
{
    public partial class Form1 : Form
    {
        private Honeywell.Mobility.DataCollection.BarcodeReader bcr;

        public Form1()
        {
            InitializeComponent();

            try
            {
                bcr = new Honeywell.Mobility.DataCollection.BarcodeReader();

                //set read event
                bcr.BarcodeRead += new BarcodeReadEventHandler(bcr_BarcodeRead);

                //enable post read
                bcr.PostRead = true;

                //get default symbology settings  
                if (bcr.Symbology.Code39.Enable == CSymbology.CCode39.EEnable.Enable)
                    this.chkCode39.Checked = true;
                else
                    this.chkCode39.Checked = false;

                if (bcr.Symbology.Code128.EnableCode128 == CSymbology.CCode128.EEnableCode128.Enable)
                    this.chkCode128.Checked = true;
                else
                    this.chkCode128.Checked = false;

                if (bcr.Symbology.Interleaved2Of5.Enable == CSymbology.CInterleaved2Of5.EEnable.Enable)
                    this.chkI2Of5.Checked = true;
                else
                    this.chkI2Of5.Checked = false;

                if (bcr.Symbology.Pdf417.EnablePdf417 == CSymbology.CPdf417.EEnablePdf417.Enable)
                    this.chkPDF417.Checked = true;
                else
                    this.chkPDF417.Checked = false;

                this.txtPreamble.Text = bcr.SymbologyOptions.Preamble;
                this.txtPostamble.Text = bcr.SymbologyOptions.Postamble;

            }
            catch (BarcodeReaderException bcrexp)
            {
                MessageBox.Show(bcrexp.Message);
            }
            catch (Exception exp)
            {
                MessageBox.Show(exp.Message);
            }
        }

        void bcr_BarcodeRead(object sender, BarcodeReadEventArgs bre)
        {
            try
            {
                this.listBox1.Items.Add("Barcode: " + bre.StrBarcodeData);
                this.listBox1.Items.Add("symbology: " + bre.SymbologyName);
                this.listBox1.Items.Add(" ");
                this.listBox1.SelectedIndex = this.listBox1.Items.Count - 1;
            }
            catch (BarcodeReaderException bcrexp)
            {
                MessageBox.Show(bcrexp.Message);
            }
        }

        private void btnSet_Click(object sender, EventArgs e)
        {
            try
            {
                //set code39
                if (this.chkCode39.Checked)
                    bcr.Symbology.Code39.Enable = CSymbology.CCode39.EEnable.Enable;
                else
                    bcr.Symbology.Code39.Enable = CSymbology.CCode39.EEnable.Disable;

                //set code128
                if (this.chkCode128.Checked)
                    bcr.Symbology.Code128.EnableCode128 = CSymbology.CCode128.EEnableCode128.Enable;
                else
                    bcr.Symbology.Code128.EnableCode128 = CSymbology.CCode128.EEnableCode128.Disable;

                //set I2Of5
                if (this.chkI2Of5.Checked)
                    bcr.Symbology.Interleaved2Of5.Enable = CSymbology.CInterleaved2Of5.EEnable.Enable;
                else
                    bcr.Symbology.Interleaved2Of5.Enable = CSymbology.CInterleaved2Of5.EEnable.Disable;

                //set PDF417
                if (this.chkPDF417.Checked)
                    bcr.Symbology.Pdf417.EnablePdf417 = CSymbology.CPdf417.EEnablePdf417.Enable;
                else
                    bcr.Symbology.Pdf417.EnablePdf417 = CSymbology.CPdf417.EEnablePdf417.Disable;

                //set preabmel
                bcr.SymbologyOptions.Preamble = this.txtPreamble.Text;

                //set postamble
                bcr.SymbologyOptions.Postamble = this.txtPostamble.Text;

                this.listBox1.Items.Add("Done settings");
                this.listBox1.Items.Add(" ");
                this.listBox1.SelectedIndex = this.listBox1.Items.Count - 1;
            }
            catch (BarcodeReaderException bcrexp)
            {
                MessageBox.Show(bcrexp.Message);
            }
            catch (Exception exp)
            {
                MessageBox.Show(exp.Message);
            }
        }

        private void btnClean_Click(object sender, EventArgs e)
        {
            this.listBox1.Items.Clear();
        }

        private void btnExit_Click(object sender, EventArgs e)
        {
            try
            {
                if (bcr != null)
                {
                    bcr.Dispose();
                    bcr = null;
                }
            }
            catch (BarcodeReaderException bcrexp)
            {
                MessageBox.Show(bcrexp.Message);
            }
            catch (Exception exp)
            {
                MessageBox.Show(exp.Message);
            }

            Application.Exit();
        }      
    }
}
