/*******************************************************************************
 *
 *  FILE NAME:  ADCErrors.h
 *
 *  PURPOSE:    Defines routine error codes returned by Intermec COM interfaces.
 *
 *  COPYRIGHT (c) 2000-2015 HONEYWELL INTERNATIONAL INC., ALL RIGHTS RESERVED
 *
 ******************************************************************************/

#ifndef INCLUDED_ADCERRORS_H
#define INCLUDED_ADCERRORS_H

////////////////////////////////////////////////////////////////
//  ERROR CODES
//

// invalid device type
const HRESULT E_ITCADC_INVALID_DEVICE = 0xC14E0000;

// invalid port ID
const HRESULT E_ITCADC_INVALID_PORT = 0xC1600002;

// invalid attribute ID
const HRESULT E_ITCADC_INVALID_ATTRIBUTE = 0xC1600003;

// The operation timed out without completing
const HRESULT E_ITCADC_OPERATION_TIMED_OUT = 0xC1600004;

// An attempt to set a read-only attribute
const HRESULT E_ITCADC_CANNOT_SET_ATTRIBUTE = 0xC1600005;

// The method returned without data due to cancel-read request
const HRESULT E_ITCADC_READ_CANCELLED = 0xC1040046;

// The requested data was too big for caller's buffer
// (note: size of data was returned)
const HRESULT E_ITCADC_RESPONSE_TOO_BIG = 0xC104001B;

// The device operation could not be completed because the
// interface is not currently attached to a device.
const HRESULT E_ITCADC_NOT_CONNECTED_TO_DEVICE = 0xC1600008;

// The call sequence convention has been violated on the
// interface, for example Initialize() was not called
// before other methods.
const HRESULT E_ITCADC_WRONG_SEQUENCE = 0xC1600009;

// The value cannot be applied
const HRESULT E_ITCADC_INVALID_VALUE = 0xC160000A;

// One of the calling parameters is invalid.
const HRESULT E_ITCADC_INVALID_PARAM = 0xC160000B;


// No more available port to add the device
const HRESULT E_ITCADC_PORT_RESOURCE_NOT_AVAILABLE = 0xC160000C;

// DO NOT USE:  Deprecated symbol. 
const HRESULT E_ITCADC_DEVICE_TIMEOUT = 0xC160000D;

// DO NOT USE:  Deprecated symbol. 
const HRESULT E_ITCADC_SERVER_TIMEOUT = 0xC160000E;

// The operation to enable the port state of an undecoded tethered scanner
// or to change the scanner model to an undecoded tethered scanner could not 
// be completed because the terminal did not detect the presence of the undecoded 
// serial adaptor on the dock connector.
const HRESULT E_ITCADC_NOT_SUPPORT_WITHOUT_UNDECODED_SERIAL_ADAPTER = 0xC160000F;

// The operation to enable the port state of a decoded tethered scanner 
// or to change the scannel model to a decoded tethered scanner could not 
// be completed because the terminal has detected the presence of the undecoded serial adaptor on the dock connector 
// instead of the decoded serial adaptor.
const HRESULT E_ITCADC_DECODED_TETH_INCORRECT_SERIAL_ADAPTER = 0xC1600010;

// The operation to enable the port state of an undecoded tethered scanner 
// or to change the scanner model to an undecoded tethered scanner could not 
// be completed because the terminal has detected the presence of the decoded 
// serial adaptor on the dock connector instead of the undecoded serial adaptor.
const HRESULT E_ITCADC_UNDECODED_TETH_INCORRECT_SERIAL_ADAPTER = 0xC1600011;

// The data collection service has closed. The interface should be released.
const HRESULT E_ITCADC_SERVICE_IS_CLOSED = 0xC1600012;

// The feature has been disabled by Microsoft Device Management (Yona) or
//	other device management systems (Smart Systems).
const HRESULT E_ITCADC_DISABLED_BY_DEVICE_MANAGEMENT = 0xC1600013;

// There is an error when attempt to open the specified resource such as the COMx port.
const HRESULT E_ITCADC_COMMUNICATION_PORT_CANNOT_OPEN = 0xC1600014;

// There is an error when attempt to communicate with the attached device.
const HRESULT E_ITCADC_CANNOT_COMMUNICATE_WITH_DEVICE = 0xC1600015;

// The image capture that was in progress has been aborted
const HRESULT E_ITCADC_IMAGE_CAPTURE_ABORT = 0xC1600016;

// The operation requires a system boot to continue
const HRESULT E_ITCADC_REBOOT_REQUIRED = 0xC1600017;

////////////////////////////////////////////////////////////////
// Legacy
const HRESULT E_ITCADC_INVALID_PORT_E = 0xC1600002;
const HRESULT E_ITCADC_WRONG_SEQUENCE_E = 0xC1600009;
////////////////////////////////////////////////////////////////

#endif
////////////////////////////////////////////////////////////////
// END OF FILE:  ADCErrors.h
//  COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////

