////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  itc50msgsys.h
//
//  Copyright (c) 1998-2015 Honeywell International Inc. All Rights Reserved.
//
////////////////////////////////////////////////////////////////////

#ifndef INCLUDED_ITC50MSGSYS_H
#define INCLUDED_ITC50MSGSYS_H
//
////////////////////////////////////////////////////////////////
//  #DEFINES   
#define ITC_SEVERITY_BITPOS         30          // Starting bit position of
                                                //  the severity field.
#define ITC_FACILITIES_MASK         0x0FFF0000  // Mask identifying the facility.
#define ITC_FACILITY_BITPOS         16          // Starting bit position of the
                                                //  facility field.
#define ITC_MAXFACILITY_VALUE       0x0FFF      // Maximum value for a facility.

#define ITC_SEVERITYVALUE_ERROR      ((DWORD)(ITC_ERROR_SEVERITY << ITC_SEVERITY_BITPOS))
#define ITC_SEVERITYVALUE_WARN       ((DWORD)(ITC_WARNING_SEVERITY << ITC_SEVERITY_BITPOS))
#define ITC_SEVERITYVALUE_INFO       ((DWORD)(ITC_INFORMATIONAL_SEVERITY << ITC_SEVERITY_BITPOS))
#define ITC_SEVERITYVALUE_SUCCESS    ((DWORD)(ITC_SUCCESS_SEVERITY << ITC_SEVERITY_BITPOS))

#define ITC_SEVERITYMASK_SUCCESS    (1 << ITC_SUCCESS_SEVERITY)
#define ITC_SEVERITYMASK_INFO       (1 << ITC_INFORMATIONAL_SEVERITY)
#define ITC_SEVERITYMASK_WARN       (1 << ITC_WARNING_SEVERITY)
#define ITC_SEVERITYMASK_ERROR      (1 << ITC_ERROR_SEVERITY)

#define ITC_SEVERITYMASK_ALL (ITC_SEVERITYMASK_SUCCESS | ITC_SEVERITYMASK_INFO | \
                              ITC_SEVERITYMASK_WARN | ITC_SEVERITYMASK_ERROR)

//
// ISOK
//  Returns nonzero (TRUE) if warn, informational, or success severity.
//  Returns zero (FALSE) otherwise
//
#define ITC_ISOK(dwStatus)      (((DWORD)dwStatus & ITC_SEVERITYVALUE_ERROR) != ITC_SEVERITYVALUE_ERROR)
#define ITC_ISSUCCESS(dwStatus)   (((DWORD)dwStatus >> ITC_SEVERITY_BITPOS ) == ITC_SUCCESS_SEVERITY)
#define ITC_ISINFO(dwStatus)   (((DWORD)dwStatus >> ITC_SEVERITY_BITPOS) == ITC_INFORMATIONAL_SEVERITY)
#define ITC_ISWARNING(dwStatus)   (((DWORD)dwStatus >> ITC_SEVERITY_BITPOS) == ITC_WARNING_SEVERITY)
#define ITC_ISERROR(dwStatus)   (((DWORD)dwStatus & ITC_SEVERITYVALUE_ERROR) == ITC_SEVERITYVALUE_ERROR)
#define ITC_FACILITY(dwStatus)   (((DWORD)dwStatus & ITC_FACILITIES_MASK) >> ITC_FACILITY_BITPOS)

////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Informational
//Facility=<facility name>
//SymbolicName=<facility acronym>_<msg name>_I 
//Language=English
//<message string>
//.
//
//  Values are 32 bit values layed out as follows:
//
//   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
//   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
//  +---+-+-+-----------------------+-------------------------------+
//  |Sev|C|R|     Facility          |               Code            |
//  +---+-+-+-----------------------+-------------------------------+
//
//  where
//
//      Sev - is the severity code
//
//          00 - Success
//          01 - Informational
//          10 - Warning
//          11 - Error
//
//      C - is the Customer code flag
//
//      R - is a reserved bit
//
//      Facility - is the facility code
//
//      Code - is the facility's status code
//
//
// Define the facility codes
//
#define ITC_SDKMSGSYS_FACILITY           0x191
#define ITC_MSGRESOURCE_FACILITY         0x12C


//
// Define the severity codes
//
#define ITC_WARNING_SEVERITY             0x2
#define ITC_SUCCESS_SEVERITY             0x0
#define ITC_INFORMATIONAL_SEVERITY       0x1
#define ITC_ERROR_SEVERITY               0x3


//
// MessageId: ITC_TFTP_IN_PROGRESS
//
// MessageText:
//
//  TFTP file transfer is in progress.
//
#define ITC_TFTP_IN_PROGRESS             0x41910000L

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Success
//Facility=<facility name>
//SymbolicName=<facility acronym>_<msg name>_S
//Language=English
//<message string>
//.
//
// MessageId: ITC_SUCCESS
//
// MessageText:
//
//  SDK function successful.
//
#define ITC_SUCCESS                      0x01910000L

//
// MessageId: ITC_OK
//
// MessageText:
//
//  SDK function successful.
//
#define ITC_OK                           0x01910001L

//
// MessageId: ITC_TFTP_DONE_OK
//
// MessageText:
//
//  Tftp file transfer successful.
//
#define ITC_TFTP_DONE_OK                 0x01910002L

//
// MessageId: ITC_SUCCESS_TIMEOUT
//
// MessageText:
//
//  timeout occured
//
#define ITC_SUCCESS_TIMEOUT              0x01910003L

//
// MessageId: ITC_INPUT_FULL
//
// MessageText:
//
//  Maximum number of characters was received and the input was stopped. All characters entered are returned
//
#define ITC_INPUT_FULL                   0x01910004L

//
// MessageId: ITC_RETURN_F1
//
// MessageText:
//
//  F1 key was received.
//
#define ITC_RETURN_F1                    0x01910005L

//
// MessageId: ITC_RETURN_F2
//
// MessageText:
//
//  F2 key was received.
//
#define ITC_RETURN_F2                    0x01910006L

//
// MessageId: ITC_RETURN_F3
//
// MessageText:
//
//  F3 key was received.
//
#define ITC_RETURN_F3                    0x01910007L

//
// MessageId: ITC_RETURN_F4
//
// MessageText:
//
//  F4 key was received.
//
#define ITC_RETURN_F4                    0x01910008L

//
// MessageId: ITC_RETURN_F5
//
// MessageText:
//
//  F5 key was received.
//
#define ITC_RETURN_F5                    0x01910009L

//
// MessageId: ITC_RETURN_F6
//
// MessageText:
//
//  F6 key was received.
//
#define ITC_RETURN_F6                    0x0191000AL

//
// MessageId: ITC_RETURN_F7
//
// MessageText:
//
//  F7 key was received.
//
#define ITC_RETURN_F7                    0x0191000BL

//
// MessageId: ITC_RETURN_F8
//
// MessageText:
//
//  F8 key was received.
//
#define ITC_RETURN_F8                    0x0191000CL

//
// MessageId: ITC_RETURN_F9
//
// MessageText:
//
//  F9 key was received.
//
#define ITC_RETURN_F9                    0x0191000DL

//
// MessageId: ITC_RETURN_F10
//
// MessageText:
//
//  F10 key was received.
//
#define ITC_RETURN_F10                   0x0191000EL

//
// MessageId: ITC_RETURN_TAB
//
// MessageText:
//
//  TAB key was received.
//
#define ITC_RETURN_TAB                   0x0191000FL

//
// MessageId: ITC_RETURN_BACK_TAB
//
// MessageText:
//
//  Back tab (shift tab) key was received.
//
#define ITC_RETURN_BACK_TAB              0x01910010L

//
// MessageId: ITC_RETURN_ESC
//
// MessageText:
//
//  ESC key was received.
//
#define ITC_RETURN_ESC                   0x01910011L

//
// MessageId: ITC_RETURN_UP_ARROW
//
// MessageText:
//
//  Up arrow key was received.
//
#define ITC_RETURN_UP_ARROW              0x01910012L

//
// MessageId: ITC_RETURN_DN_ARROW
//
// MessageText:
//
//  Down arrow key was received.
//
#define ITC_RETURN_DN_ARROW              0x01910013L

//
// MessageId: ITC_RETURN_COM_SOURCE
//
// MessageText:
//
//  Comport input was received.
//
#define ITC_RETURN_COM_SOURCE            0x01910014L

//
// MessageId: ITC_RETURN_BUTTON_PUSHED
//
// MessageText:
//
//  A button-push was received.
//
#define ITC_RETURN_BUTTON_PUSHED         0x01910015L

//
// MessageId: ITC_RETURN_ENTER
//
// MessageText:
//
//  Enter key was received.
//
#define ITC_RETURN_ENTER                 0x01910016L

//
// MessageId: ITC_RETURN_TRIGGER
//
// MessageText:
//
//  Trigger key was received.
//
#define ITC_RETURN_TRIGGER               0x01910017L

//
// MessageId: ITC_ACLINE_NOT_CONNECTED
//
// MessageText:
//
//  AC line not connected.
//
#define ITC_ACLINE_NOT_CONNECTED         0x01910018L

//
// MessageId: ITC_ACLINE_CONNECTED
//
// MessageText:
//
//  AC line connected.
//
#define ITC_ACLINE_CONNECTED             0x01910019L

//
// MessageId: ITC_UNKNOWN_ACLINE
//
// MessageText:
//
//  AC line status unknown.
//
#define ITC_UNKNOWN_ACLINE               0x0191001AL

//
// MessageId: ITC_HIGH_BAT
//
// MessageText:
//
//  Battery charge high.
//
#define ITC_HIGH_BAT                     0x0191001BL

//
// MessageId: ITC_LOW_BAT
//
// MessageText:
//
//  Battery charge low.
//
#define ITC_LOW_BAT                      0x0191001CL

//
// MessageId: ITC_CRITICAL_BAT
//
// MessageText:
//
//  Battery charge critical.
//
#define ITC_CRITICAL_BAT                 0x0191001DL

//
// MessageId: ITC_CHARGING_BAT
//
// MessageText:
//
//  Battery is charing now.
//
#define ITC_CHARGING_BAT                 0x0191001EL

//
// MessageId: ITC_NO_SYSTEM_BAT
//
// MessageText:
//
//  No system battery.
//
#define ITC_NO_SYSTEM_BAT                0x0191001FL

//
// MessageId: ITC_UNKNOWN_BAT
//
// MessageText:
//
//  Battery condition unknown.
//
#define ITC_UNKNOWN_BAT                  0x01910020L

//
// MessageId: ITC_HIGH_BACKUP
//
// MessageText:
//
//  Backup battery charge high.
//
#define ITC_HIGH_BACKUP                  0x01910021L

//
// MessageId: ITC_LOW_BACKUP
//
// MessageText:
//
//  Backup battery charge low.
//
#define ITC_LOW_BACKUP                   0x01910022L

//
// MessageId: ITC_CRITICAL_BACKUP
//
// MessageText:
//
//  Battery charge critical.
//
#define ITC_CRITICAL_BACKUP              0x01910023L

//
// MessageId: ITC_CHARGING_BACKUP
//
// MessageText:
//
//  Backup battery is charing now.
//
#define ITC_CHARGING_BACKUP              0x01910024L

//
// MessageId: ITC_NO_SYSTEM_BACKUP
//
// MessageText:
//
//  No system backup battery.
//
#define ITC_NO_SYSTEM_BACKUP             0x01910025L

//
// MessageId: ITC_UNKNOWN_BACKUP
//
// MessageText:
//
//  Backup battery condition unknown.
//
#define ITC_UNKNOWN_BACKUP               0x01910026L

//
// MessageId: ITC_PROCESS_SPAWN
//
// MessageText:
//
//  Process was spawned.
//
#define ITC_PROCESS_SPAWN                0x01910027L

////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Warning
//Facility=<facility name>
//SymbolicName=<facility acronym>_<msg name>_W
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Error
//Facility=<facility name>
//SymbolicName=<facility acronym>_<msg name>_W
//Language=English
//<message string>
//.
//
// MessageId: ITC_ERROR
//
// MessageText:
//
//  SDK function failed!
//
#define ITC_ERROR                        0xC1910000L

//
// MessageId: ITC_FAIL
//
// MessageText:
//
//  SDK function failed!
//
#define ITC_FAIL                         0xC1910001L

//
// MessageId: ITC_NOT_ENOUGH_MEMORY
//
// MessageText:
//
//  Not enough memory!  Please free up some memory!
//
#define ITC_NOT_ENOUGH_MEMORY            0xC1910002L

//
// MessageId: ITC_TIMEOUT
//
// MessageText:
//
//  SDK function timeout!
//
#define ITC_TIMEOUT                      0xC1910003L

//
// MessageId: ITC_INCOMPLETE_MSG
//
// MessageText:
//
//  Received data was incomplete!
//
#define ITC_INCOMPLETE_MSG               0xC1910004L

//
// MessageId: ITC_INVALID_PARAM_1
//
// MessageText:
//
//  Parameter 1 of function call is invalid!
//
#define ITC_INVALID_PARAM_1              0xC1910005L

//
// MessageId: ITC_INVALID_PARAM_2
//
// MessageText:
//
//  Parameter 2 of function call is invalid!
//
#define ITC_INVALID_PARAM_2              0xC1910006L

//
// MessageId: ITC_INVALID_PARAM_3
//
// MessageText:
//
//  Parameter 3 of function call is invalid!
//
#define ITC_INVALID_PARAM_3              0xC1910007L

//
// MessageId: ITC_INVALID_PARAM_4
//
// MessageText:
//
//  Parameter 4 of function call is invalid!
//
#define ITC_INVALID_PARAM_4              0xC1910008L

//
// MessageId: ITC_INVALID_PARAM_5
//
// MessageText:
//
//  Parameter 5 of function call is invalid!
//
#define ITC_INVALID_PARAM_5              0xC1910009L

//
// MessageId: ITC_TFTP_NOT_BEGIN
//
// MessageText:
//
//  TFTP file transfer not begun!
//
#define ITC_TFTP_NOT_BEGIN               0xC191000AL

//
// MessageId: ITC_TFTP_SERVER_ERROR
//
// MessageText:
//
//  TFTP file transfer server error!
//
#define ITC_TFTP_SERVER_ERROR            0xC191000BL

//
// MessageId: ITC_TFTP_CLIENT_ERROR
//
// MessageText:
//
//  TFTP file transfer client error!
//
#define ITC_TFTP_CLIENT_ERROR            0xC191000CL

//
// MessageId: ITC_TFTP_CANCEL
//
// MessageText:
//
//  TFTP file transfer cancelled by TFTP client owner!
//
#define ITC_TFTP_CANCEL                  0xC191000DL

//
// MessageId: ITC_TFTP_INVALIDARG
//
// MessageText:
//
//  Invalid input argument in calling TFTP file transfer function!
//
#define ITC_TFTP_INVALIDARG              0xC191000EL

//
// MessageId: ITC_TFTP_ACCESSDENIED
//
// MessageText:
//
//  Access Denied!  Another TFTP file transfer thread is running!
//
#define ITC_TFTP_ACCESSDENIED            0xC191000FL

//
// MessageId: ITC_UNABLE_TO_RETRIEVE_MESSAGE_STRING
//
// MessageText:
//
//  Unable to get message string for: %1!08X
//
#define ITC_UNABLE_TO_RETRIEVE_MESSAGE_STRING 0xC1910010L

//
// MessageId: ITC_VW_UNABLE_TO_CREATE_SNMP_TARGET
//
// MessageText:
//
//  Unable to create SNMP target for calling virtual wedge functions!
//
#define ITC_VW_UNABLE_TO_CREATE_SNMP_TARGET 0xC1910011L

//
// MessageId: ITC_VW_UNABLE_TO_FIND_ADC_DEVICE
//
// MessageText:
//
//  Unable to find the ADC device!
//
#define ITC_VW_UNABLE_TO_FIND_ADC_DEVICE 0xC1910012L

//
// MessageId: ITC_UNABLE_TO_LOAD_MESSAGERESOURCEDLL
//
// MessageText:
//
//  Unable to load MessageResource.DLL!
//
#define ITC_UNABLE_TO_LOAD_MESSAGERESOURCEDLL 0xC1910013L

//
// MessageId: ITC_BUFFER_OVERWRITTEN
//
// MessageText:
//
//  Input buffer was overwritten!
//
#define ITC_BUFFER_OVERWRITTEN           0xC1910014L

//
// MessageId: ITC_INSUFFICIENT_BUFFER
//
// MessageText:
//
//  Insufficient buffer size.
//
#define ITC_INSUFFICIENT_BUFFER          0xC1910015L

//
// MessageId: ITC_TO_MANY_DEVICES
//
// MessageText:
//
//  No device handles left.
//
#define ITC_TO_MANY_DEVICES              0xC1910016L

//
// MessageId: ITC_UNKNOWN_DEVICE_TYPE
//
// MessageText:
//
//  Unknown device type.
//
#define ITC_UNKNOWN_DEVICE_TYPE          0xC1910017L

//
// MessageId: ITC_INVALID_SOCKET
//
// MessageText:
//
//  A function returned INVALID_SOCKET.
//
#define ITC_INVALID_SOCKET               0xC1910018L

//
// MessageId: ITC_SOCKET_ERROR
//
// MessageText:
//
//  A function returned SOCKET_ERROR.
//
#define ITC_SOCKET_ERROR                 0xC1910019L

//
// MessageId: ITC_OBJ_INIT_ERROR
//
// MessageText:
//
//  An object failed to initialize.
//
#define ITC_OBJ_INIT_ERROR               0xC191001AL

//
// MessageId: ITC_CREATE_INST_ERROR
//
// MessageText:
//
//  A call to CoCreateInstance failed.
//
#define ITC_CREATE_INST_ERROR            0xC191001BL

//
// MessageId: ITC_STARTUP_ERROR
//
// MessageText:
//
//  startup failed to initialize winsock.dll.
//
#define ITC_STARTUP_ERROR                0xC191001CL

//
// MessageId: ITC_COM_ERROR
//
// MessageText:
//
//  A call to GetCommState failed.
//
#define ITC_COM_ERROR                    0xC191001DL

//
// MessageId: ITC_CONNRESET
//
// MessageText:
//
//  A suspend/resume has reset all socket connections.
//
#define ITC_CONNRESET                    0xC191001EL

//
// MessageId: ITC_ERROR_SYNC_RESOURCES
//
// MessageText:
//
//  Unable to acquire thread-sync resources such as events and mutexes.
//
#define ITC_ERROR_SYNC_RESOURCES         0xC191001FL

//
// MessageId: ITC_ERROR_REGISTRY_FAULT
//
// MessageText:
//
//  Attempts to read or update a registry key or value have failed.
//
#define ITC_ERROR_REGISTRY_FAULT         0xC1910020L

//
// MessageId: ITC_ERROR_EXCEPTION
//
// MessageText:
//
//  An exception has occurred.
//
#define ITC_ERROR_EXCEPTION              0xC1910021L

//
// MessageId: ITC_ERROR_EVENT_STATE_FAILED
//
// MessageText:
//
//  Attempts to signal or clear an event have failed.
//
#define ITC_ERROR_EVENT_STATE_FAILED     0xC1910022L

//
// MessageId: ITC_ERROR_SCRNLGHT_KEYDOWN
//
// MessageText:
//
//  A conflict exists because the user is pressing the backlight key.
//
#define ITC_ERROR_SCRNLGHT_KEYDOWN       0xC1910023L

//
// MessageId: ITC_ERROR_FUNCTION_NOT_SUPPORTED
//
// MessageText:
//
//  The function called is not supported in the target platform.
//
#define ITC_ERROR_FUNCTION_NOT_SUPPORTED 0xC1910024L

//
// MessageId: ITC_COM_OPEN_ERROR
//
// MessageText:
//
//  Unable to open the requested serial port
//
#define ITC_COM_OPEN_ERROR               0xC1910025L

//
// MessageId: ITC_COM_READ_BAUD_RATE
//
// MessageText:
//
//  Unable to read the baud rate registry setting
//
#define ITC_COM_READ_BAUD_RATE           0xC1910026L

//
// MessageId: ITC_COM_XFER_RETRY
//
// MessageText:
//
//  Serial file transfer exceeds maximum retry limit
//
#define ITC_COM_XFER_RETRY               0xC1910027L

//
// MessageId: ITC_COM_XFER_CANCEL
//
// MessageText:
//
//  Serial file transfer aborted by the device at the other end
//
#define ITC_COM_XFER_CANCEL              0xC1910028L

//
// MessageId: ITC_COM_XFER_WRITE_FAILED
//
// MessageText:
//
//  Serial file transfer failed in writing to the destination file
//
#define ITC_COM_XFER_WRITE_FAILED        0xC1910029L

//
// MessageId: ITC_COM_XFER_READ_FAILED
//
// MessageText:
//
//  Serial file transfer failed in reading the source file
//
#define ITC_COM_XFER_READ_FAILED         0xC191002AL

//
// MessageId: ITC_COM_USER_ABORT
//
// MessageText:
//
//  Serial file transfer aborted by the user
//
#define ITC_COM_USER_ABORT               0xC191002BL

//
// MessageId: ITC_COM_XFER_PROTOCOL
//
// MessageText:
//
//  Serial file transfer encountered protocol errors
//
#define ITC_COM_XFER_PROTOCOL            0xC191002CL

//
// MessageId: ITC_USB_READ_ERROR
//
// MessageText:
//
//  Failure to read data from USB device
//
#define ITC_USB_READ_ERROR               0xC191002DL

//
// MessageId: ITC_USB_ATTACH_ERROR
//
// MessageText:
//
//  Failure to attach USB device
//
#define ITC_USB_ATTACH_ERROR             0xC191002EL

//
// MessageId: ITC_ERROR_DEVICE_NOT_CONNECTED
//
// MessageText:
//
//  The I/O device configuration file is not available on the mobile computer to be downloaded
//
#define ITC_ERROR_DEVICE_NOT_CONNECTED   0xC191002FL

//
// MessageId: ITC_ERROR_MISSING_FILE
//
// MessageText:
//
//  Device has not been physically attached to the USB interface
//
#define ITC_ERROR_MISSING_FILE           0xC1910030L

//
// MessageId: ITC_ERROR_FILE_DOWNLOAD_FAIL
//
// MessageText:
//
//  Failed to download personality file to attached device
//
#define ITC_ERROR_FILE_DOWNLOAD_FAIL     0xC1910031L

#endif  // !defined(INCLUDED_ITC50MSGSYS_H)

