/*******************************************************************************
*
*  FILE NAME:  Itcscan2.h
*
*  PURPOSE:	   Functions that support barcode scanning and symbology settings.      
*
*  Copyright  2000-2015 Honeywell International Inc. All Rights Reserved.
*
******************************************************************************/


#ifndef INCLUDED_ITCSCAN2_H                /* Has this file been included before?  */
#define INCLUDED_ITCSCAN2_H                /* No, remember it has been now         */

#ifdef __cplusplus
extern "C"{
#endif 

#include "IADCConnection.h"
#include "IADCConnection2.h"
#include "IADC.h"
#include "IBarCodeReader.h"
#include "IS9CConfig.h"

#define ITCSCAN_MAX_GRID_FILTER_LENGTH 240

#define ITCSCAN_SUCCESS							0x00000000L
#define ITCSCAN_ERROR							-0x00000001L
#define ITCSCAN_VALUE_NOT_FOUND					-0x00000003L
#define ITCSCAN_CANCEL_VALUE					-0x00000004L
#define ITCSCAN_BUFFER_OVERRUN_ERROR			-0x00000006L
#define ITCSCAN_NO_SCANNER_ERROR				-0x00000008L

#define DCE_ISCP_SETCONFIG_RETURNED_BYTES		-0x0000000AL
#define DCE_NO_SUCCESS_ISCP_GETCONFIG_RETURNED	-0x0000000BL
#define DCE_ISCP_COMMANDCONFIG_RETURNED_BYTES	-0x0000000CL
#define DCE_NO_SUCCESS_ISCP_STATUSREAD_RETURNED -0x0000000DL
#define DCE_NOT_SUPPORT							-0x0000000EL

typedef
enum ItcscanMessageType
{
	MSG_BARCODEDATA_READ = 1,
	MSG_BARCODEDATA_ERROR = 2,
	MSG_SCANNER_NOTIFY = 3
} ITCSCAN_MESSAGE_TYPE;


//struct for port state information
typedef struct
{
	DWORD PortID;
	TCHAR szDeviceType[ITC_DEVICE_TYPE_MAXLEN];
	TCHAR szPortName[ITC_DEVICE_TYPE_MAXLEN];
	DWORD StateID;
	TCHAR szPortState[ITC_DEVICE_TYPE_MAXLEN];
}PORTDATA;


HRESULT ITCSCAN_Open(INT32 *pHandle, LPCTSTR pszDeviceName, DWORD dwDataBufferSize);
HRESULT ITCSCAN_Close(INT32 iHandle);
void ITCSCAN_SetPostRead(INT32 iHandle, BOOL fPostRead);
HRESULT ITCSCAN_GetBarcodeMessage (INT32 iHandle, ITCSCAN_MESSAGE_TYPE *peMsgType, INT32 *piMsgData);

void ITCSCAN_GetScannedDataValues(	INT32 iObjBarCode,			
									 BYTE abDataBuffer [],		
									 DWORD *pdwBytesReturned,	
									 DWORD *pdwDataType,													
									 DWORD *pdwSymbologyID,		
									 LPTSTR pszSymbology,		
									 DWORD *pdwPortID,			
									 LPTSTR pszPortName,		
									 LPTSTR pszDeviceType);		

void ITCSCAN_GetNotificationValues(INT32 iNotify, 
								   DWORD *pdwPortID, 
								   LPTSTR pszPortName, 
								   LPTSTR pszDeviceType, 
								   DWORD *pdwPortStateID, 
								   LPTSTR pszPortState);

//get and set ports data
HRESULT ITCSCAN_GetNumPorts(INT32 iHandle, DWORD *pdwNumPorts);
HRESULT ITCSCAN_GetFirstPortID(INT32 iHandle, DWORD *pdwFirstPortId);
HRESULT ITCSCAN_GetNextPortID(INT32 iHandle, DWORD *pdwNextPortId);

HRESULT ITCSCAN_GetPortDeviceType(INT32 iHandle, DWORD dwPortID, LPTSTR szDeviceType);
HRESULT ITCSCAN_GetPortName(INT32 iHandle, DWORD dwPortId, LPTSTR szPortName);
HRESULT ITCSCAN_GetPortState(INT32 iHandle, DWORD dwPortId, ITC_ADCPORT_STATE* pePortState);

HRESULT ITCSCAN_SetPortDeviceType(INT32 iHandle, DWORD dwPortId, LPCTSTR pszDeviceType);
HRESULT ITCSCAN_SetPortState(INT32 iHandle, DWORD dwPortId, ITC_ADCPORT_STATE ePortState);

HRESULT ITCSCAN_GetAllPortInfo(INT32 iHandle, PORTDATA portData[]);

//used by the symbology settings
HRESULT ITCSCAN_SetConfigInfo(INT32 iHandle, BYTE rgbCommandBuff[], DWORD dwCommandBuffSize);
HRESULT ITCSCAN_GetConfigInfo(INT32 iHandle, 
							  BYTE rgbCommandBuff[],
							  DWORD dwCommandBuffSize, 
							  BYTE rgbReplyBuff[], 
							  DWORD *pdwReplyBuffSize);


HRESULT ITCSCAN_CancelReadRequest(INT32 pHandle, BOOL FlushBufferedData);

HRESULT ITCSCAN_ControlCommandSettings(INT32 iHandle, BYTE rgbCommandBuff[], DWORD dwCommandSize);
HRESULT ITCSCAN_StatusReadCommand(INT32 iHandle, BYTE rgbCommandBuff[], DWORD dwCommandSize, BYTE rgbReplyBuff[], DWORD *pdwReplyBuffSize);

HRESULT ITCSCAN_SetAttribute(INT32 iHandle, INT32 eAttr, BYTE rgbAttrBuffer[], DWORD dwAttrBufferSize);
HRESULT ITCSCAN_QueryAttribute(INT32 iHandle, INT32 eAttr, BYTE rgbAttrBuffer[], DWORD dwAttrBufferSize);

#ifdef __cplusplus
}
#endif

#endif