/*******************************************************************************
 *
 *  FILE NAME:  SmartSysErrors.h
 *
 *  PURPOSE:    Defines routine error codes returned by Smart System components.
 *
 *
 *  COPYRIGHT (c) 2004 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
 *
 ******************************************************************************/

#ifndef INCLUDED_SMARTSYSERRORS_H
#define INCLUDED_SMARTSYSERRORS_H

//  Smart system errors are 4 byte long.  On windows platform they can be mapped to
//  an HRESULT whose values are layed out as follows:
//
//   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
//   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
//  +---+-+-+-----------------------+-------------------------------+
//  |Sev|C|R|     Facility          |               Code            |
//  +---+-+-+-----------------------+-------------------------------+
//
//  where
//
//      Sev (2 bits) - is the severity code.
//
//          00 - Success
//          01 - Informational
//          10 - Warning
//          11 - Error
//
//      C - is the Customer code flag 
//
//      R - is a reserved bit
//
//      Facility (12 bits) - is the facility code.  Reserved codes are stored in 
//			\IVA\Documentation\IVA Notes\Table Of Facility Numbers.htm. 	
//
//      Code (16 bits) - is the facility's status code

const long E_SS_SUCCESS	= 0x00000000;

//   SSClient Errors (C16B0000-C16BFFFF)

const long E_SSClient_OPEN_INPUT_FAILED = 0xC16B0001;
const long E_SSClient_READ_INPUT_FAILED = 0xC16B0002;
const long E_SSClient_PARSE_INPUT_FAILED = 0xC16B0003;
const long E_SSClient_OPEN_OUTPUT_FAILED = 0xC16B0004;
const long E_SSClient_WRITE_OUTPUT_FAILED = 0xC16B0005;
const long E_SSClient_UNRECOGNIZED_XML_TAG = 0xC16B0006;
const long E_SSClient_MISSING_ATTRIBUTE = 0xC16B0007;
const long E_SSClient_TAG_OUT_OF_CONTEXT = 0xC16B0008;
const long E_SSClient_BAD_NAME = 0xC16B0009;
const long E_SSClient_BAD_VALUE = 0xC16B000A;
const long E_SSClient_BAD_INSTANCE = 0xC16B000B;
const long E_SSClient_VERSION_MISMATCH = 0xC16B000C;
const long E_SSClient_SERVICE_IS_UNAVAILABLE = 0xC16B000D;
const long E_SSClient_ERROR_IN_SUBELEMENT = 0xC16B000E;

//   Legacy ICCE Errors (C16B0000-C16BFFFF). Replaced by SSClient Errors.

const long E_ICCE_OPEN_INPUT_FAILED = 0xC16B0001;
const long E_ICCE_READ_INPUT_FAILED = 0xC16B0002;
const long E_ICCE_PARSE_INPUT_FAILED = 0xC16B0003;
const long E_ICCE_OPEN_OUTPUT_FAILED = 0xC16B0004;
const long E_ICCE_WRITE_OUTPUT_FAILED = 0xC16B0005;
const long E_ICCE_UNRECOGNIZED_XML_TAG = 0xC16B0006;
const long E_ICCE_MISSING_ATTRIBUTE = 0xC16B0007;
const long E_ICCE_TAG_OUT_OF_CONTEXT = 0xC16B0008;
const long E_ICCE_BAD_NAME = 0xC16B0009;
const long E_ICCE_BAD_VALUE = 0xC16B000A;
const long E_ICCE_BAD_INSTANCE = 0xC16B000B;
const long E_ICCE_VERSION_MISMATCH = 0xC16B000C;
const long E_ICCE_SERVICE_IS_UNAVAILABLE = 0xC16B000D;
const long E_ICCE_ERROR_IN_SUBELEMENT = 0xC16B000E;



//   ITCConfig/SS_API Errors (C16E0000-C16EFFFF)

const long E_ITCCONFIG_OPERATION_FAILED		= 0xC16E0001;
const long E_ITCCONFIG_OPEN_CONN_FAILED		= 0xC16E0002;
const long E_ITCCONFIG_SEND_REQ_FAILED		= 0xC16E0003;
const long E_ITCCONFIG_RCV_RESP_FAILED		= 0xC16E0004;
const long E_ITCCONFIG_RCV_TIMEOUT		= 0xC16E0005;
const long E_ITCCONFIG_RCV_BUFFER_TOO_SMALL 	= 0xC16E0006;
const long E_ITCCONFIG_CONN_NOT_OPENED		= 0xC16E0007;
const long E_ITCCONFIG_READ_FILE_FAILED		= 0xC16E0008;
const long E_ITCCONFIG_CREATE_DOM_FAILED	= 0xC16E0009;
const long E_ITCCONFIG_OPEN_FILE_FAILED		= 0xC16E000A;

const long E_SSAPI_OPERATION_FAILED					= 0xC16E0021;
const long E_SSAPI_OPEN_CONN_FAILED					= 0xC16E0022;
const long E_SSAPI_SEND_REQ_FAILED					= 0xC16E0023;
const long E_SSAPI_RCV_RESP_FAILED					= 0xC16E0024;
const long E_SSAPI_RCV_TIMEOUT						= 0xC16E0025;
const long E_SSAPI_RCV_BUFFER_TOO_SMALL 			= 0xC16E0026;
const long E_SSAPI_CONN_NOT_OPENED					= 0xC16E0027;
const long E_SSAPI_READ_FILE_FAILED					= 0xC16E0028;
const long E_SSAPI_CREATE_DOM_FAILED				= 0xC16E0029;
const long E_SSAPI_OPEN_FILE_FAILED					= 0xC16E002A;
const long E_SSAPI_XML_MATCH_NOT_FOUND				= 0xC16E002B;
const long E_SSAPI_NO_MORE_CONNECTION_ALLOWED 	= 0xC16E002C;
const long E_SSAPI_SYS_RSC_ALLOC_FAILED 			= 0xC16E002D;
const long E_SSAPI_MISSING_REQUIRED_PARM			= 0xC16E002E;
const long E_SSAPI_INVALID_EVENT						= 0xC16E002F;
const long E_SSAPI_TIMEOUT								= 0xC16E0030;
const long E_SSAPI_MALFORMED_XML						= 0xC16E0031;
const long E_SSAPI_INVALID_PARM						= 0xC16E0032;
const long E_SSAPI_FUNCTION_UNAVAILABLE			= 0xC16E0033;
const long E_SSAPI_MSG_ID_IN_USE                = 0xC16E0034;
const long E_SSAPI_NOT_GROUP_MEMBER             = 0xC16E0035;


//   SSConfiglet/FileXferConfiglet Errors (C4110000-C411FFFF)
const long E_SSCONFIGLET_RULE_EXISTS		= 0xC4110001;
const long E_SSCONFIGLET_UNSUPP_RULE_TYPE		= 0xC4110002;
const long E_SSCONFIGLET_RULE_NOT_FOUND		= 0xC4110003;
const long E_SSCONFIGLET_EMPTY_LIST			= 0xC4110004;
const long E_SSCONFIGLET_NO_STATE			= 0xC4110005;

const long E_FILEXFERCONFIGLET_UPGRADE_IN_PROGRESS	= 0xC4111001;
const long E_FILEXFERCONFIGLET_NOT_ENOUGH_SPACE		= 0xC4111002;
const long E_FILEXFERCONFIGLET_NO_POWER				= 0xC4111003;
const long E_FILEXFERCONFIGLET_NO_MCCLIENT_VERSION	= 0xC4111004;
const long E_FILEXFERCONFIGLET_TEST_FAILED			= 0xC4111005;



#endif // INCLUDED_SMARTSYSERRORS_H

//
//  END OF FILE:  SmartSystemErrors.h
//  COPYRIGHT (c) 2004 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//    
