////////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  MasterMsgSys.mch
//
//  AUTHOR:     J. Hunt
//
//New Archive from Reference Directory
// COPYRIGHT (c) 1998-2015 HONEYWELL INTERNATIONAL INC., ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_MASTERMSGSYS_H
#define INCLUDED_MASTERMSGSYS_H
//
////////////////////////////////////////////////////////////////
//  #DEFINES
#define ITC_SEVERITY_BITPOS         30          // Starting bit position of
                                                //  the severity field.
#define ITC_FACILITIES_MASK         0x0FFF0000  // Mask identifying the facility.
#define ITC_FACILITY_BITPOS         16          // Starting bit position of the
                                                //  facility field.
#define ITC_MAXFACILITY_VALUE       0x0FFF      // Maximum value for a facility.

#define ITC_SEVERITYVALUE_ERROR      ((DWORD)(ITC_ERROR_SEVERITY << ITC_SEVERITY_BITPOS))
#define ITC_SEVERITYVALUE_WARN       ((DWORD)(ITC_WARNING_SEVERITY << ITC_SEVERITY_BITPOS))
#define ITC_SEVERITYVALUE_INFO       ((DWORD)(ITC_INFORMATIONAL_SEVERITY << ITC_SEVERITY_BITPOS))
#define ITC_SEVERITYVALUE_SUCCESS    ((DWORD)(ITC_SUCCESS_SEVERITY << ITC_SEVERITY_BITPOS))

#define ITC_SEVERITYMASK_SUCCESS    (1 << ITC_SUCCESS_SEVERITY)
#define ITC_SEVERITYMASK_INFO       (1 << ITC_INFORMATIONAL_SEVERITY)
#define ITC_SEVERITYMASK_WARN       (1 << ITC_WARNING_SEVERITY)
#define ITC_SEVERITYMASK_ERROR      (1 << ITC_ERROR_SEVERITY)

#define ITC_SEVERITYMASK_ALL (ITC_SEVERITYMASK_SUCCESS | ITC_SEVERITYMASK_INFO | \
                              ITC_SEVERITYMASK_WARN | ITC_SEVERITYMASK_ERROR)

//
// ISOK
//  Returns nonzero (TRUE) if warn, informational, or success severity.
//  Returns zero (FALSE) otherwise
//
#define ITC_ISOK(dwStatus)      (((DWORD)dwStatus & ITC_SEVERITYVALUE_ERROR) != ITC_SEVERITYVALUE_ERROR)
#define ITC_ISSUCCESS(dwStatus)   (((DWORD)dwStatus >> ITC_SEVERITY_BITPOS ) == ITC_SUCCESS_SEVERITY)
#define ITC_ISINFO(dwStatus)   (((DWORD)dwStatus >> ITC_SEVERITY_BITPOS) == ITC_INFORMATIONAL_SEVERITY)
#define ITC_ISWARNING(dwStatus)   (((DWORD)dwStatus >> ITC_SEVERITY_BITPOS) == ITC_WARNING_SEVERITY)
#define ITC_ISERROR(dwStatus)   (((DWORD)dwStatus & ITC_SEVERITYVALUE_ERROR) == ITC_SEVERITYVALUE_ERROR)
#define ITC_FACILITY(dwStatus)   (((DWORD)dwStatus & ITC_FACILITIES_MASK) >> ITC_FACILITY_BITPOS)

//
// DCE DirectShow driver
//
#define ITC_DCE_DSHOW_FACILITY  304
#define ITC_DCE_DSHOW_E        ((ITC_DCE_DSHOW_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DCE_DSHOW_W        ((ITC_DCE_DSHOW_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DCE_DSHOW_S        ((ITC_DCE_DSHOW_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DCE_DSHOW_I        ((ITC_DCE_DSHOW_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
//
// Facility defines for those subsystems that do not have their own Msgsys.mch files.
//
// RFID Servlet
//
#define ITC_RFIDSERVER_FAC  367
#define ITC_RFIDSERVER_E        ((ITC_RFIDSERVER_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_RFIDSERVER_W        ((ITC_RFIDSERVER_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_RFIDSERVER_S        ((ITC_RFIDSERVER_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_RFIDSERVER_I        ((ITC_RFIDSERVER_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// BRI Device Handler
//
#define ITC_BRIDH_FAC  368
#define ITC_BRIDH_E                    ((ITC_BRIDH_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_BRIDH_W        ((ITC_BRIDH_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_BRIDH_S        ((ITC_BRIDH_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_BRIDH_I        ((ITC_BRIDH_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// DeviceComm library
//
#define ITC_DEVICECOMM_FACILITY  369
#define ITC_DEVCOMM_E            ((ITC_DEVICECOMM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DEVCOMM_W        ((ITC_DEVICECOMM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DEVCOMM_S        ((ITC_DEVICECOMM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DEVCOMM_I        ((ITC_DEVICECOMM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
#define ITC_DEVCOMM__RECONNECTED_I (ITC_DEVCOMM_I + 1)
#define ITC_DEVCOMM__RECONNECTED_W (ITC_DEVCOMM_W + 1)
//
// Viewfinder facility.
//
#define ITC_VIEWFINDER_FACILITY 372
#define ITC_VIEWFINDER_E        ((ITC_VIEWFINDER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_VIEWFINDER_W        ((ITC_VIEWFINDER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_VIEWFINDER_S        ((ITC_VIEWFINDER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_VIEWFINDER_I        ((ITC_VIEWFINDER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Imager and camera acquire facility.
//
#define ITC_ACQUIRE_FACILITY 373
#define ITC_ACQUIRE_E        ((ITC_ACQUIRE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_ACQUIRE_W        ((ITC_ACQUIRE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_ACQUIRE_S        ((ITC_ACQUIRE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_ACQUIRE_I        ((ITC_ACQUIRE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// ISCP Frame
//
#define ITC_ISCPFRAME_FAC      697
#define ITC_ISCPFRAME_E        ((ITC_ISCPFRAME_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_ISCPFRAME_W        ((ITC_ISCPFRAME_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_ISCPFRAME_S        ((ITC_ISCPFRAME_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_ISCPFRAME_I        ((ITC_ISCPFRAME_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// ITCISCPComLog.
//
#define ITC_ISCPCOMLOG_FAC     698
#define ITC_ISCPCOMLOG_E       ((ITC_ISCPCOMLOG_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_ISCPCOMLOG_W       ((ITC_ISCPCOMLOG_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_ISCPCOMLOG_S       ((ITC_ISCPCOMLOG_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_ISCPCOMLOG_I       ((ITC_ISCPCOMLOG_FAC << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Engr Automated SW Test (EAST).
//
#define ITC_EAST_FACILITY 800
#define ITC_EAST_LOGSTRING_E   ((ITC_EAST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EAST_LOGSTRING_W   ((ITC_EAST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EAST_LOGSTRING_S   ((ITC_EAST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EAST_LOGSTRING_I   ((ITC_EAST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// CE Device XML Helper (EAST).
//
#define ITC_EAST_CE_XML_HELPER_FACILITY 801
#define ITC_EAST_CE_XML_HELPER_LOGSTRING_E ((ITC_EAST_CE_XML_HELPER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EAST_CE_XML_HELPER_LOGSTRING_W ((ITC_EAST_CE_XML_HELPER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EAST_CE_XML_HELPER_LOGSTRING_S ((ITC_EAST_CE_XML_HELPER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EAST_CE_XML_HELPER_LOGSTRING_I ((ITC_EAST_CE_XML_HELPER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// BC API Test (EAST).
//
#define ITC_EAST_BCAPI_TEST_FACILITY 850
#define ITC_EAST_BCAPI_TEST_LOGSTRING_E ((ITC_EAST_BCAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EAST_BCAPI_TEST_LOGSTRING_W ((ITC_EAST_BCAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EAST_BCAPI_TEST_LOGSTRING_S ((ITC_EAST_BCAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EAST_BCAPI_TEST_LOGSTRING_I ((ITC_EAST_BCAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// RFID API Test (EAST).
//
#define ITC_EAST_RFIDAPI_TEST_FACILITY 855
#define ITC_EAST_RFIDAPI_TEST_LOGSTRING_E ((ITC_EAST_RFIDAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EAST_RFIDAPI_TEST_LOGSTRING_W ((ITC_EAST_RFIDAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EAST_RFIDAPI_TEST_LOGSTRING_S ((ITC_EAST_RFIDAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EAST_RFIDAPI_TEST_LOGSTRING_I ((ITC_EAST_RFIDAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// BC Grid Test (EAST).
//
#define ITC_EAST_BCGRID_TEST_FACILITY 860
#define ITC_EAST_BCGRID_TEST_LOGSTRING_E ((ITC_EAST_BCGRID_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EAST_BCGRID_TEST_LOGSTRING_W ((ITC_EAST_BCGRID_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EAST_BCGRID_TEST_LOGSTRING_S ((ITC_EAST_BCGRID_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EAST_BCGRID_TEST_LOGSTRING_I ((ITC_EAST_BCGRID_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Virtual Scanner DH (EAST).
//
#define ITC_EAST_VIRTUAL_SCANNER_FACILITY 861
#define ITC_EAST_VIRTUAL_SCANNER_LOGSTRING_E   ((ITC_EAST_VIRTUAL_SCANNER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EAST_VIRTUAL_SCANNER_LOGSTRING_W   ((ITC_EAST_VIRTUAL_SCANNER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EAST_VIRTUAL_SCANNER_LOGSTRING_S   ((ITC_EAST_VIRTUAL_SCANNER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EAST_VIRTUAL_SCANNER_LOGSTRING_I   ((ITC_EAST_VIRTUAL_SCANNER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Virtual Scanner API (EAST).
//
#define ITC_EAST_VIRTUAL_SCANNER_API_FACILITY 862
#define ITC_EAST_VIRTUAL_SCANNER_API_LOGSTRING_E ((ITC_EAST_VIRTUAL_SCANNER_API_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EAST_VIRTUAL_SCANNER_API_LOGSTRING_W ((ITC_EAST_VIRTUAL_SCANNER_API_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EAST_VIRTUAL_SCANNER_API_LOGSTRING_S ((ITC_EAST_VIRTUAL_SCANNER_API_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EAST_VIRTUAL_SCANNER_API_LOGSTRING_I ((ITC_EAST_VIRTUAL_SCANNER_API_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Smart System API (EAST).
//
#define ITC_EAST_SSAPI_TEST_FACILITY 865
#define ITC_EAST_SSAPI_TEST_LOGSTRING_E ((ITC_EAST_SSAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EAST_SSAPI_TEST_LOGSTRING_W ((ITC_EAST_SSAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EAST_SSAPI_TEST_LOGSTRING_S ((ITC_EAST_SSAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EAST_SSAPI_TEST_LOGSTRING_I ((ITC_EAST_SSAPI_TEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Linear Scanner Device Driver.
//
#define ITC_HOSTDECODE_LASER 1001
#define ITC_LDD_LOGSTRING_E    ((ITC_HOSTDECODE_LASER << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_LDD_LOGSTRING_W    ((ITC_HOSTDECODE_LASER << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_LDD_LOGSTRING_S    ((ITC_HOSTDECODE_LASER << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_LDD_LOGSTRING_I    ((ITC_HOSTDECODE_LASER << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL Manufacturing Functions
//
#define ITC_PAL_MFGOPTION_FACILITY 1008
#define ITC_PALMFG_LOGSTRING_E ((ITC_PAL_MFGOPTION_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALMFG_LOGSTRING_W ((ITC_PAL_MFGOPTION_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALMFG_LOGSTRING_S ((ITC_PAL_MFGOPTION_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALMFG_LOGSTRING_I ((ITC_PAL_MFGOPTION_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL SYSIO Functions
//
#define ITC_PAL_SYSIO_FACILITY 1009
#define ITC_PALSYS_LOGSTRING_E ((ITC_PAL_SYSIO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALSYS_LOGSTRING_W ((ITC_PAL_SYSIO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALSYS_LOGSTRING_S ((ITC_PAL_SYSIO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALSYS_LOGSTRING_I ((ITC_PAL_SYSIO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// DCEInit Functions
//
#define ITC_DCEINIT_FACILITY 1010
#define ITC_DCEINIT_LOGSTRING_E    ((ITC_DCEINIT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DCEINIT_LOGSTRING_W    ((ITC_DCEINIT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DCEINIT_LOGSTRING_S    ((ITC_DCEINIT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DCEINIT_LOGSTRING_I    ((ITC_DCEINIT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Scanner Interrupt Events
//
#define ITC_LSCANNER_INTERRUPT_FACILITY 1011
#define ITC_LDDINT_LOGSTRING_E ((ITC_LSCANNER_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_LDDINT_LOGSTRING_W ((ITC_LSCANNER_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_LDDINT_LOGSTRING_S ((ITC_LSCANNER_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_LDDINT_LOGSTRING_I ((ITC_LSCANNER_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// STC Decodes Events
//
#define ITC_STCDECODES_FACILITY 1012
#define ITC_STCDECODE_LOGSTRING_E  ((ITC_STCDECODES_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_STCDECODE_LOGSTRING_W  ((ITC_STCDECODES_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_STCDECODE_LOGSTRING_S  ((ITC_STCDECODES_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_STCDECODE_LOGSTRING_I  ((ITC_STCDECODES_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Host Decodes Driver Common
//
#define ITC_DRIVERCOMMON_FACILITY 1013
#define ITC_DRIVERCOMMON_LOGSTRING_E   ((ITC_DRIVERCOMMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DRIVERCOMMON_LOGSTRING_W   ((ITC_DRIVERCOMMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DRIVERCOMMON_LOGSTRING_S   ((ITC_DRIVERCOMMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DRIVERCOMMON_LOGSTRING_I   ((ITC_DRIVERCOMMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Imager Interrupt Events
//
#define ITC_IMGDECODER_INTERRUPT_FACILITY 1014
#define ITC_IMGINT_LOGSTRING_E ((ITC_IMGDECODER_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IMGINT_LOGSTRING_W ((ITC_IMGDECODER_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IMGINT_LOGSTRING_S ((ITC_IMGDECODER_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IMGINT_LOGSTRING_I ((ITC_IMGDECODER_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// EV10 Linear Imager Interrupt Events
//
#define ITC_EV10_INTERRUPT_FACILITY 1017
#define ITC_EVXINT_LOGSTRING_E ((ITC_EV10_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EVXINT_LOGSTRING_W ((ITC_EV10_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EVXINT_LOGSTRING_S ((ITC_EV10_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EVXINT_LOGSTRING_I ((ITC_EV10_INTERRUPT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Imager Interrupt Events
//
#define ITC_DCDEMO_FACILITY 1016
#define ITC_DCDEMO_LOGSTRING_E ((ITC_DCDEMO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DCDEMO_LOGSTRING_W ((ITC_DCDEMO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DCDEMO_LOGSTRING_S ((ITC_DCDEMO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DCDEMO_LOGSTRING_I ((ITC_DCDEMO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL Beeper
//
#define ITC_PALBEEP_FACILITY 1003
#define ITC_PALBEEP_LOGSTRING_E    ((ITC_PALBEEP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALBEEP_LOGSTRING_W    ((ITC_PALBEEP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALBEEP_LOGSTRING_S    ((ITC_PALBEEP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALBEEP_LOGSTRING_I    ((ITC_PALBEEP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL Led
//
#define ITC_PALLED_FACILITY 1004
#define ITC_PALLED_LOGSTRING_E ((ITC_PALLED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALLED_LOGSTRING_W ((ITC_PALLED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALLED_LOGSTRING_S ((ITC_PALLED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALLED_LOGSTRING_I ((ITC_PALLED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL Keypad
//
#define ITC_PALKEYPAD_FACILITY 1005
#define ITC_PALKEYPAD_LOGSTRING_E  ((ITC_PALKEYPAD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALKEYPAD_LOGSTRING_W  ((ITC_PALKEYPAD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALKEYPAD_LOGSTRING_S  ((ITC_PALKEYPAD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALKEYPAD_LOGSTRING_I  ((ITC_PALKEYPAD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL Display
//
#define ITC_PALDISP_FACILITY 1006
#define ITC_PALDISP_LOGSTRING_E    ((ITC_PALDISP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALDISP_LOGSTRING_W    ((ITC_PALDISP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALDISP_LOGSTRING_S    ((ITC_PALDISP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALDISP_LOGSTRING_I    ((ITC_PALDISP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL Power Management
//
#define ITC_PALPWR_FACILITY 1007
#define ITC_PALPWR_LOGSTRING_E ((ITC_PALPWR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALPWR_LOGSTRING_W ((ITC_PALPWR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALPWR_LOGSTRING_S ((ITC_PALPWR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALPWR_LOGSTRING_I ((ITC_PALPWR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL Vibrate
//
#define ITC_PALVIB_FACILITY 1015
#define ITC_PALVIB_LOGSTRING_E ((ITC_PALVIB_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALVIB_LOGSTRING_W ((ITC_PALVIB_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALVIB_LOGSTRING_S ((ITC_PALVIB_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALVIB_LOGSTRING_I ((ITC_PALVIB_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// S9CUpgrade
//
#define ITC_S9CUPGRADE_FACILITY 699
#define ITC_S9CUPGRADE_LOGSTRING_E ((ITC_S9CUPGRADE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_S9CUPGRADE_LOGSTRING_W ((ITC_S9CUPGRADE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_S9CUPGRADE_LOGSTRING_S ((ITC_S9CUPGRADE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_S9CUPGRADE_LOGSTRING_I ((ITC_S9CUPGRADE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL POWER COMx
//
#define ITC_PALCOMXPWR_FACILITY 1018
#define ITC_PALCOMXPWR_LOGSTRING_E ((ITC_PALCOMXPWR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALCOMXPWR_LOGSTRING_W ((ITC_PALCOMXPWR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALCOMXPWR_LOGSTRING_S ((ITC_PALCOMXPWR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALCOMXPWR_LOGSTRING_I ((ITC_PALCOMXPWR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// S9CDeviceHandler Autobaud
//
#define ITC_S9CDH_AUTOBAUD_FACILITY 1019
#define ITC_S9CDH_AUTOBAUD_LOGSTRING_E ((ITC_S9CDH_AUTOBAUD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_S9CDH_AUTOBAUD_LOGSTRING_W ((ITC_S9CDH_AUTOBAUD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_S9CDH_AUTOBAUD_LOGSTRING_S ((ITC_S9CDH_AUTOBAUD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_S9CDH_AUTOBAUD_LOGSTRING_I ((ITC_S9CDH_AUTOBAUD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
#define ITC_S9CDH_AUTOBAUD_LOGBINARY_I ((ITC_S9CDH_AUTOBAUD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// UnitConfig
//
#define ITC_UNITCONFIG_FACILITY 1020
#define ITC_UNITCONFIG_LOGSTRING_E ((ITC_UNITCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_UNITCONFIG_LOGSTRING_W ((ITC_UNITCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_UNITCONFIG_LOGSTRING_S ((ITC_UNITCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_UNITCONFIG_LOGSTRING_I ((ITC_UNITCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// DataCollConfig
//
#define ITC_DATACOLLCONFIG_FACILITY 320
#define ITC_DATACOLLCONFIG_LOGSTRING_E ((ITC_DATACOLLCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DATACOLLCONFIG_LOGSTRING_W ((ITC_DATACOLLCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DATACOLLCONFIG_LOGSTRING_S ((ITC_DATACOLLCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DATACOLLCONFIG_LOGSTRING_I ((ITC_DATACOLLCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// ITCDCConfig
//
#define ITC_ITCDCCONFIG_FACILITY 321
#define ITC_ITCDCCONFIG_LOGSTRING_E    ((ITC_ITCDCCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_ITCDCCONFIG_LOGSTRING_W    ((ITC_ITCDCCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_ITCDCCONFIG_LOGSTRING_S    ((ITC_ITCDCCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_ITCDCCONFIG_LOGSTRING_I    ((ITC_ITCDCCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// DataServer
//
#define ITC_DATASERVER_FACILITY 352
#define ITC_DATASERVER_LOGSTRING_E    ((ITC_DATASERVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DATASERVER_LOGSTRING_W    ((ITC_DATASERVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DATASERVER_LOGSTRING_S    ((ITC_DATASERVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DATASERVER_LOGSTRING_I    ((ITC_DATASERVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Viewfinder
//
#define ITC_VIEWFINDER_FACILITY 372
#define ITC_VIEWFINDER__LOGSTRING_E    ((ITC_VIEWFINDER__FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_VIEWFINDER__LOGSTRING_W    ((ITC_VIEWFINDER__FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_VIEWFINDER__LOGSTRING_S    ((ITC_VIEWFINDER__FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_VIEWFINDER__LOGSTRING_I    ((ITC_VIEWFINDER__FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// NETWORKCONFIGLET
//
//#define ITC_CNPSUBAGENT_FACILITY 502
#define ITC_CNPSUBAGENT_LOGSTRING_E    ((ITC_NETWORKCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_CNPSUBAGENT_LOGSTRING_W    ((ITC_NETWORKCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_CNPSUBAGENT_LOGSTRING_S    ((ITC_NETWORKCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_CNPSUBAGENT_LOGSTRING_I    ((ITC_NETWORKCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// ITCDCEPreSetup
//
#define ITC_CV60CEPRESETUP_FACILITY 1021
#define ITC_CV60CEPRESETUP_LOGSTRING_E ((ITC_CV60CEPRESETUP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_CV60CEPRESETUP_LOGSTRING_W ((ITC_CV60CEPRESETUP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_CV60CEPRESETUP_LOGSTRING_S ((ITC_CV60CEPRESETUP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_CV60CEPRESETUP_LOGSTRING_I ((ITC_CV60CEPRESETUP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// IKL
//
#define ITC_IKL_FACILITY 1023
#define ITC_IKL_LOGSTRING_E    ((ITC_IKL_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IKL_LOGSTRING_W    ((ITC_IKL_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IKL_LOGSTRING_S    ((ITC_IKL_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IKL_LOGSTRING_I    ((ITC_IKL_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// IKL
//
#define ITC_IKL_EVENT_FACILITY 1024
#define ITC_IKL_EVENT_LOGSTRING_E  ((ITC_IKL_EVENT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IKL_EVENT_LOGSTRING_W  ((ITC_IKL_EVENT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IKL_EVENT_LOGSTRING_S  ((ITC_IKL_EVENT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IKL_EVENT_LOGSTRING_I  ((ITC_IKL_EVENT_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PALIDLETIMER
//
#define ITC_PALIDLETIMER_FACILITY 1025
#define ITC_PALIDLETIMER_LOGSTRING_E   ((ITC_PALIDLETIMER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALIDLETIMER_LOGSTRING_W   ((ITC_PALIDLETIMER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALIDLETIMER_LOGSTRING_S   ((ITC_PALIDLETIMER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALIDLETIMER_LOGSTRING_I   ((ITC_PALIDLETIMER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// TETHTEST
//
#define ITC_TETHTEST_FACILITY 1026
#define ITC_TETHTEST_LOGSTRING_E   ((ITC_TETHTEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_TETHTEST_LOGSTRING_W   ((ITC_TETHTEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_TETHTEST_LOGSTRING_S   ((ITC_TETHTEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_TETHTEST_LOGSTRING_I   ((ITC_TETHTEST_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// BTScannerDH facility BTSCANDH
//
#define ITC_BTSCANDH_FACILITY 1027
#define ITC_BTSCANDH_LOGSTRING_E   ((ITC_BTSCANDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_BTSCANDH_LOGSTRING_W   ((ITC_BTSCANDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_BTSCANDH_LOGSTRING_S   ((ITC_BTSCANDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_BTSCANDH_LOGSTRING_I   ((ITC_BTSCANDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
#define ITC_BTSCANDH_RECONNECT_W   (ITC_BTSCANDH_LOGSTRING_W + 1)
#define ITC_BTSCANDH_RECONNECT_I   (ITC_BTSCANDH_LOGSTRING_I + 1)
#define ITC_BTSCANDH_INVPACKET_W   (ITC_BTSCANDH_LOGSTRING_W + 2)
//
// ISCPScanGroupPH facility
//
#define ITC_ISCP_SCANGROUPPH_FACILITY 1028
#define ITC_ISCP_SGPH_LOGSTRING_E  ((ITC_ISCP_SCANGROUPPH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_ISCP_SGPH_LOGSTRING_W  ((ITC_ISCP_SCANGROUPPH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_ISCP_SGPH_LOGSTRING_S  ((ITC_ISCP_SCANGROUPPH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_ISCP_SGPH_LOGSTRING_I  ((ITC_ISCP_SCANGROUPPH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// BTServer facility
//
#define ITC_BTSERVER_FACILITY 1030
#define ITC_BTSERVER_LOGSTRING_E   ((ITC_BTSERVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_BTSERVER_LOGSTRING_W   ((ITC_BTSERVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_BTSERVER_LOGSTRING_S   ((ITC_BTSERVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_BTSERVER_LOGSTRING_I   ((ITC_BTSERVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// UnitConfiglet
//
#define ITC_UNITCONFIGLET_FACILITY 1029
#define ITC_UNITCONFIGLET_LOGSTRING_E  ((ITC_UNITCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_UNITCONFIGLET_LOGSTRING_W  ((ITC_UNITCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_UNITCONFIGLET_LOGSTRING_S  ((ITC_UNITCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_UNITCONFIGLET_LOGSTRING_I  ((ITC_UNITCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// RCP
//
#define ITC_RCP_FACILITY 1031
#define ITC_RCP_LOGSTRING_E    ((ITC_RCP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_RCP_LOGSTRING_W    ((ITC_RCP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_RCP_LOGSTRING_S    ((ITC_RCP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_RCP_LOGSTRING_I    ((ITC_RCP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// RCPREQ
//
#define ITC_RCPREQ_FACILITY 1032
#define ITC_RCPREQ_LOGSTRING_E    ((ITC_RCPREQ_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_RCPREQ_LOGSTRING_W    ((ITC_RCPREQ_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_RCPREQ_LOGSTRING_S    ((ITC_RCPREQ_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_RCPREQ_LOGSTRING_I    ((ITC_RCPREQ_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// NetClient Configlet
// (UDP Plus, PSK networking, dcBrowser, etc.,)
//
#define ITC_NETCLIENTCONFIGLET_FACILITY 1034
#define ITC_NETCLIENTCONFIGLET_LOGSTRING_E  ((ITC_NETCLIENTCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_NETCLIENTCONFIGLET_LOGSTRING_W  ((ITC_NETCLIENTCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_NETCLIENTCONFIGLET_LOGSTRING_S  ((ITC_NETCLIENTCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_NETCLIENTCONFIGLET_LOGSTRING_I  ((ITC_NETCLIENTCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// EV15 ISCP DH
//
#define ITC_EV15DH_FACILITY 1033
#define ITC_EV15DH_LOGSTRING_E ((ITC_EV15DH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_EV15DH_LOGSTRING_W ((ITC_EV15DH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_EV15DH_LOGSTRING_S ((ITC_EV15DH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_EV15DH_LOGSTRING_I ((ITC_EV15DH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// NETWORKCONFIGLET
//
#define ITC_NETWORKCONFIGLET_FACILITY 1035
#define ITC_NETWORKCONFIGLET_LOGSTRING_E    ((ITC_NETWORKCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_NETWORKCONFIGLET_LOGSTRING_W    ((ITC_NETWORKCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_NETWORKCONFIGLET_LOGSTRING_S    ((ITC_NETWORKCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_NETWORKCONFIGLET_LOGSTRING_I    ((ITC_NETWORKCONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// ICCU
//
#define ITC_ICCU_FACILITY 1036
#define ITC_ICCU_LOGSTRING_E    ((ITC_ICCU_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_ICCU_LOGSTRING_W    ((ITC_ICCU_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_ICCU_LOGSTRING_S    ((ITC_ICCU_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_ICCU_LOGSTRING_I    ((ITC_ICCU_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// IQACCESS
//
#define ITC_IQACCESS_FACILITY 1037
#define ITC_IQACCESS_LOGSTRING_E    ((ITC_IQACCESS_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IQACCESS_LOGSTRING_W    ((ITC_IQACCESS_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IQACCESS_LOGSTRING_S    ((ITC_IQACCESS_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IQACCESS_LOGSTRING_I    ((ITC_IQACCESS_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// TriggerEvents
//
#define ITC_TRIG_FACILITY 1038
#define ITC_TRIG_LOGSTRING_E    ((ITC_TRIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_TRIG_LOGSTRING_W    ((ITC_TRIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_TRIG_LOGSTRING_S    ((ITC_TRIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_TRIG_LOGSTRING_I    ((ITC_TRIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL SysInfo
//
#define ITC_PALSYSINFO_FACILITY 1039
#define ITC_PALSYSINFO_LOGSTRING_E    ((ITC_PALSYSINFO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALSYSINFO_LOGSTRING_W    ((ITC_PALSYSINFO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALSYSINFO_LOGSTRING_S    ((ITC_PALSYSINFO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALSYSINFO_LOGSTRING_I    ((ITC_PALSYSINFO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PB42Config
//
#define ITC_PB42CONFIG_FACILITY 1040
#define ITC_PB42CONFIG_LOGSTRING_E    ((ITC_PB42CONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PB42CONFIG_LOGSTRING_W    ((ITC_PB42CONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PB42CONFIG_LOGSTRING_S    ((ITC_PB42CONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PB42CONFIG_LOGSTRING_I    ((ITC_PB42CONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PALClock
//
#define ITC_PALCLOCK_FACILITY 1043
#define ITC_PALCLOCK_LOGSTRING_E    ((ITC_PALCLOCK_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALCLOCK_LOGSTRING_W    ((ITC_PALCLOCK_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALCLOCK_LOGSTRING_S    ((ITC_PALCLOCK_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALCLOCK_LOGSTRING_I    ((ITC_PALCLOCK_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// ITCCommon
//
#define ITC_ITCCOMMON_FACILITY 1045
#define ITC_ITCCOMMON_LOGSTRING_E    ((ITC_ITCCOMMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_ITCCOMMON_LOGSTRING_W    ((ITC_ITCCOMMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_ITCCOMMON_LOGSTRING_S    ((ITC_ITCCOMMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_ITCCOMMON_LOGSTRING_I    ((ITC_ITCCOMMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// AutoReg
//
#define ITC_AUTOREG_FACILITY 1046
#define ITC_AUTOREG_LOGSTRING_E    ((ITC_AUTOREG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_AUTOREG_LOGSTRING_W    ((ITC_AUTOREG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_AUTOREG_LOGSTRING_S    ((ITC_AUTOREG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_AUTOREG_LOGSTRING_I    ((ITC_AUTOREG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// AutoCab
//
#define ITC_AUTOCAB_FACILITY 1047
#define ITC_AUTOCAB_LOGSTRING_E    ((ITC_AUTOCAB_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_AUTOCAB_LOGSTRING_W    ((ITC_AUTOCAB_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_AUTOCAB_LOGSTRING_S    ((ITC_AUTOCAB_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_AUTOCAB_LOGSTRING_I    ((ITC_AUTOCAB_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// AutoExec
//
#define ITC_AUTOEXEC_FACILITY 1048
#define ITC_AUTOEXEC_LOGSTRING_E    ((ITC_AUTOEXEC_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_AUTOEXEC_LOGSTRING_W    ((ITC_AUTOEXEC_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_AUTOEXEC_LOGSTRING_S    ((ITC_AUTOEXEC_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_AUTOEXEC_LOGSTRING_I    ((ITC_AUTOEXEC_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// AutoRun
//
#define ITC_AUTORUN_FACILITY 1049
#define ITC_AUTORUN_LOGSTRING_E    ((ITC_AUTORUN_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_AUTORUN_LOGSTRING_W    ((ITC_AUTORUN_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_AUTORUN_LOGSTRING_S    ((ITC_AUTORUN_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_AUTORUN_LOGSTRING_I    ((ITC_AUTORUN_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// MemMgr device driver
//
#define ITC_MEMMGR_FACILITY 1050
#define ITC_MEMMGR_LOGSTRING_E    ((ITC_MEMMGR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_MEMMGR_LOGSTRING_W    ((ITC_MEMMGR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_MEMMGR_LOGSTRING_S    ((ITC_MEMMGR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_MEMMGR_LOGSTRING_I    ((ITC_MEMMGR_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// IQ
//
#define ITC_IQ_FACILITY 1051
#define ITC_IQ_LOGSTRING_E    ((ITC_IQ_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IQ_LOGSTRING_W    ((ITC_IQ_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IQ_LOGSTRING_S    ((ITC_IQ_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IQ_LOGSTRING_I    ((ITC_IQ_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Imager - discrete functions
//
#define ITC_IMGDSC_FACILITY 1052
#define ITC_IMGDSC_LOGSTRING_E    ((ITC_IMGDSC_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IMGDSC_LOGSTRING_W    ((ITC_IMGDSC_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IMGDSC_LOGSTRING_S    ((ITC_IMGDSC_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IMGDSC_LOGSTRING_I    ((ITC_IMGDSC_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Smart Systems Device Monitor
//
#define ITC_SSDEVMON_FACILITY 1053
#define ITC_SSDEVMON_LOGSTRING_E    ((ITC_SSDEVMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_SSDEVMON_LOGSTRING_W    ((ITC_SSDEVMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_SSDEVMON_LOGSTRING_S    ((ITC_SSDEVMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_SSDEVMON_LOGSTRING_I    ((ITC_SSDEVMON_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Bluetooth testware and production software
//
#define ITC_BLUETOOTH_FACILITY 1054
#define ITC_BLUETOOTH_LOGSTRING_E    ((ITC_BLUETOOTH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_BLUETOOTH_LOGSTRING_W    ((ITC_BLUETOOTH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_BLUETOOTH_LOGSTRING_S    ((ITC_BLUETOOTH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_BLUETOOTH_LOGSTRING_I    ((ITC_BLUETOOTH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// IDTech slot scanner device handler
//
#define ITC_IDTECH_FACILITY 1056
#define ITC_IDTECH_LOGSTRING_E    ((ITC_IDTECH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IDTECH_LOGSTRING_W    ((ITC_IDTECH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IDTECH_LOGSTRING_S    ((ITC_IDTECH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IDTECH_LOGSTRING_I    ((ITC_IDTECH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// IDTech slot scanner communications
//
#define ITC_IDTECH_COM_FACILITY 1057
#define ITC_IDTECH_COM_LOGSTRING_E    ((ITC_IDTECH_COM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IDTECH_COM_LOGSTRING_W    ((ITC_IDTECH_COM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IDTECH_COM_LOGSTRING_S    ((ITC_IDTECH_COM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IDTECH_COM_LOGSTRING_I    ((ITC_IDTECH_COM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Install Select Control Panel Applet
//
#define ITC_INSTALLSEL_FACILITY 1058
#define ITC_INSTALLSEL_LOGSTRING_E    ((ITC_INSTALLSEL_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_INSTALLSEL_LOGSTRING_W    ((ITC_INSTALLSEL_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_INSTALLSEL_LOGSTRING_S    ((ITC_INSTALLSEL_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_INSTALLSEL_LOGSTRING_I    ((ITC_INSTALLSEL_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// GROUPDH
//
#define ITC_GROUPDH_FACILITY 1042
#define ITC_GROUPDH_LOGSTRING_E    ((ITC_GROUPDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_GROUPDH_LOGSTRING_W    ((ITC_GROUPDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_GROUPDH_LOGSTRING_S    ((ITC_GROUPDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_GROUPDH_LOGSTRING_I    ((ITC_GROUPDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Group APIs or classes in DeviceLib project
//
#define ITC_DEVICELIB_GROUP_FACILITY 1044
#define ITC_DEVICELIB_GROUP_LOGSTRING_E    ((ITC_DEVICELIB_GROUP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DEVICELIB_GROUP_LOGSTRING_W    ((ITC_DEVICELIB_GROUP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DEVICELIB_GROUP_LOGSTRING_S    ((ITC_DEVICELIB_GROUP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DEVICELIB_GROUP_LOGSTRING_I    ((ITC_DEVICELIB_GROUP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Used in Group Input/Output functions in DeviceLib project
//
#define ITC_DEVICELIB_GROUPIO_FACILITY 1060
#define ITC_DEVICELIB_GROUPIO_LOGSTRING_E    ((ITC_DEVICELIB_GROUPIO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DEVICELIB_GROUPIO_LOGSTRING_W    ((ITC_DEVICELIB_GROUPIO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DEVICELIB_GROUPIO_LOGSTRING_S    ((ITC_DEVICELIB_GROUPIO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DEVICELIB_GROUPIO_LOGSTRING_I    ((ITC_DEVICELIB_GROUPIO_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Scanner Upgrade Utility
//
#define ITC_SCANUPGRD_FACILITY 1059
#define ITC_SCANUPGRD_LOGSTRING_E    ((ITC_SCANUPGRD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_SCANUPGRD_LOGSTRING_W    ((ITC_SCANUPGRD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_SCANUPGRD_LOGSTRING_S    ((ITC_SCANUPGRD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_SCANUPGRD_LOGSTRING_I    ((ITC_SCANUPGRD_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// TE2000
//
#define ITC_TE2000_FACILITY 1059
#define ITC_TE2000_LOGSTRING_E    ((ITC_TE2000_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_TE2000_LOGSTRING_W    ((ITC_TE2000_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_TE2000_LOGSTRING_S    ((ITC_TE2000_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_TE2000_LOGSTRING_I    ((ITC_TE2000_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// SigCap events
//
#define ITC_SIGCAP_FACILITY 1061
#define ITC_SIGCAP_LOGSTRING_E    ((ITC_SIGCAP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_SIGCAP_LOGSTRING_W    ((ITC_SIGCAP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_SIGCAP_LOGSTRING_S    ((ITC_SIGCAP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_SIGCAP_LOGSTRING_I    ((ITC_SIGCAP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// SerialISCPDH events
//
#define ITC_SERIALISCPDH_FACILITY 1062
#define ITC_SERIALISCPDH_LOGSTRING_E    ((ITC_SERIALISCPDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_SERIALISCPDH_LOGSTRING_W    ((ITC_SERIALISCPDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_SERIALISCPDH_LOGSTRING_S    ((ITC_SERIALISCPDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_SERIALISCPDH_LOGSTRING_I    ((ITC_SERIALISCPDH_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PnPServlet
//
#define ITC_PNPSERVLET_FACILITY 1063
#define ITC_PNPSERVLET_LOGSTRING_E    ((ITC_PNPSERVLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PNPSERVLET_LOGSTRING_W    ((ITC_PNPSERVLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PNPSERVLET_LOGSTRING_S    ((ITC_PNPSERVLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PNPSERVLET_LOGSTRING_I    ((ITC_PNPSERVLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// SPI Driver
//
#define ITC_SPI_DRIVER_FACILITY 1064
#define ITC_SPI_LOGSTRING_E    ((ITC_SPI_DRIVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_SPI_LOGSTRING_W    ((ITC_SPI_DRIVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_SPI_LOGSTRING_S    ((ITC_SPI_DRIVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_SPI_LOGSTRING_I    ((ITC_SPI_DRIVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// TE2000
//
#define ITC_TE2000_FACILITY 1059
#define ITC_TE2000_LOGSTRING_E    ((ITC_TE2000_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_TE2000_LOGSTRING_W    ((ITC_TE2000_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_TE2000_LOGSTRING_S    ((ITC_TE2000_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_TE2000_LOGSTRING_I    ((ITC_TE2000_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL INTERFACE
//
#define ITC_PALINTERFACE_FACILITY 1068
#define ITC_PALINTERFACE_LOGSTRING_E    ((ITC_PALINTERFACE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALINTERFACE_LOGSTRING_W    ((ITC_PALINTERFACE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALINTERFACE_LOGSTRING_S    ((ITC_PALINTERFACE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALINTERFACE_LOGSTRING_I    ((ITC_PALINTERFACE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL PHONE
//
#define ITC_PALPHONE_FACILITY 1069
#define ITC_PALPHONE_LOGSTRING_E    ((ITC_PALPHONE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALPHONE_LOGSTRING_W    ((ITC_PALPHONE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALPHONE_LOGSTRING_S    ((ITC_PALPHONE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALPHONE_LOGSTRING_I    ((ITC_PALPHONE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Memory diagnostics logging
//
#define ITC_MEMDIAG_FACILITY 1067
#define ITC_MEMDIAG_LOGSTRING_E    ((ITC_MEMDIAG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_MEMDIAG_LOGSTRING_W    ((ITC_MEMDIAG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_MEMDIAG_LOGSTRING_S    ((ITC_MEMDIAG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_MEMDIAG_LOGSTRING_I    ((ITC_MEMDIAG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Scanner Stats
//
#define ITC_SCANSTATS_FACILITY 1070
#define ITC_SCANSTATS_LOGSTRING_E    ((ITC_SCANSTATS_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_SCANSTATS_LOGSTRING_W    ((ITC_SCANSTATS_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_SCANSTATS_LOGSTRING_S    ((ITC_SCANSTATS_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_SCANSTATS_LOGSTRING_I    ((ITC_SCANSTATS_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL VERSION
//
#define ITC_PALVER_FACILITY 1071
#define ITC_PALVER_LOGSTRING_E    ((ITC_PALVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALVER_LOGSTRING_W    ((ITC_PALVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALVER_LOGSTRING_S    ((ITC_PALVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALVER_LOGSTRING_I    ((ITC_PALVER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Acquire Driver
//
#define ITC_DCDRV_FACILITY 1072
#define ITC_DCDRV_LOGSTRING_E    ((ITC_DCDRV_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DCDRV_LOGSTRING_W    ((ITC_DCDRV_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DCDRV_LOGSTRING_S    ((ITC_DCDRV_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DCDRV_LOGSTRING_I    ((ITC_DCDRV_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Policy
//
#define ITC_POLICY_FACILITY 1074
#define ITC_POLICY_LOGSTRING_E    ((ITC_POLICY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_POLICY_LOGSTRING_W    ((ITC_POLICY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_POLICY_LOGSTRING_S    ((ITC_POLICY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_POLICY_LOGSTRING_I    ((ITC_POLICY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// I2C for imager drivers
//
#define ITC_I2C_FACILITY 1075
#define ITC_I2C_LOGSTRING_E    ((ITC_I2C_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_I2C_LOGSTRING_W    ((ITC_I2C_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_I2C_LOGSTRING_S    ((ITC_I2C_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_I2C_LOGSTRING_I    ((ITC_I2C_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL Security
//
#define ITC_PALSECURITY_FACILITY 1094
#define ITC_PALSECURITY_LOGSTRING_E    ((ITC_PALSECURITY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALSECURITY_LOGSTRING_W    ((ITC_PALSECURITY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALSECURITY_LOGSTRING_S    ((ITC_PALSECURITY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALSECURITY_LOGSTRING_I    ((ITC_PALSECURITY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Image capture classes in DeviceLib
//
#define ITC_IMGCAP_HELP_FACILITY 1077
#define ITC_IMGCAP_HELP_LOGSTRING_E    ((ITC_IMGCAP_HELP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IMGCAP_HELP_LOGSTRING_W    ((ITC_IMGCAP_HELP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IMGCAP_HELP_LOGSTRING_S    ((ITC_IMGCAP_HELP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IMGCAP_HELP_LOGSTRING_I    ((ITC_IMGCAP_HELP_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// S9CISCPPH IImage4 APIs
//
#define ITC_IMGCAP_API_FACILITY 1078
#define ITC_IMGCAP_API_LOGSTRING_E    ((ITC_IMGCAP_API_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_IMGCAP_API_LOGSTRING_W    ((ITC_IMGCAP_API_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_IMGCAP_API_LOGSTRING_S    ((ITC_IMGCAP_API_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_IMGCAP_API_LOGSTRING_I    ((ITC_IMGCAP_API_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PAL USB MASS STORAGE
//
#define ITC_PALUSBMASSSTORAGE_FACILITY 1103
#define ITC_PALUSBMASSSTORAGE_LOGSTRING_E    ((ITC_PALUSBMASSSTORAGE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PALUSBMASSSTORAGE_LOGSTRING_W    ((ITC_PALUSBMASSSTORAGE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PALUSBMASSSTORAGE_LOGSTRING_S    ((ITC_PALUSBMASSSTORAGE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PALUSBMASSSTORAGE_LOGSTRING_I    ((ITC_PALUSBMASSSTORAGE_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// SeiralISCPDH ProcessFrame 
//
#define ITC_ISCPDH_PROCFRM_FACILITY 1081
#define ITC_ISCPDH_PROCFRM_LOGSTRING_E    ((ITC_ISCPDH_PROCFRM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_ISCPDH_PROCFRM_LOGSTRING_W    ((ITC_ISCPDH_PROCFRM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_ISCPDH_PROCFRM_LOGSTRING_S    ((ITC_ISCPDH_PROCFRM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_ISCPDH_PROCFRM_LOGSTRING_I    ((ITC_ISCPDH_PROCFRM_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Device Native LicenseManagerApi for Licenseing 
//
#define ITC_DEVICE_LMAPI_FACILITY 1083
#define ITC_DEVICE_LMAPI_LOGSTRING_E    ((ITC_DEVICE_LMAPI_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DEVICE_LMAPI_LOGSTRING_W    ((ITC_DEVICE_LMAPI_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DEVICE_LMAPI_LOGSTRING_S    ((ITC_DEVICE_LMAPI_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DEVICE_LMAPI_LOGSTRING_I    ((ITC_DEVICE_LMAPI_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Device Managed LicenseManagerApi for Licenseing  
//
#define ITC_DEVICE_LMAPI_MANAGED_FACILITY 1084
#define ITC_DEVICE_LMAPI_MANAGED_LOGSTRING_E    ((ITC_DEVICE_LMAPI_MANAGED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_DEVICE_LMAPI_MANAGED_LOGSTRING_W    ((ITC_DEVICE_LMAPI_MANAGED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_DEVICE_LMAPI_MANAGED_LOGSTRING_S    ((ITC_DEVICE_LMAPI_MANAGED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_DEVICE_LMAPI_MANAGED_LOGSTRING_I    ((ITC_DEVICE_LMAPI_MANAGED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// License Configlet
//
#define ITC_LICENSE_CONFIGLET_FACILITY 1085
#define ITC_LICENSE_CONFIGLET_LOGSTRING_E    ((ITC_LICENSE_CONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_LICENSE_CONFIGLET_LOGSTRING_W    ((ITC_LICENSE_CONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_LICENSE_CONFIGLET_LOGSTRING_S    ((ITC_LICENSE_CONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_LICENSE_CONFIGLET_LOGSTRING_I    ((ITC_LICENSE_CONFIGLET_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PC Native LMAPI for Licensing
//
#define ITC_PC_LMAPI_FACILITY 1086
#define ITC_PC_LMAPI_LOGSTRING_E    ((ITC_PC_LMAPI_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PC_LMAPI_LOGSTRING_W    ((ITC_PC_LMAPI_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PC_LMAPI_LOGSTRING_S    ((ITC_PC_LMAPI_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PC_LMAPI_LOGSTRING_I    ((ITC_PC_LMAPI_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// PC Managed LMAPI for Licensing 
//
#define ITC_PC_LMAPI_MANAGED_FACILITY 1087
#define ITC_PC_LMAPI_MANAGED_LOGSTRING_E    ((ITC_PC_LMAPI_MANAGED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_PC_LMAPI_MANAGED_LOGSTRING_W    ((ITC_PC_LMAPI_MANAGED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_PC_LMAPI_MANAGED_LOGSTRING_S    ((ITC_PC_LMAPI_MANAGED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_PC_LMAPI_MANAGED_LOGSTRING_I    ((ITC_PC_LMAPI_MANAGED_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Used for logging by the Intermec License Utility PC application
//
#define ITC_LICENSE_UTILITY_FACILITY 1088
#define ITC_LICENSE_UTILITY_LOGSTRING_E    ((ITC_LICENSE_UTILITY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_LICENSE_UTILITY_LOGSTRING_W    ((ITC_LICENSE_UTILITY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_LICENSE_UTILITY_LOGSTRING_S    ((ITC_LICENSE_UTILITY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_LICENSE_UTILITY_LOGSTRING_I    ((ITC_LICENSE_UTILITY_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Used for logging by the InstallLicenseCheck PC application 
//
#define ITC_INSTALL_LICENSE_CHECK_FACILITY 1089
#define ITC_INSTALL_LICENSE_CHECK_LOGSTRING_E    ((ITC_INSTALL_LICENSE_CHECK_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_INSTALL_LICENSE_CHECK_LOGSTRING_W    ((ITC_INSTALL_LICENSE_CHECK_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_INSTALL_LICENSE_CHECK_LOGSTRING_S    ((ITC_INSTALL_LICENSE_CHECK_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_INSTALL_LICENSE_CHECK_LOGSTRING_I    ((ITC_INSTALL_LICENSE_CHECK_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
// Used for logging by the SmartSystems License Manager Service (PC) 
//
#define ITC_SS_LICENSE_MANAGER_FACILITY 1090
#define ITC_SS_LICENSE_MANAGER_LOGSTRING_E    ((ITC_SS_LICENSE_MANAGER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_SS_LICENSE_MANAGER_LOGSTRING_W    ((ITC_SS_LICENSE_MANAGER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_SS_LICENSE_MANAGER_LOGSTRING_S    ((ITC_SS_LICENSE_MANAGER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_SS_LICENSE_MANAGER_LOGSTRING_I    ((ITC_SS_LICENSE_MANAGER_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
//
//    Virtual Wedge configlet.
//
#define ITC_VWCONFIG_FACILITY 1095
#define ITC_VWCONFIG_LOGSTRING_E      ((ITC_VWCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_ERROR)
#define ITC_VWCONFIG_LOGSTRING_W      ((ITC_VWCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_WARN)
#define ITC_VWCONFIG_LOGSTRING_S      ((ITC_VWCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_SUCCESS)
#define ITC_VWCONFIG_LOGSTRING_I      ((ITC_VWCONFIG_FACILITY << ITC_FACILITY_BITPOS) | ITC_SEVERITYVALUE_INFO)
#endif
////////////////////////////////////////////////////////////////////////
// END OF FILE:  MasterMsgSys.mch
//  COPYRIGHT (c) 1998 - 2004 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////
//
//  FILE NAME:  BufferService.mch
//
//  AUTHOR:	 J. Hunt
// COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  BufferService.mch
//  COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  CommPortWedgeDh.mch
//
//  AUTHOR:     
//
// COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  CommPortWedgeDh.mch
//  COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////;////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  devicelib.mch
//
//  AUTHOR:     
//
//  COPYRIGHT (c) 2002 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  InternalHostDecode.mch
//  COPYRIGHT (c) 2002 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
/*///////////////////////////////////////////////////////////////////
//
//  FILE NAME:  IADCDevice.mch
//
//  AUTHOR:
//
// $Log:   S:/raptor/archive/INTERMEC/IADCDevice/common/vcs/IADCDevice.mch.archive  $
//
//   Rev 1.3   17 Sep 1998 16:43:04   JHunt
//Put block style comments in the file headers
//
//   Rev 1.2   04 Sep 1998 15:52:54   JHunt
//Changed facility number to 309
//
//   Rev 1.1   04 Sep 1998 15:50:56   JHunt
//Changed facility number to 308
//
//   Rev 1.0   04 Sep 1998 14:07:08   JHunt
//Initial revision.
// COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
*////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  IADCDevice.mch
//  COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCComServer.mch
//
//  AUTHOR:
//
// $log$
// COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCComServer.mch
//  COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCConfigRouter.mch
//
//  AUTHOR:  Paul D. Shoeman
//
// COPYRIGHT (c) 2003 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCConfigRouter.mch
//  COPYRIGHT (c) 2003 INTERMEC TECHNOLOGIES CORPORATION, 
//                ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCDataServer.mch
//
//  AUTHOR:     C. Ho
// COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCDataServer.mch
//  COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////;////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCEventLog.mch
//
//  AUTHOR:     J. Hunt
//
// COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCEventLog.mch
//  COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////;////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCIPCPipe.mch
//
//  AUTHOR:
//
// COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCIPCPipe.mch
//  COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCUtilities.mch
//
//  AUTHOR:     J. Hunt
//
// $log$
// COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCUtilities.mch
//  COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCVirtualWedge.mch
//
//  AUTHOR:
//
//
//   Rev 1.0   21 Sep 1998 11:03:30   BReed
//Initial checkin
// COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCVirtualWedge.mch
//  COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ReaderCommandSnmpGateway.mch
//
//  AUTHOR:  Randy Sales
//
// COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  ReaderCommandSnmpGateway.mch
//  COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, 
//                ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  S9CDeviceHandler.mch
//
//  AUTHOR:     
//
// COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  S9CDeviceHandler.mch
//  COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////;////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  S9CProtocolHandler.mch
//
//  AUTHOR:     
//
// COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
// END OF FILE:  S9CProtocolHandler.mch
//  COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////;////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  BufferServices.mcs
//
//  AUTHOR:	 J. Hunt
//
// COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_BUFFERSERVICES_MCS
#define INCLUDED_BUFFERSERVICES_MCS
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//
//  Values are 32 bit values layed out as follows:
//
//   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
//   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
//  +---+-+-+-----------------------+-------------------------------+
//  |Sev|C|R|     Facility          |               Code            |
//  +---+-+-+-----------------------+-------------------------------+
//
//  where
//
//      Sev - is the severity code
//
//          00 - Success
//          01 - Informational
//          10 - Warning
//          11 - Error
//
//      C - is the Customer code flag
//
//      R - is a reserved bit
//
//      Facility - is the facility code
//
//      Code - is the facility's status code
//
//
// Define the facility codes
//
#define ITC_S9C_ISCP_PH_FACILITY         0x156
#define ITC_S9C_DH_FACILITY              0x14C
#define ITC_RCSG_FACILITY                0x147
#define ITC_MSGRESOURCE_FACILITY         0x12C
#define ITC_ITCVIRTUALWEDGE_FACILITY     0x102
#define ITC_UTILITIES_FACILITY           0x12E
#define ITC_IPC_PIPE_FACILITY            0x136
#define ITCCONFIGROUTER_FACILITY         0x154
#define ITC_COMSERVER_FACILITY           0x12F
#define ITC_IADCDEVICE_FACILITY          0x135
#define ITC_EVTLOG_FACILITY              0x103
#define ITC_DEVICELIB_FACILITY           0x162
#define DATASERVER_FACILITY              0x104
#define ITC_WEDGE_DH_FACILITY            0x164
#define ITC_BUFFER_SERVICES_FACILITY     0x132


//
// Define the severity codes
//
#define ITC_WARNING_SEVERITY             0x2
#define ITC_SUCCESS_SEVERITY             0x0
#define ITC_INFORMATIONAL_SEVERITY       0x1
#define ITC_ERROR_SEVERITY               0x3


//
// MessageId: ITC_IBS_CONSTUCTOR_I
//
// MessageText:
//
//  IITCBufferService Object constructor. pUnknownOuter = %1!08X!
//
#define ITC_IBS_CONSTUCTOR_I             0x41320000L

//
// MessageId: ITC_IBS_DESTRUCTOR_I
//
// MessageText:
//
//  IITCBufferService Object destructor
//
#define ITC_IBS_DESTRUCTOR_I             0x41320001L

//
// MessageId: ITC_IBS_CREATEINSTANCE_I
//
// MessageText:
//
//  CBufferService::CreateInstance
//
#define ITC_IBS_CREATEINSTANCE_I         0x41320002L

//
// MessageId: ITC_IBS_NONDELEGATINGQUERYINTERFACE_I
//
// MessageText:
//
//  CBufferService::NondelegatingQueryInterface
//
#define ITC_IBS_NONDELEGATINGQUERYINTERFACE_I 0x41320003L

//
// MessageId: ITC_IBS_COPY_TO_SHARED_I
//
// MessageText:
//
//  CPoolMap::CopyToShared - Buffer Handle %1!08X!
//
#define ITC_IBS_COPY_TO_SHARED_I         0x41320004L

//
// MessageId: ITC_IBS_COPY_TO_LOCAL_I
//
// MessageText:
//
//  CPoolMap::CopyToLocal - Buffer Handle %1!08X!
//
#define ITC_IBS_COPY_TO_LOCAL_I          0x41320005L

//
// MessageId: ITC_IBS_QUERY_DATA_I
//
// MessageText:
//
//  CPoolMap::QueryData - Buffer Handle %1!08X!
//
#define ITC_IBS_QUERY_DATA_I             0x41320006L

//
// MessageId: ITC_IBS_RELEASE_BUFFER_I
//
// MessageText:
//
//  CPoolMap::ReleaseBuffer - hBuffer: %1!08X!; RefCnt (after release): %2!d!
//
#define ITC_IBS_RELEASE_BUFFER_I         0x41320007L

//
// MessageId: ITC_IBS_ADDREF_BUFFER_I
//
// MessageText:
//
//  CPoolMap::AddRefBuffer - hBuffer %1!08X!; RefCnt (after AddRef): %2!d!
//
#define ITC_IBS_ADDREF_BUFFER_I          0x41320008L

//
// MessageId: ITC_IBS_ALLOC_BUFFS_I
//
// MessageText:
//
//  CPoolMap::AllocateBuffer - Buffs avail before %1!d!; Buffs needed: %2!d!
//
#define ITC_IBS_ALLOC_BUFFS_I            0x41320009L

//
// MessageId: ITC_IBS_REL_BUFFS_I
//
// MessageText:
//
//  CPoolMap::ReleaseBuffer - Buffs before %1!d!; Buffs after: %2!d!
//
#define ITC_IBS_REL_BUFFS_I              0x4132000AL

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Success
//Facility=BufferService
//SymbolicName=ITC_<facility acronym>_<msg name>_S 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Warning
//Facility=BufferService
//SymbolicName=ITC_<facility acronym>_<message acronym>_W 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_IBS_ALREADY_INIT_E
//
// MessageText:
//
//  Buffer Services has already been initialized.
//
#define ITC_IBS_ALREADY_INIT_E           0xC1320000L

//
// MessageId: ITC_IBS_CREATEPOOL_SERVICE_NOT_INITIALIZED_E
//
// MessageText:
//
//  CBufferService::CreatePool - The Buffer Service has not been initialized.
//
#define ITC_IBS_CREATEPOOL_SERVICE_NOT_INITIALIZED_E 0xC1320001L

//
// MessageId: ITC_IBS_POOL_INIT_MUTEX_E
//
// MessageText:
//
//  CPoolMap::Initialize - CreateMutex error: %1!08X!, ServiceID/PoolID: %2!08X!
//
#define ITC_IBS_POOL_INIT_MUTEX_E        0xC1320002L

//
// MessageId: ITC_IBS_NOPOOLS_REMAINING_E
//
// MessageText:
//
//  CBufferService::CreatePool - No buffer pools remaining to be created. ServiceID: %1!d!
//
#define ITC_IBS_NOPOOLS_REMAINING_E      0xC1320003L

//
// MessageId: ITC_IBS_POOL_ALREADY_CREATED_E
//
// MessageText:
//
//  CreatePool - Buffer pool already created. m_hPoolMap: %1!d!
//
#define ITC_IBS_POOL_ALREADY_CREATED_E   0xC1320004L

//
// MessageId: ITC_IBS_POOL_NOT_CREATED_E
//
// MessageText:
//
//  The requested buffer pool not created.  ServiceID/PoolID: %1!08X!
//
#define ITC_IBS_POOL_NOT_CREATED_E       0xC1320005L

//
// MessageId: ITC_IBS_INVALID_HPOOL_E
//
// MessageText:
//
//  CBufferService::MapBufferPool - Invalid Pool Handle. ServiceID: %1!04X!  hPool: %2!08X!
//
#define ITC_IBS_INVALID_HPOOL_E          0xC1320006L

//
// MessageId: ITC_IBS_INVALID_BUFFERINDEX_E
//
// MessageText:
//
//  CPool::GetBuffer - Invalid Buffer Index. nBuffers: %1!d!, wBufferIndex: %2!d!
//
#define ITC_IBS_INVALID_BUFFERINDEX_E    0xC1320007L

//
// MessageId: ITC_IBS_NOTENOUGH_BUFFERS_E
//
// MessageText:
//
//  CPoolMap::AllocateBuffer - Not enough buffers. hPool: %1!08X!, nBuffers: %2!d!
//
#define ITC_IBS_NOTENOUGH_BUFFERS_E      0xC1320008L

//
// MessageId: ITC_IBS_BUFFER_ALREADY_ALLOCATED_E
//
// MessageText:
//
//  CPoolMap::AllocateBuffer - Retrieved Buffer already allocated. hPool: %1!08X!, Buffer Index: %2!d!
//
#define ITC_IBS_BUFFER_ALREADY_ALLOCATED_E 0xC1320009L

//
// MessageId: ITC_IBS_INVALID_BUFFERHANDLE_E
//
// MessageText:
//
//  CPoolMap::AssertBufferHandleValid - Invalid Buffer Handle. hPool: %1!08X!, hBuffer: %2!08X!
//
#define ITC_IBS_INVALID_BUFFERHANDLE_E   0xC132000AL

//
// MessageId: ITC_IBS_SHARED_TOOSMALL_E
//
// MessageText:
//
//  CPoolMap::CopyToShared - Shared Buffer too small. Requested: %1!08X!, Available: %2!08X!
//
#define ITC_IBS_SHARED_TOOSMALL_E        0xC132000BL

//
// MessageId: ITC_IBS_COPYTO_SWERROR_E
//
// MessageText:
//
//  CPoolMap::CopyToShared - SW Error: Not all data copied. Remaining: %2!08X!
//
#define ITC_IBS_COPYTO_SWERROR_E         0xC132000CL

//
// MessageId: ITC_IBS_LOCAL_TOOSMALL_E
//
// MessageText:
//
//  CPoolMap::CopyToShared -  Local Buffer too small. Requested: %1!08X!, Available: %2!08X!
//
#define ITC_IBS_LOCAL_TOOSMALL_E         0xC132000DL

//
// MessageId: ITC_IBS_COPYFROM_SWERROR_E
//
// MessageText:
//
//  CPoolMap::CopyToLocal - SW Error: Not all data copied. Remaining: %2!08X!
//
#define ITC_IBS_COPYFROM_SWERROR_E       0xC132000EL

//
// MessageId: ITC_IBS_BUFFER_NOTALLOCATED_E
//
// MessageText:
//
//  CPoolMap::QueryData - Buffer not allocated: hBuffer %1!08X!
//
#define ITC_IBS_BUFFER_NOTALLOCATED_E    0xC132000FL

//
// MessageId: ITC_IBS_AVAIL_Q_FULL_E
//
// MessageText:
//
//  CPoolMap::ReleaseBuffer - SW Error.  The available queue has filled. 
//
#define ITC_IBS_AVAIL_Q_FULL_E           0xC1320010L

//
// MessageId: ITC_IBS_POOL_NOT_MAPPED_E
//
// MessageText:
//
//  CPoolMap::Handle - Pool not mapped.
//
#define ITC_IBS_POOL_NOT_MAPPED_E        0xC1320011L

//
// MessageId: ITC_IBS_IMPORTCORRUPT_BUFFER_E
//
// MessageText:
//
//  CBuffer::Import - Corrupt Buffer. hBuffer: %1!08X!
//
#define ITC_IBS_IMPORTCORRUPT_BUFFER_E   0xC1320012L

//
// MessageId: ITC_IBS_EXPORTCORRUPT_BUFFER_E
//
// MessageText:
//
//  CBuffer::Export - Corrupt Buffer. hBuffer: %1!08X!
//
#define ITC_IBS_EXPORTCORRUPT_BUFFER_E   0xC1320013L

//
// MessageId: ITC_IBS_BUFFER_EXIM_NOTALLOCATED_E
//
// MessageText:
//
//  CBuffer::Export/Import/AddRef/Release - Buffer not Allocated. hBuffer: %1!08X!
//
#define ITC_IBS_BUFFER_EXIM_NOTALLOCATED_E 0xC1320014L

//
// MessageId: ITC_IBS_OUT_OF_MEMORY_E
//
// MessageText:
//
//  System out of memory.  "new" failed to create CBufferService object.
//
#define ITC_IBS_OUT_OF_MEMORY_E          0xC1320015L

//
// MessageId: ITC_IBS_MINTHRESH_EVENT_NOTEXIST_E
//
// MessageText:
//
//  CreatePool() - Minimum threshold event does not already exist.
//
#define ITC_IBS_MINTHRESH_EVENT_NOTEXIST_E 0xC1320016L

//
// MessageId: ITC_IBS_CREATE_EVENT_E
//
// MessageText:
//
//  CPoolMap::OpenEvent - CreateEvent Error: %1!08X!
//
#define ITC_IBS_CREATE_EVENT_E           0xC1320017L

//
// MessageId: ITC_IBS_MINTHRESH_EVENTNAME_E
//
// MessageText:
//
//  CPool::SetBufferThreshold - Eventname too long. Max chars:  %1!d!; Event name chars: %2!d!
//
#define ITC_IBS_MINTHRESH_EVENTNAME_E    0xC1320018L

//
// MessageId: ITC_IBS_MINTHRESH_EVENTALREADY_OPENED_E
//
// MessageText:
//
//  CPoolMap::SetBufferThreshold - The minimum threshold event has already been opened.
//
#define ITC_IBS_MINTHRESH_EVENTALREADY_OPENED_E 0xC1320019L

//
// MessageId: ITC_IBS_EVENT_ARRAY_FULL_E
//
// MessageText:
//
//  CPoolMap::AllocateBuffer - Unable to wait for buffer available: wait array is full.
//
#define ITC_IBS_EVENT_ARRAY_FULL_E       0xC132001AL

//
// MessageId: ITC_IBS_DATAVAILABLE_TIMEOUT_E
//
// MessageText:
//
//  CPoolMap::AllocateBuffer - Timed out waiting %1!d! msec for data available 
//
#define ITC_IBS_DATAVAILABLE_TIMEOUT_E   0xC132001BL

//
// MessageId: ITC_IBS_EVENTWAIT_INIT_CREATE_EVENT_ERROR_E
//
// MessageText:
//
//  CAllocateWaitEvent::Initialize - CreateEvent Error: %1!08X!
//
#define ITC_IBS_EVENTWAIT_INIT_CREATE_EVENT_ERROR_E 0xC132001CL

//
// MessageId: ITC_IBS_EVENTWAIT_EVENT_NOT_UNIQUE_E
//
// MessageText:
//
//  CAllocateWaitEvent::Initialize - The event created was not unique.
//
#define ITC_IBS_EVENTWAIT_EVENT_NOT_UNIQUE_E 0xC132001DL

//
// MessageId: ITC_IBS_EVENTWAIT_EVENT_DOESNOT_EXIST_E
//
// MessageText:
//
//  CAllocateWaitEvent::SignalDataAvailable - The event did not already exist.
//
#define ITC_IBS_EVENTWAIT_EVENT_DOESNOT_EXIST_E 0xC132001EL

//
// MessageId: ITC_IBS_EVENTWAIT_SIGNAL_CREATE_EVENT_ERROR_E
//
// MessageText:
//
//  CAllocateWaitEvent::SignalDataAvailable - CreateEvent Error: %1!08X!
//
#define ITC_IBS_EVENTWAIT_SIGNAL_CREATE_EVENT_ERROR_E 0xC132001FL

#endif  // THIS LINE MUST BE AFTER ANY MESSAGE DEFINITIONS.
////////////////////////////////////////////////////////////////////
// END OF FILE:  BufferServices.mcs
//  COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  CommPortWedgeDh.mcs
//
//  AUTHOR:     
//
// COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_COMMPORTWEDGEDH_MSG
#define INCLUDED_COMMPORTWEDGEDH_MSG
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_WEDGEDH_INITENTRY_I
//
// MessageText:
//
//  CWedgeDh::Initialize Entry
//
#define ITC_WEDGEDH_INITENTRY_I          0x41640000L

//
// MessageId: ITC_WEDGEDH_READENTRY_I
//
// MessageText:
//
//  CWedgeDh::Read Entry
//
#define ITC_WEDGEDH_READENTRY_I          0x41640001L

//
// MessageId: ITC_WEDGEDH_INITEXIT_I
//
// MessageText:
//
//  CWedgeDh::Initialize Exit. Status: 0x%1!08X!
//
#define ITC_WEDGEDH_INITEXIT_I           0x41640002L

//
// MessageId: ITC_WEDGEDH_READEXIT_I
//
// MessageText:
//
//  CWedgeDh::Read Exit. Status: %1!08X!
//
#define ITC_WEDGEDH_READEXIT_I           0x41640003L

//
// MessageId: ITC_WEDGEDH_OPENENTRY_I
//
// MessageText:
//
//  CWedgeDh::Open Entry *pwClientHandle: 0x%1!08X!
//
#define ITC_WEDGEDH_OPENENTRY_I          0x41640004L

//
// MessageId: ITC_WEDGEDH_OPENEXIT_I
//
// MessageText:
//
//  CWedgeDh::Open Exit *pwClientHandle: 0x%1!08X!
//
#define ITC_WEDGEDH_OPENEXIT_I           0x41640005L

//
// MessageId: ITC_WEDGEDH_CLOSEENTRYEXIT_I
//
// MessageText:
//
//  CWedgeDh::Close Entry/Exit. bClientHandle: %1!d!
//
#define ITC_WEDGEDH_CLOSEENTRYEXIT_I     0x41640006L

//
// MessageId: ITC_WEDGEDH_READDCENTRYEXIT_I
//
// MessageText:
//
//  CWedgeDh::ReadDataClass Entry/Exit
//
#define ITC_WEDGEDH_READDCENTRYEXIT_I    0x41640007L

//
// MessageId: ITC_WEDGEDH_CANCELREQUEST_ENTRYEXIT_I
//
// MessageText:
//
//  CWedgeDh::CancelRequest Entry/Exit. bClientHandle: %1!d!
//
#define ITC_WEDGEDH_CANCELREQUEST_ENTRYEXIT_I 0x41640008L

//
// MessageId: ITC_WEDGEDH_WRITEENTRY_I
//
// MessageText:
//
//  CWedgeDh::Write Entry.  Bytes to write: %1!d!; Cmd: %2!d! 
//
#define ITC_WEDGEDH_WRITEENTRY_I         0x41640009L

//
// MessageId: ITC_WEDGEDH_WRITEEXIT_I
//
// MessageText:
//
//  CWedgeDh::Write Exit. hrStatus: 0x0x%1!08X!; Bytes returned: %2!d!
//
#define ITC_WEDGEDH_WRITEEXIT_I          0x4164000AL

//
// MessageId: ITC_WEDGEDH_READLABEL_ENTRY_I
//
// MessageText:
//
//  CWedgeDh::ReadLabel Entry:  0x%1!08X!,  0x%2!08X!
//
#define ITC_WEDGEDH_READLABEL_ENTRY_I    0x4164000BL

//
// MessageId: ITC_WEDGEDH_READLABEL_EXIT_I
//
// MessageText:
//
//  CWedgeDh::ReadLabel Exit:  0x%1!08X!,  0x%2!08X!
//
#define ITC_WEDGEDH_READLABEL_EXIT_I     0x4164000CL

//
// MessageId: ITC_WEDGEDH_WRITEPACKET_I
//
// MessageText:
//
//  CProtocol::WritePacket: #bytes actually written: %1!d!, #bytes requested to write: %2!d!
//
#define ITC_WEDGEDH_WRITEPACKET_I        0x4164000DL

//
// MessageId: ITC_WEDGEDH_WRITEFILE_BYTES_I
//
// MessageText:
//
//  CProtocol::WritePacket data: 0x%1!08x! 0x%2!08x!
//
#define ITC_WEDGEDH_WRITEFILE_BYTES_I    0x4164000EL

//
// MessageId: ITC_WEDGEDH_READPACKET_I
//
// MessageText:
//
//  CProtocol::ReadPacket: #bytes actually read: %1!d!,  #bytes requested to read: %2!d!
//
#define ITC_WEDGEDH_READPACKET_I         0x4164000FL

//
// MessageId: ITC_WEDGEDH_READPACKET_BYTES_I
//
// MessageText:
//
//  CProtocol::ReadPacket data: 0x%1!08x! 0x%2!08x!
//
#define ITC_WEDGEDH_READPACKET_BYTES_I   0x41640010L

//
// MessageId: ITC_WEDGEDH_READLABEL_AFTER_ENTERCRITICALSECTION_I
//
// MessageText:
//
//  CWedgeDh::ReadLabel After EnterCriticalSection :  #%1!d!  
//
#define ITC_WEDGEDH_READLABEL_AFTER_ENTERCRITICALSECTION_I 0x41640011L

//
// MessageId: ITC_WEDGEDH_READLABEL_AFTER_LEAVECRITICALSECTION_I
//
// MessageText:
//
//  CWedgeDh::ReadLabel After LeaveCriticalSection :  #%1!d!  
//
#define ITC_WEDGEDH_READLABEL_AFTER_LEAVECRITICALSECTION_I 0x41640012L

//
// MessageId: ITC_WEDGEDH_SETREADTIMEOUT_I
//
// MessageText:
//
//  CS9CProtocol::SetReadTimeout =  %1!d! msec
//
#define ITC_WEDGEDH_SETREADTIMEOUT_I     0x41640013L

//
// MessageId: ITC_WEDGEDH_DEVICEENABLED_ENTRY_I
//
// MessageText:
//
//  CWedgeDh::DeviceEnabled, *fpEnabled:  %1!d!
//
#define ITC_WEDGEDH_DEVICEENABLED_ENTRY_I 0x41640014L

//
// MessageId: ITC_WEDGEDH_DEVICEENABLED_EXIT_I
//
// MessageText:
//
//  CWedgeDh::DeviceEnabled Exit, hrStatus:  0x%1!08x!
//
#define ITC_WEDGEDH_DEVICEENABLED_EXIT_I 0x41640015L

//
// MessageId: ITC_WEDGEDH_SETATTRIBUTE_EXIT_I
//
// MessageText:
//
//  CWedgeDh::SetAttribute Exit, hrStatus:  0x%1!08x!
//
#define ITC_WEDGEDH_SETATTRIBUTE_EXIT_I  0x41640016L

//
// MessageId: ITC_WEDGEDH_SETATTRIBUTE_ENTRY_I
//
// MessageText:
//
//  CWedgeDh::DeviceEnabled, eAttribID:  %1!d!
//
#define ITC_WEDGEDH_SETATTRIBUTE_ENTRY_I 0x41640017L

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_DISABLE_EXIT_I
//
// MessageText:
//
//  CS9CProtocol::Enable Exit. hrStatus:  0x%1!08x!
//
#define ITC_WEDGEDH_CS9CPROTOCOL_DISABLE_EXIT_I 0x41640018L

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_DISABLE_ENTRY_I
//
// MessageText:
//
//  CS9CProtocol::Enable Entry.
//
#define ITC_WEDGEDH_CS9CPROTOCOL_DISABLE_ENTRY_I 0x41640019L

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_OPENCOMMPORT_EXIT_I
//
// MessageText:
//
//  CS9CProtocol::OpenCommPort Exit. hrStatus:  0x%1!08x!
//
#define ITC_WEDGEDH_CS9CPROTOCOL_OPENCOMMPORT_EXIT_I 0x4164001AL

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_OPENCOMMPORT_ENTRY_I
//
// MessageText:
//
//  CS9CProtocol::OpenCommPort Entry.
//
#define ITC_WEDGEDH_CS9CPROTOCOL_OPENCOMMPORT_ENTRY_I 0x4164001BL

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_ENABLE_EXIT_I
//
// MessageText:
//
//  CS9CProtocol::Enable Exit. hrStatus:  0x%1!08x!
//
#define ITC_WEDGEDH_CS9CPROTOCOL_ENABLE_EXIT_I 0x4164001CL

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_ENABLE_ENTRY_I
//
// MessageText:
//
//  CS9CProtocol::Enable Entry.
//
#define ITC_WEDGEDH_CS9CPROTOCOL_ENABLE_ENTRY_I 0x4164001DL

//
// MessageId: ITC_WEDGEDH_AIMID_NOT_XMIT_I
//
// MessageText:
//
//  CWedgeDh::: SetSymbology - S9C did not transmitted AIM Id. First byte: %1!d!;  %2!d!
//
#define ITC_WEDGEDH_AIMID_NOT_XMIT_I     0x4164001EL

//
// MessageId: ITC_WEDGEDH_READTIMEOUT_I
//
// MessageText:
//
//  CS9CProtocol::Read Timeout error. Timeout = %1!d! msec
//
#define ITC_WEDGEDH_READTIMEOUT_I        0x4164001FL

//
// MessageId: ITC_WEDGEDH_FILTERREADDATA_ENTRY_I
//
// MessageText:
//
//  CWedgeDh::FilterReadData Entry. %1!d! total bytes in, %2!d! data bytes.
//
#define ITC_WEDGEDH_FILTERREADDATA_ENTRY_I 0x41640020L

//
// MessageId: ITC_WEDGEDH_FILTERREADDATA_EXIT_I
//
// MessageText:
//
//  CWedgeDh::FilterReadData Exit. Status: 0x%1!08x!, %2!d! total bytes out.
//
#define ITC_WEDGEDH_FILTERREADDATA_EXIT_I 0x41640021L

//
// MessageId: ITC_WEDGEDH_READ_FILTERREJECT_I
//
// MessageText:
//
//  CWedgeDh::Read Data rejected by filter
//
#define ITC_WEDGEDH_READ_FILTERREJECT_I  0x41640022L

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_RELEASE_ENTRY_I
//
// MessageText:
//
//  CS9CProtocol::ReleaseResource Entry: 0x%1!08x!
//
#define ITC_WEDGEDH_CS9CPROTOCOL_RELEASE_ENTRY_I 0x41640023L

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_RELEASE_EXIT_I
//
// MessageText:
//
//  CS9CProtocol::ReleaseResource Exit: 0x%1!08x!
//
#define ITC_WEDGEDH_CS9CPROTOCOL_RELEASE_EXIT_I 0x41640024L

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_WEDGEDH_RDR_CMD_INIT_S
//
// MessageText:
//
//  CWedgeDh::Initialize: Succeeded initializing the RCSG, 0x%1!08x! 0x%2!08x!
//
#define ITC_WEDGEDH_RDR_CMD_INIT_S       0x01640000L

//
// MessageId: ITC_WEDGEDH_HANDLEDOWNLOADCMD_DOWNLOAD_S
//
// MessageText:
//
//  CWedgeDh::HandleDownLoadCmd: Firmware Upgrade Function is complete with successfull status.
//
#define ITC_WEDGEDH_HANDLEDOWNLOADCMD_DOWNLOAD_S 0x01640001L

//
// MessageId: ITC_WEDGEDH_HANDLEDOWNLOADCMD_LOADLIBRARY_S
//
// MessageText:
//
//  CWedgeDh::HandleDownLoadCmd: LoadLibray S9CUpgrade.dll returned a successfull Status, 0x%1!08x! 
//
#define ITC_WEDGEDH_HANDLEDOWNLOADCMD_LOADLIBRARY_S 0x01640002L

//
// MessageId: ITC_WEDGEDH_HANDLEDOWNLOADCMD_GETPROCADDRESS_S
//
// MessageText:
//
//  CWedgeDh::HandleDownLoadCmd: GetProAddress of Firmware Upgrade Function is successfull. Firmware upgrade is in progress. Please wait...
//
#define ITC_WEDGEDH_HANDLEDOWNLOADCMD_GETPROCADDRESS_S 0x01640003L

//
// MessageId: ITC_WEDGEDH_HANDLEDOWNLOADCMD_FREELIBRARY_S
//
// MessageText:
//
//  CWedgeDh::HandleDownLoadCmd: FreeLibray of S9CUpgrade.dll returned a successfull status, 0x%1!08x! 
//
#define ITC_WEDGEDH_HANDLEDOWNLOADCMD_FREELIBRARY_S 0x01640004L

//
// MessageId: ITC_WEDGEDH_GETVERSIONINFO_SENT_VOLUMEOFF_CMD_S
//
// MessageText:
//
//  CWedgeDh::GetVersionInfo: Sent S9C Volume Off Cmd successfull, 0x%1!08x! 
//
#define ITC_WEDGEDH_GETVERSIONINFO_SENT_VOLUMEOFF_CMD_S 0x01640005L

//
// MessageId: ITC_WEDGEDH_GETVERSIONINFO_SENT_GETVERSIONINFO_CMD_S
//
// MessageText:
//
//  CWedgeDh::GetVersionInfo: Sent S9C Get Version Info Cmd successfull, 0x%1!08x! 
//
#define ITC_WEDGEDH_GETVERSIONINFO_SENT_GETVERSIONINFO_CMD_S 0x01640006L

//
// MessageId: ITC_WEDGEDH_GETVERSIONINFO_READPACKETET_RETURNED_S
//
// MessageText:
//
//  CWedgeDh::GetVersionInfo: ReadPacket returned with dwBytesReturned = %1!d! bytes 
//
#define ITC_WEDGEDH_GETVERSIONINFO_READPACKETET_RETURNED_S 0x01640007L

////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_WEDGEDH_SETFILTER_COCI_W
//
// MessageText:
//
//  CWedgeDh::SetFilter CoCI Failed 0x%1!08x!
//
#define ITC_WEDGEDH_SETFILTER_COCI_W     0x81640008L

//
// MessageId: ITC_WEDGEDH_SETFILTER_COMPILE_W
//
// MessageText:
//
//  CWedgeDh::SetFilter Compile Failed 0x%1!08x!
//
#define ITC_WEDGEDH_SETFILTER_COMPILE_W  0x81640009L

//
// MessageId: ITC_WEDGEDH_NO_PREDEFINED_GET_ALL_ISCP_CMD_W
//
// MessageText:
//
//  WEDGEDH - CheckForAll. No Predefined GET ALL for Gid: 0x%1!08x!
//
#define ITC_WEDGEDH_NO_PREDEFINED_GET_ALL_ISCP_CMD_W 0x8164000AL

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_WEDGEDH_READ_INVDATADETAILS_E
//
// MessageText:
//
//  CWedgeDh::Read Invalid Data Details structure size. Required size: %1!d!; pass in size:  %2!d!
//
#define ITC_WEDGEDH_READ_INVDATADETAILS_E 0xC1640000L

//
// MessageId: ITC_WEDGEDH_CREATEFILE_E
//
// MessageText:
//
//  S9CProtocol::InitCommPort CreateFile Error: 0x%1!08X!
//
#define ITC_WEDGEDH_CREATEFILE_E         0xC1640001L

//
// MessageId: ITC_WEDGEDH_SETCOMMSTATE_E
//
// MessageText:
//
//  S9CProtocol::InitCommPort SetCommState Error: 0x%1!08X!
//
#define ITC_WEDGEDH_SETCOMMSTATE_E       0xC1640002L

//
// MessageId: ITC_WEDGEDH_SETTIMOUT_E
//
// MessageText:
//
//  S9CProtocol::InitCommPort SetCommState Error: 0x%1!08X!
//
#define ITC_WEDGEDH_SETTIMOUT_E          0xC1640003L

//
// MessageId: ITC_WEDGEDH_SETREAD_SETTIMOUT_E
//
// MessageText:
//
//  S9CProtocol::SetReadTimeout SetCommState Error: 0x%1!08X!
//
#define ITC_WEDGEDH_SETREAD_SETTIMOUT_E  0xC1640004L

//
// MessageId: ITC_WEDGEDH_SETREAD_GETCOMMTIMEOUT_E
//
// MessageText:
//
//  S9CProtocol::SetReadTimeout GetCommTimeout Error: 0x%1!08X!
//
#define ITC_WEDGEDH_SETREAD_GETCOMMTIMEOUT_E 0xC1640005L

//
// MessageId: ITC_WEDGEDH_READFILE_E
//
// MessageText:
//
//  S9CProtocol::ReadPacket ReadFile Error: 0x%1!08X!
//
#define ITC_WEDGEDH_READFILE_E           0xC1640006L

//
// MessageId: ITC_WEDGEDH_WRITEFILE_E
//
// MessageText:
//
//  S9CProtocol::WritePacket WriteFile Error: 0x%1!08X!
//
#define ITC_WEDGEDH_WRITEFILE_E          0xC1640007L

//
// MessageId: ITC_WEDGEDH_CREATETHREAD_E
//
// MessageText:
//
//  S9CProtocol::Initialize CreateThread Error: 0x%1!08X!
//
#define ITC_WEDGEDH_CREATETHREAD_E       0xC1640008L

//
// MessageId: ITC_WEDGEDH_GRID_RTNDATA_E
//
// MessageText:
//
//  CWedgeDh::MatchGrid Response data integrity error. Expected: %1!d!; Actual: %2!d!
//
#define ITC_WEDGEDH_GRID_RTNDATA_E       0xC1640009L

//
// MessageId: ITC_WEDGEDH_GRID_GRIDSIZE_E
//
// MessageText:
//
//  CWedgeDh::MatchGrid Response data integrity error. Expected: %1!d!; Actual: %2!d!
//
#define ITC_WEDGEDH_GRID_GRIDSIZE_E      0xC164000AL

//
// MessageId: ITC_WEDGEDH_BUFFER_TOOSMALL_E
//
// MessageText:
//
//  CS9CProtocol::ReadPacket Buffer of size %1!d! bytes is too small to hold data.
//
#define ITC_WEDGEDH_BUFFER_TOOSMALL_E    0xC164000BL

//
// MessageId: ITC_WEDGEDH_SYSIO_CREATEFILE_E
//
// MessageText:
//
//  CSysIO::CSysIO CreateFile error: 0x%1!08X!
//
#define ITC_WEDGEDH_SYSIO_CREATEFILE_E   0xC164000CL

//
// MessageId: ITC_WEDGEDH_SYSIO_SCANFLASH_IOCTL_E
//
// MessageText:
//
//  CSysIO::SetScanFlashEnable DeviceIoControl error: 0x%1!08X!
//
#define ITC_WEDGEDH_SYSIO_SCANFLASH_IOCTL_E 0xC164000DL

//
// MessageId: ITC_WEDGEDH_INDEX_OUTOFRANGE_E
//
// MessageText:
//
//  CWedgeDh::SetSymbology Index mapping out of range error. Calculated Index: %1!d! %2!d!
//
#define ITC_WEDGEDH_INDEX_OUTOFRANGE_E   0xC164000EL

//
// MessageId: ITC_WEDGEDH_INV_WRITEMSG_E
//
// MessageText:
//
//  CWedgeDh::Write Invalid Message Type. m_eCommand: %1!d! 
//
#define ITC_WEDGEDH_INV_WRITEMSG_E       0xC164000FL

//
// MessageId: ITC_WEDGEDH_S9CDSRERROR_E
//
// MessageText:
//
//  CWedgeDh::PowerDownS9C S9C failed to deassert DSR in %1!d! milliseconds.
//
#define ITC_WEDGEDH_S9CDSRERROR_E        0xC1640010L

//
// MessageId: ITC_WEDGEDH_SYSIO_SCANPOWER_IOCTL_E
//
// MessageText:
//
//  CWedgeDh::SetScanPower DeviceIoControl error: 0x%1!08X!
//
#define ITC_WEDGEDH_SYSIO_SCANPOWER_IOCTL_E 0xC1640011L

//
// MessageId: ITC_WEDGEDH_SYSIO_SETSCANLED_IOCTL_E
//
// MessageText:
//
//  CSysIO::SetScanLED DeviceIoControl error: 0x%1!08X!
//
#define ITC_WEDGEDH_SYSIO_SETSCANLED_IOCTL_E 0xC1640012L

//
// MessageId: ITC_WEDGEDH_SYSIO_GETSCANLED_IOCTL_E
//
// MessageText:
//
//  CSysIO::GetScanLED DeviceIoControl error: 0x%1!08X!
//
#define ITC_WEDGEDH_SYSIO_GETSCANLED_IOCTL_E 0xC1640013L

//
// MessageId: ITC_WEDGEDH_CS9CPM_CREATETHREAD_E
//
// MessageText:
//
//  CS9CProtocol::InitCommPort CreateThread error: 0x%1!08X!
//
#define ITC_WEDGEDH_CS9CPM_CREATETHREAD_E 0xC1640014L

//
// MessageId: ITC_WEDGEDH_VALIDATEANDSETCONFIG_INVALIDARG_E
//
// MessageText:
//
//  CWedgeDh::ValidateAndSetConfig invalid command: 0x%1!08X!
//
#define ITC_WEDGEDH_VALIDATEANDSETCONFIG_INVALIDARG_E 0xC1640015L

//
// MessageId: ITC_WEDGEDH_VALIDATEANDSETCONFIG_FAILED_UPDATECONFIG_E
//
// MessageText:
//
//  CWedgeDh::ValidateAndSetConfig error returned from UpdateConfig hr: 0x%1!08X!
//
#define ITC_WEDGEDH_VALIDATEANDSETCONFIG_FAILED_UPDATECONFIG_E 0xC1640016L

//
// MessageId: ITC_WEDGEDH_UPDATECONFIG_REGISTRY_E
//
// MessageText:
//
//  CWedgeDh::UpdateConfig - Registry sub system throw exception with hr: 0x%1!08X!
//
#define ITC_WEDGEDH_UPDATECONFIG_REGISTRY_E 0xC1640017L

//
// MessageId: ITC_WEDGEDH_HANDLESETCONFIG_INVALIDARG_E
//
// MessageText:
//
//  CWedgeDh::HandleSetConfig - Error! Invalid configuration id enum: %1!d!
//
#define ITC_WEDGEDH_HANDLESETCONFIG_INVALIDARG_E 0xC1640018L

//
// MessageId: ITC_WEDGEDH_HANDLEGETCONFIG_INVALIDARG_E
//
// MessageText:
//
//  CWedgeDh::HandleGetConfig - Error! Invalid configuration id enum: %1!d!
//
#define ITC_WEDGEDH_HANDLEGETCONFIG_INVALIDARG_E 0xC1640019L

//
// MessageId: ITC_WEDGEDH_GETCONFIG_BUFFER_TOOSMALL_E
//
// MessageText:
//
//  CWedgeDh::HandleSetConfig - Error! Buffer is too small: dwIndex: %1!d! > allocated: %2!d!
//
#define ITC_WEDGEDH_GETCONFIG_BUFFER_TOOSMALL_E 0xC164001AL

//
// MessageId: ITC_WEDGEDH_GETCONFIG_ENUMVALUE_E
//
// MessageText:
//
//  CWedgeDh::HandleGetConfig - Error returned from EnumValue(), hr: 0x%1!08X!
//
#define ITC_WEDGEDH_GETCONFIG_ENUMVALUE_E 0xC164001BL

//
// MessageId: ITC_WEDGEDH_SETCONFIGCMDBUFFER_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  CWedgeDh::CS9CRequestGetConfig::SetConfigCmdBuffer - Error! Buffer is too small: dataLength: %1!d! > allocated: %2!d!
//
#define ITC_WEDGEDH_SETCONFIGCMDBUFFER_BUFFER_TOO_SMALL_E 0xC164001CL

//
// MessageId: ITC_WEDGEDH_SENDS9CCONFIG_ENUMVALUE_E
//
// MessageText:
//
//  CWedgeDh::SendS9CConfig - Error returned from RegEnumValue! :0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_SENDS9CCONFIG_ENUMVALUE_E 0xC164001DL

//
// MessageId: ITC_WEDGEDH_DOWNLOADCMD_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  CWedgeDh::CS9CDownLoadCmd  - Error! Buffer is too small: nFileNames: %1!d! > allocated: %2!d!
//
#define ITC_WEDGEDH_DOWNLOADCMD_BUFFER_TOO_SMALL_E 0xC164001EL

//
// MessageId: ITC_WEDGEDH_ENUMTOVALUENAME_SUBID_E
//
// MessageText:
//
//  CWedgeDh::EnumToValueName - Error! No matching registry value name for eSubId: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_ENUMTOVALUENAME_SUBID_E 0xC164001FL

//
// MessageId: ITC_WEDGEDH_HANDLEDOWNLOADCMD_GETPROCADDRESS_E
//
// MessageText:
//
//  CWedgeDh::HandleDownLoadCmd - GetProcAddress GetLastError: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_HANDLEDOWNLOADCMD_GETPROCADDRESS_E 0xC1640020L

//
// MessageId: ITC_WEDGEDH_HANDLEDOWNLOADCMD_LOADLIBRARY_E
//
// MessageText:
//
//  CWedgeDh::HandleDownLoadCmd - LoadLibrary GetLastError: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_HANDLEDOWNLOADCMD_LOADLIBRARY_E 0xC1640021L

//
// MessageId: ITC_WEDGEDH_HANDLEDOWNLOADCMD_FREELIBRARY_E
//
// MessageText:
//
//  CWedgeDh::HandleDownLoadCmd - FreeLibrary GetLastError: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_HANDLEDOWNLOADCMD_FREELIBRARY_E 0xC1640022L

//
// MessageId: ITC_WEDGEDH_DOWNLOADCMD_FILENAMES_NULL_E
//
// MessageText:
//
//  CWedgeDh::CS9CDownLoadCmd  - Error! FileNames buffer is NULL: nFileNames: %1!d!, %2!d!
//
#define ITC_WEDGEDH_DOWNLOADCMD_FILENAMES_NULL_E 0xC1640023L

//
// MessageId: ITC_WEDGEDH_HANDLEDOWNLOADCMD_FILENAMES_NULL_E
//
// MessageText:
//
//  CWedgeDh::HandleDownLoadCmd - Some null file names: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_HANDLEDOWNLOADCMD_FILENAMES_NULL_E 0xC1640024L

//
// MessageId: ITC_WEDGEDH_DOWNLOADCMD_BAD_FORMAT_E
//
// MessageText:
//
//  CWedgeDh::CS9CDownLoadCmd - File names string has bad format, no comma delimiters: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_DOWNLOADCMD_BAD_FORMAT_E 0xC1640025L

//
// MessageId: ITC_WEDGEDH_INIT_READERCMD_E
//
// MessageText:
//
//  CWedgeDh::Initialize - Failed to initialize IReaderCommand, hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_INIT_READERCMD_E     0xC1640026L

//
// MessageId: ITC_WEDGEDH_COCI_READERCMD_E
//
// MessageText:
//
//  CWedgeDh::Initialize - Failed to CoCreateInstance IReaderCommand, hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_COCI_READERCMD_E     0xC1640027L

//
// MessageId: ITC_WEDGEDH_NORCSGCLSID_E
//
// MessageText:
//
//  CWedgeDh::Initialize - Failed to CLSIDFromProgID of RCSG, hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_NORCSGCLSID_E        0xC1640028L

//
// MessageId: ITC_WEDGEDH_GETVERSIONINFO_REGISTRY_E
//
// MessageText:
//
//  CWedgeDh::GetVersionInfo - Error Returned From CRegistry, hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_GETVERSIONINFO_REGISTRY_E 0xC1640029L

//
// MessageId: ITC_WEDGEDH_HANDLEDOWNLOADCMD_DOWNLOAD_E
//
// MessageText:
//
//  CWedgeDh::HandleDownLoadCmd - S9CUpgrade Function returned an error: 0x%1!08X!, 0x%2!08X!
//
#define ITC_WEDGEDH_HANDLEDOWNLOADCMD_DOWNLOAD_E 0xC164002AL

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_CREATEFILE_E
//
// MessageText:
//
//  CS9CProtocol::OpenCommPort CreateFile Error: 0x%1!08X!
//
#define ITC_WEDGEDH_CS9CPROTOCOL_CREATEFILE_E 0xC164002BL

//
// MessageId: ITC_WEDGEDH_CS9CPROTOCOL_DISABLE_CLOSE_COMMPORT_E
//
// MessageText:
//
//  CS9CProtocol::Disable CloseHandle Error: 0x%1!08X!
//
#define ITC_WEDGEDH_CS9CPROTOCOL_DISABLE_CLOSE_COMMPORT_E 0xC164002CL

//
// MessageId: ITC_WEDGEDH_QUERYATTRIBUTESIZE_E
//
// MessageText:
//
//  CWedgeDh::QueryAttribute: Error: object size is %1!d!, dwBufferSize is %2!d!. 
//
#define ITC_WEDGEDH_QUERYATTRIBUTESIZE_E 0xC164002DL

//
// MessageId: ITC_WEDGEDH_READSIZE_E
//
// MessageText:
//
//  CWedgeDh::FilterReadData: Error: data size is %1!d!, buffer size is %2!d!. 
//
#define ITC_WEDGEDH_READSIZE_E           0xC164002EL

//
// MessageId: ITC_WEDGEDH_WRITEFILE_TIMEOUT_E
//
// MessageText:
//
//  S9CProtocol::WritePacket WriteFile Timeout Error: Req:%1!d! bytes, Written:%2!d! bytes
//
#define ITC_WEDGEDH_WRITEFILE_TIMEOUT_E  0xC164002FL

//
// MessageId: ITC_WEDGEDH_SETUP_READ_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  CCommContainer::HandleSetupRead - Resp buffer Too Small: Resp size %1!d!, Expected size: %2!d!
//
#define ITC_WEDGEDH_SETUP_READ_BUFFER_TOO_SMALL_E 0xC1640030L

//
// MessageId: ITC_WEDGEDH_READ_RETURNED_ZERO_BYTE_E
//
// MessageText:
//
//  S9CProtocol::Read Error: 0x%1!08X!
//
#define ITC_WEDGEDH_READ_RETURNED_ZERO_BYTE_E 0xC1640031L

//
// MessageId: ITC_WEDGEDH_ESCAPECOMMFUNCTION_E
//
// MessageText:
//
//  S9CProtocol::Enable. EscapeCommFunction error: GetLastError: 0x%1!08X!
//
#define ITC_WEDGEDH_ESCAPECOMMFUNCTION_E 0xC1640032L

#endif
////////////////////////////////////////////////////////////////////
// END OF FILE:  CommPortWedgeDh.mcs
//  COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  devicelib.mcs
//
//  AUTHOR:     
//
//  COPYRIGHT (c) 2002 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_DEVICELIB_MSG
#define INCLUDED_DEVICELIB_MSG
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_DEVICELIB_SETSCANFLASHENABLE_I
//
// MessageText:
//
//  DeviceLib::CSysIO::SetScanFlashEnable Setting S9C Scan Flash enable to %1!d!
//
#define ITC_DEVICELIB_SETSCANFLASHENABLE_I 0x41620000L

//
// MessageId: ITC_DEVICELIB_SETSCANPOWER_I
//
// MessageText:
//
//  DeviceLib::CSysIO::SetScanPower Setting Scan Power to %1!d!
//
#define ITC_DEVICELIB_SETSCANPOWER_I     0x41620001L

//
// MessageId: ITC_DEVICELIB_SETSCANTRIGGER_I
//
// MessageText:
//
//  DeviceLib::CSysIO::SetScanTrigger Setting Scan Trigger to %1!d!
//
#define ITC_DEVICELIB_SETSCANTRIGGER_I   0x41620002L

//
// MessageId: ITC_DEVICELIB_SETSCANLED_I
//
// MessageText:
//
//  DeviceLib::CSysIO::SetScanLED Setting Scan LED enable to %1!d!
//
#define ITC_DEVICELIB_SETSCANLED_I       0x41620003L

//
// MessageId: ITC_DEVICELIB_GETSCANLED_I
//
// MessageText:
//
//  DeviceLib::CSysIO::GetScanLED current Scan LED setting: %1!d!
//
#define ITC_DEVICELIB_GETSCANLED_I       0x41620004L

//
// MessageId: ITC_DEVICELIB_SYSIO_SEARAY_I
//
// MessageText:
//
//  DeviceLib::CSysIO::CSysIO - Searay Platform Detected.
//
#define ITC_DEVICELIB_SYSIO_SEARAY_I     0x41620005L

//
// MessageId: ITC_DEVICELIB_SYSIO_STINGRAY_I
//
// MessageText:
//
//  DeviceLib::CSysIO::CSysIO - Stingray Platform Detected.
//
#define ITC_DEVICELIB_SYSIO_STINGRAY_I   0x41620006L

//
// MessageId: ITC_DEVICELIB_SETTING_DTR_I
//
// MessageText:
//
//  DeviceLib::CSysIO::LegSetScanTrigger - Setting DTR to to %1!d!.
//
#define ITC_DEVICELIB_SETTING_DTR_I      0x41620007L

//
// MessageId: ITC_DEVICELIB_SETVIBRATION_I
//
// MessageText:
//
//  DeviceLib::CSysIO::SetVibration: fState: %1!d!, platform: %2!d!
//
#define ITC_DEVICELIB_SETVIBRATION_I     0x41620008L

//
// MessageId: ITC_DEVICELIB_GETVIBRATION_I
//
// MessageText:
//
//  DeviceLib::CSysIO::GetVibration: current Vibration bit: %1!d!
//
#define ITC_DEVICELIB_GETVIBRATION_I     0x41620009L

//
// MessageId: ITC_DEVICELIB_MAPBUTTON_ENTRY_I
//
// MessageText:
//
//  DeviceLib::CUtility::MapButton: Entry: eValue: 0x%1!08X!
//
#define ITC_DEVICELIB_MAPBUTTON_ENTRY_I  0x4162000AL

//
// MessageId: ITC_DEVICELIB_MAPBUTTON_EXIT_I
//
// MessageText:
//
//  DeviceLib::CUtility::MapButton: Exit: hrStatus: 0x%1!08X!
//
#define ITC_DEVICELIB_MAPBUTTON_EXIT_I   0x4162000BL

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_DEVICELIB_AIMID_NOT_XMIT_W
//
// MessageText:
//
//  DeviceLib::CS9CBCLabelResponse::: ShiftLabel - S9C did not transmitted AIM Id. First byte: %1!d!;  %2!d!
//
#define ITC_DEVICELIB_AIMID_NOT_XMIT_W   0x81620000L

//
// MessageId: ITC_DEVICELIB_NO_MATCHING_SYMBOLOGY_MASK_W
//
// MessageText:
//
//  DeviceLib::CS9CBCLabelResponse:::SetSymbology. Cannot matched sym mask. AIM/Custom Id Xmission option is ON. 1st byte: %1!d!, Option: %2!d!
//
#define ITC_DEVICELIB_NO_MATCHING_SYMBOLOGY_MASK_W 0x81620001L

//
// MessageId: ITC_DEVICELIB_INVALID_SYM_ID_XMIT_OPTION_W
//
// MessageText:
//
//  DeviceLib::CS9CBCLabelResponse::: ShiftLabel - Invalid Symbology Id Transmit Option: %1!d!; %2!d!
//
#define ITC_DEVICELIB_INVALID_SYM_ID_XMIT_OPTION_W 0x81620002L

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_DEVICELIB_SYSIO_CREATEFILE_E
//
// MessageText:
//
//  DeviceLib::CSysIO::CSysIO CreateFile error: 0x%1!08X!
//
#define ITC_DEVICELIB_SYSIO_CREATEFILE_E 0xC1620000L

//
// MessageId: ITC_DEVICELIB_SYSIO_SCANFLASH_IOCTL_E
//
// MessageText:
//
//  DeviceLib::CSysIO::SetScanFlashEnable DeviceIoControl error: 0x%1!08X!
//
#define ITC_DEVICELIB_SYSIO_SCANFLASH_IOCTL_E 0xC1620001L

//
// MessageId: ITC_DEVICELIB_SYSIO_SCANPOWER_IOCTL_E
//
// MessageText:
//
//  DeviceLib::CISCPDH::SetScanPower DeviceIoControl error: 0x%1!08X!
//
#define ITC_DEVICELIB_SYSIO_SCANPOWER_IOCTL_E 0xC1620002L

//
// MessageId: ITC_DEVICELIB_SYSIO_SCANTRIGGER_IOCTL_E
//
// MessageText:
//
//  DeviceLib::CISCPDH::SetScanTrigger DeviceIoControl error: 0x%1!08X!
//
#define ITC_DEVICELIB_SYSIO_SCANTRIGGER_IOCTL_E 0xC1620003L

//
// MessageId: ITC_DEVICELIB_SYSIO_SETSCANLED_IOCTL_E
//
// MessageText:
//
//  DeviceLib::CSysIO::SetScanLED DeviceIoControl error: 0x%1!08X!
//
#define ITC_DEVICELIB_SYSIO_SETSCANLED_IOCTL_E 0xC1620004L

//
// MessageId: ITC_DEVICELIB_SYSIO_GETSCANLED_IOCTL_E
//
// MessageText:
//
//  DeviceLib::CSysIO::GetScanLED DeviceIoControl error: 0x%1!08X!
//
#define ITC_DEVICELIB_SYSIO_GETSCANLED_IOCTL_E 0xC1620005L

//
// MessageId: ITC_DEVICELIB_DOWNLOADCMD_BAD_FORMAT_E
//
// MessageText:
//
//  DeviceLib::CS9CDownLoadCmd::GetFileNames - File names string has bad format, no comma delimiters: 0x%1!08X!, 0x%2!08X!
//
#define ITC_DEVICELIB_DOWNLOADCMD_BAD_FORMAT_E 0xC1620006L

//
// MessageId: ITC_DEVICELIB_CS9CWRITECMD_E
//
// MessageText:
//
//  DeviceLib::CS9CWriteCmd::Fill: Callers buffer of %1!d! bytes is too large. Max bytes: %2!d! bytes.
//
#define ITC_DEVICELIB_CS9CWRITECMD_E     0xC1620007L

//
// MessageId: ITC_DEVICELIB_SETCONFIGCMDBUFFER_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  DeviceLib::CS9CRequestGetConfig::SetConfigCmdBuffer - Error! Buffer is too small: dataLength: %1!d! > allocated: %2!d!
//
#define ITC_DEVICELIB_SETCONFIGCMDBUFFER_BUFFER_TOO_SMALL_E 0xC1620008L

//
// MessageId: ITC_DEVICELIB_DOWNLOADCMD_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  DeviceLib::CISCPDH::CS9CDownLoadCmd  - Error! Buffer is too small: nFileNames: %1!d! > allocated: %2!d!
//
#define ITC_DEVICELIB_DOWNLOADCMD_BUFFER_TOO_SMALL_E 0xC1620009L

//
// MessageId: ITC_DEVICELIB_DOWNLOADCMD_FILENAMES_NULL_E
//
// MessageText:
//
//  DeviceLib::CISCPDH::CS9CDownLoadCmd  - Error! FileNames buffer is NULL: nFileNames: %1!d!, %2!d!
//
#define ITC_DEVICELIB_DOWNLOADCMD_FILENAMES_NULL_E 0xC162000AL

//
// MessageId: ITC_DEVICELIB_CCODEMARK_INDEX_OUT_OF_BOUND_E
//
// MessageText:
//
//  DeviceLib::CCodeMark:UpdateCodeMarkTable - Index out of bound: i: %1!d!,  m_dwNumCodeMark: %2!d!
//
#define ITC_DEVICELIB_CCODEMARK_INDEX_OUT_OF_BOUND_E 0xC162000BL

//
// MessageId: ITC_DEVICELIB_LEGSETSCANTRIGGER_INVALID_COMMPORT_E
//
// MessageText:
//
//  DeviceLib::CSysio::LegSetScanTrigger - Invalid Comm Port Value.
//
#define ITC_DEVICELIB_LEGSETSCANTRIGGER_INVALID_COMMPORT_E 0xC162000CL

//
// MessageId: ITC_DEVICELIB_SEASETSCANLED_E
//
// MessageText:
//
//  DeviceLib::CSysio::SeaSetScanLed - Failed on call to NLedSetDevice. uLedState: %1!d!
//
#define ITC_DEVICELIB_SEASETSCANLED_E    0xC162000DL

//
// MessageId: ITC_DEVICELIB_SEAGETSCANLED_E
//
// MessageText:
//
//  DeviceLib::CSysio::SeaGetScanLed - Failed on call to NLedGetDeviceInfo.
//
#define ITC_DEVICELIB_SEAGETSCANLED_E    0xC162000EL

//
// MessageId: ITC_DEVICELIB_SYMBOLOGIESNOTUPDATED_E
//
// MessageText:
//
//  DeviceLib::CSysio::UpdateRegEntries - Could not launch ITCREGLOADER. Symbologies not updated: 0x%1!08X!
//
#define ITC_DEVICELIB_SYMBOLOGIESNOTUPDATED_E 0xC162000FL

//
// MessageId: ITC_DEVICELIB_SYSIO_OPEN_HCRO_E
//
// MessageText:
//
//  DeviceLib::CSysio::CSysio - Failed on call Open_Hcro.
//
#define ITC_DEVICELIB_SYSIO_OPEN_HCRO_E  0xC1620010L

//
// MessageId: ITC_DEVICELIB_SYSIO_SCANFLASH_ITCSETSCANFLASH_E
//
// MessageText:
//
//  DeviceLib::CSysio::SeaSetScanFlashEnable - Failed.
//
#define ITC_DEVICELIB_SYSIO_SCANFLASH_ITCSETSCANFLASH_E 0xC1620011L

//
// MessageId: ITC_DEVICELIB_SYSIO_SCANPOWER_ITCSETSCANPOWER_E
//
// MessageText:
//
//  DeviceLib::CSysio::SeaSetScanPower - Failed.
//
#define ITC_DEVICELIB_SYSIO_SCANPOWER_ITCSETSCANPOWER_E 0xC1620012L

//
// MessageId: ITC_DEVICELIB_SYSIO_SCANTRIGGER_ITCSETTRIGAIM_E
//
// MessageText:
//
//  DeviceLib::CSysio::SeaSetScanTrigger - Failed.
//
#define ITC_DEVICELIB_SYSIO_SCANTRIGGER_ITCSETTRIGAIM_E 0xC1620013L

//
// MessageId: ITC_DEVICELIB_SEASETVIBRATION_E
//
// MessageText:
//
//  DeviceLib::CSysio::SeaSetVibration - Failed.
//
#define ITC_DEVICELIB_SEASETVIBRATION_E  0xC1620014L

//
// MessageId: ITC_DEVICELIB_SEAGETVIBRATION_E
//
// MessageText:
//
//  DeviceLib::CSysio::SeaGetVibration - Failed.
//
#define ITC_DEVICELIB_SEAGETVIBRATION_E  0xC1620015L

//
// MessageId: ITC_DEVICELIB_NOT_SEARAY_PLATFORM_E
//
// MessageText:
//
//  DeviceLib::XXXX - Error: Not Searay Platform.
//
#define ITC_DEVICELIB_NOT_SEARAY_PLATFORM_E 0xC1620016L

//
// MessageId: ITC_DEVICELIB_INVALID_OPTION_E
//
// MessageText:
//
//  DeviceLib::XXXX - Invalid Option.
//
#define ITC_DEVICELIB_INVALID_OPTION_E   0xC1620017L

//
// MessageId: ITC_DEVICELIB_GETSYSTEMRESETINFO_BYTE_RETURNED_E
//
// MessageText:
//
//  DeviceLib::GetSystemResetInfo - bytesRet error: expected: %1!d!, bytesRet: %2!d!
//
#define ITC_DEVICELIB_GETSYSTEMRESETINFO_BYTE_RETURNED_E 0xC1620018L

//
// MessageId: ITC_DEVICELIB_GETSYSTEMRESETINFO_KERNELIOCTRL_E
//
// MessageText:
//
//  DeviceLib::GetSystemResetInfo - KernelIOControl error: GetLastError: 0x%1!08X!
//
#define ITC_DEVICELIB_GETSYSTEMRESETINFO_KERNELIOCTRL_E 0xC1620019L

//
// MessageId: ITC_DEVICELIB_GETREGFILENAMETOLOAD_E
//
// MessageText:
//
//  DeviceLib::GetRegFileNameToLoad - Buffer too small:  expected: %1!d!, dwszFileToLoadSize: %2!d!
//
#define ITC_DEVICELIB_GETREGFILENAMETOLOAD_E 0xC162001AL

//
// MessageId: ITC_DEVICELIB_CINDICATOR_SETSCANAUDIOLEVEL_INVALID_INPUT_E
//
// MessageText:
//
//  DeviceLib::CIndicator::SetScanAudioLevel - Invalid Input: %1!d!
//
#define ITC_DEVICELIB_CINDICATOR_SETSCANAUDIOLEVEL_INVALID_INPUT_E 0xC162001BL

//
// MessageId: ITC_DEVICELIB_CINDICATOR_SETSCANAUDIOLEVEL_WAVEINMESSAGE_MUTE_E
//
// MessageText:
//
//  DeviceLib::CIndicator::SetScanAudioLevel - waveInMessage failed: error: %1!d!, mute: %2!d!
//
#define ITC_DEVICELIB_CINDICATOR_SETSCANAUDIOLEVEL_WAVEINMESSAGE_MUTE_E 0xC162001CL

//
// MessageId: ITC_DEVICELIB_CINDICATOR_SETSCANAUDIOLEVEL_WAVEINMESSAGE_GAIN_E
//
// MessageText:
//
//  DeviceLib::CIndicator::SetScanAudioLevel - waveInMessage failed: error: %1!d!, Gain: %2!d!
//
#define ITC_DEVICELIB_CINDICATOR_SETSCANAUDIOLEVEL_WAVEINMESSAGE_GAIN_E 0xC162001DL

//
// MessageId: ITC_DEVICELIB_CINDICATOR_GETSCANAUDIOLEVEL_WAVEINMESSAGE_E
//
// MessageText:
//
//  DeviceLib::CIndicator::GetScanAudioLevel - waveInMessage failed: error: %1!d!, Registry volume: %2!d!
//
#define ITC_DEVICELIB_CINDICATOR_GETSCANAUDIOLEVEL_WAVEINMESSAGE_E 0xC162001EL

//
// MessageId: ITC_DEVICELIB_CINDICATOR_WAVEINOPEN_FAILED_E
//
// MessageText:
//
//  DeviceLib::CIndicator::WaveInOpen - waveInOpen failed: error: %1!d!
//
#define ITC_DEVICELIB_CINDICATOR_WAVEINOPEN_FAILED_E 0xC162001FL

//
// MessageId: ITC_DEVICELIB_CINDICATOR_SETSCANAUDIOLEVEL_WAVEINCLOSE_FAILED_E
//
// MessageText:
//
//  DeviceLib::CIndicator - waveInClose failed in SetScanAudioLevel: error: %1!d!
//
#define ITC_DEVICELIB_CINDICATOR_SETSCANAUDIOLEVEL_WAVEINCLOSE_FAILED_E 0xC1620020L

//
// MessageId: ITC_DEVICELIB_CINDICATOR_GETSCANAUDIOLEVEL_WAVEINCLOSE_FAILED_E
//
// MessageText:
//
//  DeviceLib::CIndicator - waveInClose failed in GetScanAudioLevel: error: %1!d!
//
#define ITC_DEVICELIB_CINDICATOR_GETSCANAUDIOLEVEL_WAVEINCLOSE_FAILED_E 0xC1620021L

//
// MessageId: ITC_DEVICELIB_CCOMMCONFIG_EXEPTION_E
//
// MessageText:
//
//  CCommConfig::CCommConfig. CRegistry Class Throw Exception. hr=0x%1!08X!
//
#define ITC_DEVICELIB_CCOMMCONFIG_EXEPTION_E 0xC1620022L

//
// MessageId: ITC_DEVICELIB_CCOMMCONFIG_SETCONFIG_EXEPTION_E
//
// MessageText:
//
//  CCommConfig::SetConfig. CRegistry Class Throw Exception. hr=0x%1!08X!
//
#define ITC_DEVICELIB_CCOMMCONFIG_SETCONFIG_EXEPTION_E 0xC1620023L

//
// MessageId: ITC_DEVICELIB_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  DeviceLib - Buffer too small:  expected: %1!d!, input: %2!d!
//
#define ITC_DEVICELIB_BUFFER_TOO_SMALL_E 0xC1620024L

//
// MessageId: ITC_DEVICELIB_CANNOT_FIND_GIDFID_IN_TABLE_E
//
// MessageText:
//
//  DeviceLib - UpdateCustomSymIdTable: Cannot find: Gid:0x%1!X!, Fid:0x%2!X!
//
#define ITC_DEVICELIB_CANNOT_FIND_GIDFID_IN_TABLE_E 0xC1620025L

//
// MessageId: ITC_DEVICELIB_ASCIITOPARAM_E
//
// MessageText:
//
//  DeviceLib - AsciiToParam: ASCII value not support: %1!x!
//
#define ITC_DEVICELIB_ASCIITOPARAM_E     0xC1620026L

#endif	// INCLUDED_DEVICELIB_MSG
////////////////////////////////////////////////////////////////////
// END OF FILE:  devicelib.mcs
//  COPYRIGHT (c) 2002 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
/*///////////////////////////////////////////////////////////////////
//
//  FILE NAME:  IADCDevice.mcs
//
//  AUTHOR:
//
// $Log:   S:/raptor/archive/INTERMEC/IADCDevice/common/vcs/IADCDevice.mcs.archive  $
//
//   Rev 1.1   17 Sep 1998 16:43:04   JHunt
//Put block style comments in the file headers
//
//   Rev 1.0   04 Sep 1998 14:08:04   JHunt
//Initial revision.
//   
//      Rev 1.1   Aug 26 1998 14:00:14   MAlbro
//   Corrected Case on either WorkFile or Log
// COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
*////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_IADCDEVICE_MCS
#define INCLUDED_IADCDEVICE_MCS
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Informational
//Facility=IADCDevice
//SymbolicName=ITC_<facility acronym>_<msg name>_I 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Success
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_S 
//Language=English
//<message string>
//.
//
// MessageId: ITC_IADCDEV_RESPONSE_PENDING_S
//
// MessageText:
//
//  The IADCDevice response is pending
//
#define ITC_IADCDEV_RESPONSE_PENDING_S   0x01350000L

////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Warning
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<message acronym>_W 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_IADCDEV_REINIT_DEVICE_E
//
// MessageText:
//
//  The IADCDevice needs to be reinitialized.
//
#define ITC_IADCDEV_REINIT_DEVICE_E      0xC1350000L

#endif  // THIS LINE MUST BE AFTER ANY MESSAGE DEFINITIONS.
////////////////////////////////////////////////////////////////////
// END OF FILE:  <filename>.mcs
//  COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCComServer.mcs
//
//  AUTHOR:	J. Hunt
//
// $log$
// COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_ITCCOMSERVER_MCS
#define INCLUDED_ITCCOMSERVER_MCS
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_COMSRV_NONDELEGATE_CUKNOWN_CTOR_I
//
// MessageText:
//
//  CUnknown()::CUnknown  Non Delegating.  this: %1!08X!  
//
#define ITC_COMSRV_NONDELEGATE_CUKNOWN_CTOR_I 0x412F0000L

//
// MessageId: ITC_COMSRV_DELEGATE_CUKNOWN_CTOR_I
//
// MessageText:
//
//  CUnknown()::CUnknown  Delegating. this: %1!08X! 
//
#define ITC_COMSRV_DELEGATE_CUKNOWN_CTOR_I 0x412F0001L

//
// MessageId: ITC_COMSRV_NONDELEGATE_QI_I
//
// MessageText:
//
//  CUnknown()::NondelegatingQueryInterface success.
//
#define ITC_COMSRV_NONDELEGATE_QI_I      0x412F0002L

//
// MessageId: ITC_COMSRV_NONDELEGATE_RELEASE_I
//
// MessageText:
//
//  CUnknown()::NondelegatingRelease this: %1!08X!; cRef: %2!d! 
//
#define ITC_COMSRV_NONDELEGATE_RELEASE_I 0x412F0003L

//
// MessageId: ITC_COMSRV_CFACTORY_CI_I
//
// MessageText:
//
//  CFactory::CreateInstance
//
#define ITC_COMSRV_CFACTORY_CI_I         0x412F0004L

//
// MessageId: ITC_COMSRV_CFACTORY_CI_STATUS_I
//
// MessageText:
//
//  CFactory::CreateInstance status: 0x%1!08X!
//
#define ITC_COMSRV_CFACTORY_CI_STATUS_I  0x412F0005L

//
// MessageId: ITC_COMSRV_CFACTORY_CI_INIT_I
//
// MessageText:
//
//  CFactory::CreateInstance Init status: 0x%1!08X!
//
#define ITC_COMSRV_CFACTORY_CI_INIT_I    0x412F0006L

//
// MessageId: ITC_COMSRV_CFACTORY_CI_FAILED_I
//
// MessageText:
//
//  CFactory::CreateInstance Failed: 0x%1!08X!
//
#define ITC_COMSRV_CFACTORY_CI_FAILED_I  0x412F0007L

//
// MessageId: ITC_COMSRV_CFACTORY_CI_EXCEPTION_I
//
// MessageText:
//
//  CFactory::CreateInstance EXCEPTION: 0x%1!08X!
//
#define ITC_COMSRV_CFACTORY_CI_EXCEPTION_I 0x412F0008L

//
// MessageId: ITC_COMSRV_CFACTORY_GETCLASSOBJECT_I
//
// MessageText:
//
//  CFactory::GetClassObject
//
#define ITC_COMSRV_CFACTORY_GETCLASSOBJECT_I 0x412F0009L

//
// MessageId: ITC_COMSRV_CFACTORY_GETCLASSOBJECT_SUCCEEDED_I
//
// MessageText:
//
//  CFactory::GetClassObject created object %1!d!
//
#define ITC_COMSRV_CFACTORY_GETCLASSOBJECT_SUCCEEDED_I 0x412F000AL

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Success
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_S 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Warning
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<message acronym>_W 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_COMSRV_REGSRV_E
//
// MessageText:
//
//  CFactoryData::Register Server Failed.  Reason: %1!08X!
//
#define ITC_COMSRV_REGSRV_E              0xC12F0000L

//
// MessageId: ITC_INVALID_QI_REQUEST_E
//
// MessageText:
//
//  CUknown::NondelegatingQueryInterface invalid interface request
//
#define ITC_INVALID_QI_REQUEST_E         0xC12F0001L

//
// MessageId: ITC_CFACTORY_GETCLASSOBJECT_E
//
// MessageText:
//
//  CFactory::GetClassObject out of memory - object #%1!d!
//
#define ITC_CFACTORY_GETCLASSOBJECT_E    0xC12F0002L

#endif  // THIS LINE MUST BE AFTER ANY MESSAGE DEFINITIONS.
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCComServer.mcs
//  COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCConfigRouter.mcs
//
//  AUTHOR:  Paul D. Shoeman
//
//  COPYRIGHT (c) 2003 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_ITCCONFIGROUTER_MCS
#define INCLUDED_ITCCONFIGROUTER_MCS
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_CONSTRUCTOR_ENTRY_I
//
// MessageText:
//
//  SnmpObj::SnmpObj - Function entry
//
#define ITC_CONFIGROUTER_SNMPOBJ_CONSTRUCTOR_ENTRY_I 0x41540000L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_DESTRUCTOR_ENTRY_I
//
// MessageText:
//
//  SnmpObj::~SnmpObj - Function entry
//
#define ITC_CONFIGROUTER_SNMPOBJ_DESTRUCTOR_ENTRY_I 0x41540001L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_ENTRY_I
//
// MessageText:
//
//  SnmpObj::Initialize - Function entry
//
#define ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_ENTRY_I 0x41540002L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_END_OF_LIST_I
//
// MessageText:
//
//  Reached the end of a linked list or array
//
#define ITC_CONFIGROUTER_SNMPOBJ_END_OF_LIST_I 0x41540003L

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_GET_CURRENT_OID_TEXT_S
//
// MessageText:
//
//  SnmpObj::Get 1 m_pWCurrentOidText[%1!u!]
//
#define ITC_CONFIGROUTER_SNMPOBJ_GET_CURRENT_OID_TEXT_S 0x01540000L

////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Warning
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<message acronym>_W 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_WSASTARTFAIL_E
//
// MessageText:
//
//  SnmpObj::Initialize E_WSASTARTFAIL 1
//
#define ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_WSASTARTFAIL_E 0xC1540000L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_NULL_NEW_SNMPTARGET_E
//
// MessageText:
//
//  SnmpObj::Initialize NULL new itc_SnmpTarget(wBuff) 2
//
#define ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_NULL_NEW_SNMPTARGET_E 0xC1540001L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_INVALID_SOCKET_E
//
// MessageText:
//
//  SnmpObj::Initialize m_Socket == INVALID_SOCKET 3
//
#define ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_INVALID_SOCKET_E 0xC1540002L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_LOW_MEM_E
//
// MessageText:
//
//  SnmpObj::Initialize LOW MEM 4
//
#define ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_LOW_MEM_E 0xC1540003L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_SNMPVARBIND_FAILED_E
//
// MessageText:
//
//  SnmpObj::Initialize new itc_SnmpVarBind FAILED 5
//
#define ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_SNMPVARBIND_FAILED_E 0xC1540004L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_EXCEPTION_EXECUTE_HANDLER_E
//
// MessageText:
//
//  SnmpObj::Initialize EXCEPTION_EXECUTE_HANDLER 6
//
#define ITC_CONFIGROUTER_SNMPOBJ_INITIALIZE_EXCEPTION_EXECUTE_HANDLER_E 0xC1540005L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_GET_UNEXPECTED1_E
//
// MessageText:
//
//  SnmpObj::Get E_UNEXPECTED nErrStat[%1!d!] 1
//
#define ITC_CONFIGROUTER_SNMPOBJ_GET_UNEXPECTED1_E 0xC1540006L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_GET_UNEXPECTED2_E
//
// MessageText:
//
//  SnmpObj::Get E_UNEXPECTED 2
//
#define ITC_CONFIGROUTER_SNMPOBJ_GET_UNEXPECTED2_E 0xC1540007L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_GET_UNEXPECTED3_E
//
// MessageText:
//
//  SnmpObj::Get E_UNEXPECTED 3
//
#define ITC_CONFIGROUTER_SNMPOBJ_GET_UNEXPECTED3_E 0xC1540008L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_GET_EXCEPTION_E
//
// MessageText:
//
//  SnmpObj::Get EXCEPTION_EXECUTE_HANDLER 4
//
#define ITC_CONFIGROUTER_SNMPOBJ_GET_EXCEPTION_E 0xC1540009L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_SET_UNKNOWN_TYPE_E
//
// MessageText:
//
//  SnmpObj::Set Unknown type in m_pType
//
#define ITC_CONFIGROUTER_SNMPOBJ_SET_UNKNOWN_TYPE_E 0xC154000AL

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJ_SET_EXCEPTION_E
//
// MessageText:
//
//  SnmpObj::Set EXCEPTION_EXECUTE_HANDLER
//
#define ITC_CONFIGROUTER_SNMPOBJ_SET_EXCEPTION_E 0xC154000BL

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJHELPER_REALSNMPGET_GETFAIL_E
//
// MessageText:
//
//  SnmpObjHelper::RealSnmpGet pSO->Get() FAILED
//
#define ITC_CONFIGROUTER_SNMPOBJHELPER_REALSNMPGET_GETFAIL_E 0xC154000CL

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJHELPER_REALSNMPGET_UNKNOWNERROR_E
//
// MessageText:
//
//  SnmpObjHelper::RealSnmpGet E_UNKNOWNERROR 4 RealSnmpGet 1
//
#define ITC_CONFIGROUTER_SNMPOBJHELPER_REALSNMPGET_UNKNOWNERROR_E 0xC154000DL

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJHELPER_MULTIPLEREALSNMPGET_GETFAIL_E
//
// MessageText:
//
//  SnmpObjHelper::MultipleRealSnmpGet pV->GetValue() FAILED
//
#define ITC_CONFIGROUTER_SNMPOBJHELPER_MULTIPLEREALSNMPGET_GETFAIL_E 0xC154000EL

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJHELPER_MULTIPLEREALSNMPGET_MEMORY_ALLOC_E
//
// MessageText:
//
//  SnmpObjHelper::MultipleRealSnmpGet Memory alloc of SnmpObj failed
//
#define ITC_CONFIGROUTER_SNMPOBJHELPER_MULTIPLEREALSNMPGET_MEMORY_ALLOC_E 0xC154000FL

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJHELPER_MULTIPLEREALSNMPGET_UNKNOWNERROR_E
//
// MessageText:
//
//  SnmpObjHelper::MultipleRealSnmpGet Exception caught: E_UNKNOWNERROR
//
#define ITC_CONFIGROUTER_SNMPOBJHELPER_MULTIPLEREALSNMPGET_UNKNOWNERROR_E 0xC1540010L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJHELPER_GETIP_FAILED_E
//
// MessageText:
//
//  SnmpObjHelper::GetIPAddressLocalMachine itc_InetAddress::getLocalHost() FAILED
//
#define ITC_CONFIGROUTER_SNMPOBJHELPER_GETIP_FAILED_E 0xC1540011L

//
// MessageId: ITC_CONFIGROUTER_SNMPOBJHELPER_GETIP_INET_FAILED_E
//
// MessageText:
//
//  SnmpObjHelper::GetIPAddressLocalMachine inet_ntoa FAILED
//
#define ITC_CONFIGROUTER_SNMPOBJHELPER_GETIP_INET_FAILED_E 0xC1540012L

#endif  // THIS LINE MUST BE AFTER ANY MESSAGE DEFINITIONS.
////////////////////////////////////////////////////////////////////
//  END OF FILE:  ITCConfigRouter.mcs
//  COPYRIGHT (c) 2003 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCDataServer.mcs
//
//  AUTHOR:     C. Ho
// COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_ITCDATASERVER_MCS
#define INCLUDED_ITCDATASERVER_MCS
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Informational
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_I 
//Language=English
//<message string>
//.
//
// MessageId: ITC_DS_WORKER_THREAD_EXIT_I
//
// MessageText:
//
//  DS: Worker thread exit
//
#define ITC_DS_WORKER_THREAD_EXIT_I      0x41040001L

//
// MessageId: ITC_DS_DEVICE_RSP_THREAD_EXIT_I
//
// MessageText:
//
//  CDevice::ProcessDeviceResponses - Exit; Dev %1!08X!
//
#define ITC_DS_DEVICE_RSP_THREAD_EXIT_I  0x41040002L

//
// MessageId: ITC_DS_DEVMGR_NO_DEVICE_ACTIVE_I
//
// MessageText:
//
//  CDeviceManager::Initialize - No device active
//
#define ITC_DS_DEVMGR_NO_DEVICE_ACTIVE_I 0x41040003L

//
// MessageId: ITC_DS_CLIENTCONN_CLOSE_I
//
// MessageText:
//
//  DS: Client Connection closes.  
//
#define ITC_DS_CLIENTCONN_CLOSE_I        0x41040004L

//
// MessageId: ITC_DS_POST_OPEN_I
//
// MessageText:
//
//  CDeviceConnection::OpenRequest - ConnID: %1!08X!; Flags: %2!08X!
//
#define ITC_DS_POST_OPEN_I               0x41040005L

//
// MessageId: ITC_DS_POST_READ_I
//
// MessageText:
//
//  CDeviceConnection::ReadRequest - Begin Read Req;  ConnID: %1!08X!; Data Class: %2!08X!
//
#define ITC_DS_POST_READ_I               0x41040006L

//
// MessageId: ITC_DS_SUBMIT_READ_I
//
// MessageText:
//
//  CDeviceConnection::ReadRequest - Submit Read Req; ConnID: %1!08X!; status: %2!08X!
//
#define ITC_DS_SUBMIT_READ_I             0x41040007L

//
// MessageId: ITC_DS_POST_WRITE_I
//
// MessageText:
//
//  CDeviceConnection::WriteRequest -  Entry; ConnID: %1!08X!
//
#define ITC_DS_POST_WRITE_I              0x41040008L

//
// MessageId: ITC_DS_POST_QUERY_ATTRIBUTE_I
//
// MessageText:
//
//  DS: CDeviceConnection::QueryAttributeRequest; ConnID: %1!08X! - Attrib: %2!08X!
//
#define ITC_DS_POST_QUERY_ATTRIBUTE_I    0x41040009L

//
// MessageId: ITC_DS_POST_SET_ATTRIBUTE_I
//
// MessageText:
//
//  DS: CDeviceConnection::SetAttributeRequest; ConnID: %1!08X! - Attrib: %2!08X!
//
#define ITC_DS_POST_SET_ATTRIBUTE_I      0x4104000AL

//
// MessageId: ITC_DS_POST_CLOSE_I
//
// MessageText:
//
//  CDeviceConnection::CloseRequest - Entry; ConnID: %1!08X!
//
#define ITC_DS_POST_CLOSE_I              0x4104000BL

//
// MessageId: ITC_DS_SET_ATTRIBUTE_I
//
// MessageText:
//
//  CDeviceConnection::SetAttributeRequest - Entry; ConnID: %1!08X!; Req: %2!08X!
//
#define ITC_DS_SET_ATTRIBUTE_I           0x4104000CL

//
// MessageId: ITC_DS_QUERY_ATTRIBUTE_I
//
// MessageText:
//
//  CDeviceConnection::QueryAttributeRequest - Entry; ConnID: %1!08X!; Req: %2!08X!
//
#define ITC_DS_QUERY_ATTRIBUTE_I         0x4104000DL

//
// MessageId: ITC_DS_QUERY_DATA_I
//
// MessageText:
//
//  DS: ConnID: %1!08X! QueryData Req
//
#define ITC_DS_QUERY_DATA_I              0x4104000EL

//
// MessageId: ITC_DS_SET_DATACLASS_I
//
// MessageText:
//
//  CGrid::SetDataClass - Entry; ConnID: %1!08X!; DataClass %2!08X!
//
#define ITC_DS_SET_DATACLASS_I           0x4104000FL

//
// MessageId: ITC_DS_ATTEMPT_AUTO_READ_I
//
// MessageText:
//
//  CDeviceConnection::PostAutomaticRequest -  ConnID: %1!08X!
//
#define ITC_DS_ATTEMPT_AUTO_READ_I       0x41040010L

//
// MessageId: ITC_RESPONSE_BUFFERED_I
//
// MessageText:
//
//  CDeviceConnection::IsResponseBuffered - Retrieved buffered response; ConnID: %1!08X! 
//
#define ITC_RESPONSE_BUFFERED_I          0x41040011L

//
// MessageId: ITC_DS_ADD_RESPONSE_LIST_I
//
// MessageText:
//
//  CDeviceConnection::AddBufferResponse - Added entry response list; ConnID: %1!08X!; Total: %2!0d!
//
#define ITC_DS_ADD_RESPONSE_LIST_I       0x41040012L

//
// MessageId: ITC_DS_REMOVE_RESPONSE_LIST_I
//
// MessageText:
//
//  CDeviceConnection::RemoveBufferResponse - Removed entry response list; ConnID: %1!08X!; Total: %2!0d!
//
#define ITC_DS_REMOVE_RESPONSE_LIST_I    0x41040013L

//
// MessageId: ITC_DS_CONNECTION_ALREADY_INITIALIZED_I
//
// MessageText:
//
//  CDeviceConnection::Reinitialize - Already initialized; ConnID: %1!08X! 
//
#define ITC_DS_CONNECTION_ALREADY_INITIALIZED_I 0x41040014L

//
// MessageId: ITC_DS_RETURN_DATA_FALSE_I
//
// MessageText:
//
//  CDeviceConnection::MatchResponse- MultiClient flag FALSE not accepting data; ConnID: %1!08X!  
//
#define ITC_DS_RETURN_DATA_FALSE_I       0x41040015L

//
// MessageId: ITC_DS_SET_MULTICLIENT_ACTIVATED_FLAG_I
//
// MessageText:
//
//  CDeviceConnection::ActivateMultiClient - After set MultiClient Activated;ConnID: %1!08X!; Flag: %2!08X!
//
#define ITC_DS_SET_MULTICLIENT_ACTIVATED_FLAG_I 0x41040016L

//
// MessageId: ITC_DS_SET_FLUSH_BUFFER_FLAG_I
//
// MessageText:
//
//  CDeviceConnection::SetFlushDeviceBufferFlag - After set flush buffer flag; ConnID: %1!08X!; Flag: %2!08X!
//
#define ITC_DS_SET_FLUSH_BUFFER_FLAG_I   0x41040017L

//
// MessageId: ITC_DS_ADD_RA_CONNECTION_I
//
// MessageText:
//
//  CDevice::CreateDeviceConnection - Adding RA Connection; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_ADD_RA_CONNECTION_I       0x41040018L

//
// MessageId: ITC_DS_REMOVE_CONNECTION_I
//
// MessageText:
//
//  CDevice::RemoveDeviceConnection - Removing Connection; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_REMOVE_CONNECTION_I       0x41040019L

//
// MessageId: ITC_DS_ALLOCATE_RESPONSE_LIST_ENTRY_I
//
// MessageText:
//
//  CDevice::AllocateResponseListEntry - Dev: %1!08X!; Total avail: %2!0d!
//
#define ITC_DS_ALLOCATE_RESPONSE_LIST_ENTRY_I 0x4104001AL

//
// MessageId: ITC_DS_FREE_RESPONSE_LIST_ENTRY_I
//
// MessageText:
//
//  CDevice::FreeResponseListEntry -  Dev: %1!08X!; Total avail: %2!0d!
//
#define ITC_DS_FREE_RESPONSE_LIST_ENTRY_I 0x4104001BL

//
// MessageId: ITC_DS_WAIT_REQUEST_POST_I
//
// MessageText:
//
//  CDeviceConnection::IsRequestPosted - Waiting for request to be posted; DevConn: %1!08X!; Thread: %2!08X!
//
#define ITC_DS_WAIT_REQUEST_POST_I       0x4104001CL

//
// MessageId: ITC_DS_WAIT_READ_RESPONSE_I
//
// MessageText:
//
//  CDeviceConnection::IsRequestPosted - Request posted; DevConn: %1!08X!
//
#define ITC_DS_WAIT_READ_RESPONSE_I      0x4104001DL

//
// MessageId: ITC_DS_CLIENT_POST_READ_REQUEST_I
//
// MessageText:
//
//  CDeviceConnection::IsRequestPosted - Read posted; DevConn: %1!08X!; Thread: 0x%2!08X!
//
#define ITC_DS_CLIENT_POST_READ_REQUEST_I 0x4104001EL

//
// MessageId: ITC_DS_SET_READ_ACCEPTED_FLAG_I
//
// MessageText:
//
//  CDeviceConnection::SetReadAcceptedFlag - Exit; ConnID: %1!08X! Flags: %2!08X!
//
#define ITC_DS_SET_READ_ACCEPTED_FLAG_I  0x4104001FL

//
// MessageId: ITC_DS_BEFOREWAIT_DEVICE_RESPONSE_I
//
// MessageText:
//
//  CDeviceConnection::WaitForDeviceResponse - before WaitForSingleObject; ConnID: %1!08X!
//
#define ITC_DS_BEFOREWAIT_DEVICE_RESPONSE_I 0x41040020L

//
// MessageId: ITC_DS_AFTERWAIT_DEVICE_RESPONSE_I
//
// MessageText:
//
//  CDeviceConnection::WaitForDeviceResponse - After WaitForSingleObject status: 0x%2!08X!; ConnID: %1!08X!;  
//
#define ITC_DS_AFTERWAIT_DEVICE_RESPONSE_I 0x41040021L

//
// MessageId: ITC_DS_PROCESS_READ_RESPONSE_ENTRY_I
//
// MessageText:
//
//  CDeviceConnection::ProcessReadResponse - Entry; ConnID: %1!08X!
//
#define ITC_DS_PROCESS_READ_RESPONSE_ENTRY_I 0x41040022L

//
// MessageId: ITC_DS_PROCESS_DEVICE_RESPONSE_READ_I
//
// MessageText:
//
//  CDevice::ProcessDeviceResponses - MerlinRead; whDevice: %1!08X!  wSequenceNumber: %2! d!
//
#define ITC_DS_PROCESS_DEVICE_RESPONSE_READ_I 0x41040023L

//
// MessageId: ITC_DS_COPY_RESPONSE_ALLOCATEBUF_I
//
// MessageText:
//
//  CDevice::CopyResponse - AllocateBuffer; dwDataSize: %1!08X!  pbData %2!08X!
//
#define ITC_DS_COPY_RESPONSE_ALLOCATEBUF_I 0x41040024L

//
// MessageId: ITC_DS_DISTRIB_RESPONSE_GETAT_I
//
// MessageText:
//
//  CDevice::DistributeResponse - GetAt; Connection: %1!08X!
//
#define ITC_DS_DISTRIB_RESPONSE_GETAT_I  0x41040025L

//
// MessageId: ITC_DS_DISTRIB_RESPONSE_GETOBJACC_I
//
// MessageText:
//
//  CDevice::DistributeResponse - GetObjAccess; - Connection: %1!08X! 
//
#define ITC_DS_DISTRIB_RESPONSE_GETOBJACC_I 0x41040026L

//
// MessageId: ITC_DS_PROC_READ_RESP_SETEVT_I
//
// MessageText:
//
//  CDeviceConnection::ProcessReadResponse - SetEvent; m_dwID: %1!08X!  
//
#define ITC_DS_PROC_READ_RESP_SETEVT_I   0x41040027L

//
// MessageId: ITC_DS_GET_DAT_FRM_RESP_Q_I
//
// MessageText:
//
//  CDeviceConnection::WaitForDeviceResponse, IsRespBuf - pReq: %1!08X!  m_ppRspBuff %2!08X!
//
#define ITC_DS_GET_DAT_FRM_RESP_Q_I      0x41040028L

//
// MessageId: ITC_DS_SET_STATE_COMPLETE_I
//
// MessageText:
//
//  CDeviceConnection::WaitForDeviceResponse, Set State Complete - pReq: %1!08X!  m_pReqData %2!08X!
//
#define ITC_DS_SET_STATE_COMPLETE_I      0x41040029L

//
// MessageId: ITC_DS_DONE_POST_READ_I
//
// MessageText:
//
//  CDeviceConnection::PostAutomaticRequest, Conn: %1!08X!, pReq is NULL, can't clear the request object.
//
#define ITC_DS_DONE_POST_READ_I          0x4104002AL

//
// MessageId: ITC_DS_DEBUG_I
//
// MessageText:
//
//  Data Server Debug - Code: %1!d!. Param: %2!08X!
//
#define ITC_DS_DEBUG_I                   0x4104002BL

//
// MessageId: ITC_DS_DEVMGR_GETNUMBEROFDEVICES_ENTRY_I
//
// MessageText:
//
//  CDeviceInfo::GetNumberOfDevices - Entry. dwNumDevices: %1!d!
//
#define ITC_DS_DEVMGR_GETNUMBEROFDEVICES_ENTRY_I 0x4104002CL

//
// MessageId: ITC_DS_DEVMGR_GETNUMBEROFDEVICES_REMOVE_DEVICE_KEY_I
//
// MessageText:
//
//  CDeviceInfo::GetNumberOfDevices. Removed a device with VW Type = 0, registry index: %1!d!
//
#define ITC_DS_DEVMGR_GETNUMBEROFDEVICES_REMOVE_DEVICE_KEY_I 0x4104002DL

//
// MessageId: ITC_DS_DEVMGR_GETNUMBEROFDEVICES_EXIT_I
//
// MessageText:
//
//  CDeviceInfo::GetNumberOfDevices - Exit. dwNumDevices: %1!d!
//
#define ITC_DS_DEVMGR_GETNUMBEROFDEVICES_EXIT_I 0x4104002EL

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_DS_REMOTE_INIT_S
//
// MessageText:
//
//  DS: Remote Clients Service Init Successful
//
#define ITC_DS_REMOTE_INIT_S             0x01040000L

//
// MessageId: ITC_DS_LOCAL_INIT_S
//
// MessageText:
//
//  DS: Local Clients Service Init Successful
//
#define ITC_DS_LOCAL_INIT_S              0x01040001L

//
// MessageId: ITC_DS_DEVMGR_INIT_S
//
// MessageText:
//
//  DS: Init Successful
//
#define ITC_DS_DEVMGR_INIT_S             0x01040002L

//
// MessageId: ITC_DS_DEVMGR_DEVICE_ADD_S
//
// MessageText:
//
//  DS: Added Dev %1!08X!
//
#define ITC_DS_DEVMGR_DEVICE_ADD_S       0x01040003L

//
// MessageId: ITC_DS_DEVMGR_DEVICE_ACTIVE_S
//
// MessageText:
//
//  DS: Device already active
//
#define ITC_DS_DEVMGR_DEVICE_ACTIVE_S    0x01040004L

//
// MessageId: ITC_DS_DEVCONN_RETRIEVE_BUFFER_RSP_S
//
// MessageText:
//
//  DS: ConnID: %1!08X! retrieved buffered response
//
#define ITC_DS_DEVCONN_RETRIEVE_BUFFER_RSP_S 0x01040005L

//
// MessageId: ITC_DS_INITIALIZE_CONNECTION_S
//
// MessageText:
//
//  DS: Initialize ConnID: %1!08X!
//
#define ITC_DS_INITIALIZE_CONNECTION_S   0x01040006L

//
// MessageId: ITC_DS_CLOSE_CONNECTION_S
//
// MessageText:
//
//  DS: Close ConnID: %1!08X!
//
#define ITC_DS_CLOSE_CONNECTION_S        0x01040007L

//
// MessageId: ITC_DS_DEVCONN_REINITIALIZE_S
//
// MessageText:
//
//  DS: Device: %1!08X! - Reinitialize Conn %2!8X!
//
#define ITC_DS_DEVCONN_REINITIALIZE_S    0x01040008L

//
// MessageId: ITC_DS_ADD_RA_CONNECTION_S
//
// MessageText:
//
//  CDevice::CreateDeviceConnection - Add RA Connection; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_ADD_RA_CONNECTION_S       0x01040009L

//
// MessageId: ITC_DS_ADD_NRA_CONNECTION_S
//
// MessageText:
//
//  CDevice::CreateDeviceConnection - Add NRA Connection; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_ADD_NRA_CONNECTION_S      0x0104000AL

//
// MessageId: ITC_DS_ADD_NON_DATA_CONNECTION_S
//
// MessageText:
//
//  CDevice::CreateDeviceConnection - Add NonData Connection; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_ADD_NON_DATA_CONNECTION_S 0x0104000BL

//
// MessageId: ITC_DS_ADD_CANCEL_CHANNEL_S
//
// MessageText:
//
//  CDevice::CreateDeviceConnection - Add NonData Connection; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_ADD_CANCEL_CHANNEL_S      0x0104000CL

//
// MessageId: ITC_DS_REMOVE_RA_CONNECTION_S
//
// MessageText:
//
//  CDevice::RemoveDeviceConnection - Remove RA Connection; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_REMOVE_RA_CONNECTION_S    0x0104000DL

//
// MessageId: ITC_DS_REMOVE_NRA_CONNECTION_S
//
// MessageText:
//
//  CDevice::RemoveDeviceConnection - Remove NRA Connection; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_REMOVE_NRA_CONNECTION_S   0x0104000EL

//
// MessageId: ITC_DS_REMOVE_NON_DATA_CONNECTION_S
//
// MessageText:
//
//  CDevice::RemoveDeviceConnection - Remove NonData Connection; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_REMOVE_NON_DATA_CONNECTION_S 0x0104000FL

//
// MessageId: ITC_DS_REMOVE_CANCEL_CHANNEL_S
//
// MessageText:
//
//  CDevice::RemoveDeviceConnection - Remove Cancel Channel; Dev: %1!08X!; ConnID: %2!08X!
//
#define ITC_DS_REMOVE_CANCEL_CHANNEL_S   0x01040010L

//Severity=Success
//SymbolicName=ITC_<facility acronym>_<msg name>_S 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Warning
//SymbolicName=ITC_<facility acronym>_<message acronym>_W 
//Language=English
//<message string>
//.
//
// MessageId: ITC_DS_DEVCONN_DISCARD_BUFFER_RESPONSE_W
//
// MessageText:
//
//  DS: ConnID %1!08X! - Discarded %2!d! buffered messages
//
#define ITC_DS_DEVCONN_DISCARD_BUFFER_RESPONSE_W 0x81040000L

//
// MessageId: ITC_DS_BUFFER_POOL_TEMPORARY_FULL_W
//
// MessageText:
//
//  DS: Device: %1!08X! Buffer Pool is temporarily full
//
#define ITC_DS_BUFFER_POOL_TEMPORARY_FULL_W 0x81040001L

//
// MessageId: ITC_DS_NO_AUTO_READ_POST_BUFFER_FULL_W
//
// MessageText:
//
//  DS: ConnID %1!08X! - reached max buffered responses %2!d!, no more read posted
//
#define ITC_DS_NO_AUTO_READ_POST_BUFFER_FULL_W 0x81040002L

//
// MessageId: ITC_DS_COPY_RESPONSE_BUFFER_EXCEPTION_W
//
// MessageText:
//
//  DS: CDevice::CopyResponse - Device thread got Buffer Services exception %1!08X!
//
#define ITC_DS_COPY_RESPONSE_BUFFER_EXCEPTION_W 0x81040003L

//
// MessageId: ITC_DS_GET_REQUEST_OBJECT_FAILED_W
//
// MessageText:
//
//  DS: CDevice::GetRequestObject - Index: %1!d! - State: %2!08X!
//
#define ITC_DS_GET_REQUEST_OBJECT_FAILED_W 0x81040004L

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_DS_CLIENTCONN_WSASTARTUP_E
//
// MessageText:
//
//  DS: WSAStartup failed
//
#define ITC_DS_CLIENTCONN_WSASTARTUP_E   0xC1040000L

//
// MessageId: ITC_DS_CLIENTCONN_CREATE_SOCKET_E
//
// MessageText:
//
//  DS: Create socket failed
//
#define ITC_DS_CLIENTCONN_CREATE_SOCKET_E 0xC1040001L

//
// MessageId: ITC_DS_CLIENTCONN_BIND_SOCKET_E
//
// MessageText:
//
//  DS: Bind socket failed
//
#define ITC_DS_CLIENTCONN_BIND_SOCKET_E  0xC1040002L

//
// MessageId: ITC_DS_CLIENTCONN_LISTEN_SOCKET_E
//
// MessageText:
//
//  DS: Listening for sockets failed
//
#define ITC_DS_CLIENTCONN_LISTEN_SOCKET_E 0xC1040003L

//
// MessageId: ITC_DS_CLIENTCONN_ACCEPT_SOCKET_E
//
// MessageText:
//
//  DS: Accepting remote clients failed
//
#define ITC_DS_CLIENTCONN_ACCEPT_SOCKET_E 0xC1040004L

//
// MessageId: ITC_DS_CLIENTCONN_CLOSE_SOCKET_E
//
// MessageText:
//
//  DS: Close socket failed
//
#define ITC_DS_CLIENTCONN_CLOSE_SOCKET_E 0xC1040005L

//
// MessageId: ITC_DS_CLIENTMGR_CREATE_INITIALIZE_EVENT_E
//
// MessageText:
//
//  DS: Client Mgr creates System initialize event failed. Err: %1!08X!
//
#define ITC_DS_CLIENTMGR_CREATE_INITIALIZE_EVENT_E 0xC1040006L

//
// MessageId: ITC_DS_CLIENTMGR_NULL_DEVMGR_E
//
// MessageText:
//
//  DS: Initialize Client Manager failed, NULL Dev Mgr Ptr
//
#define ITC_DS_CLIENTMGR_NULL_DEVMGR_E   0xC1040007L

//
// MessageId: ITC_DS_CLIENTMGR_ALLOCATE_NEW_LOCAL_CONNECTION_E
//
// MessageText:
//
//  DS: Client Manager failed to allocate new local connection
//
#define ITC_DS_CLIENTMGR_ALLOCATE_NEW_LOCAL_CONNECTION_E 0xC1040008L

//
// MessageId: ITC_DS_CLIENTMGR_ALLOCATE_NEW_REMOTE_CONNECTION_E
//
// MessageText:
//
//  DS: Client Manager failed to allocate new remote connection
//
#define ITC_DS_CLIENTMGR_ALLOCATE_NEW_REMOTE_CONNECTION_E 0xC1040009L

//
// MessageId: ITC_DS_CREATE_REMOTE_THREAD_E
//
// MessageText:
//
//  DS: Create remote clients thread failed
//
#define ITC_DS_CREATE_REMOTE_THREAD_E    0xC104000AL

//
// MessageId: ITC_DS_CREATE_LOCAL_THREAD_E
//
// MessageText:
//
//  DS: Create local clients thread failed
//
#define ITC_DS_CREATE_LOCAL_THREAD_E     0xC104000BL

//
// MessageId: ITC_DS_CREATE_WORKER_THREAD_E
//
// MessageText:
//
//  DS: Can't create worker thread, client: %1!4d!. Err: %2!08X!
//
#define ITC_DS_CREATE_WORKER_THREAD_E    0xC104000CL

//
// MessageId: ITC_DS_LOCAL_INIT_E
//
// MessageText:
//
//  DS: Init Local Clients Service failed
//
#define ITC_DS_LOCAL_INIT_E              0xC104000DL

//
// MessageId: ITC_DS_REMOTE_INIT_E
//
// MessageText:
//
//  DS: Init Remote Clients Service failed
//
#define ITC_DS_REMOTE_INIT_E             0xC104000EL

//
// MessageId: ITC_DS_INIT_E
//
// MessageText:
//
//  DS: Initialize Data Server failed. Data Server exit
//
#define ITC_DS_INIT_E                    0xC104000FL

//
// MessageId: ITC_DS_NULL_NEW_CONNECTION_E
//
// MessageText:
//
//  DS: Can't service client NULL ClientConnection Ptr
//
#define ITC_DS_NULL_NEW_CONNECTION_E     0xC1040010L

//
// MessageId: ITC_DS_CLIENTCONN_INIT_E
//
// MessageText:
//
//  DS: Init Local Connector failed, can't create IPC Server
//
#define ITC_DS_CLIENTCONN_INIT_E         0xC1040011L

//
// MessageId: ITC_DS_CLIENTCONN_NULL_IPC_CHANNEL_E
//
// MessageText:
//
//  DS: Init Client Connection failed, NULL IPC Channel Ptr
//
#define ITC_DS_CLIENTCONN_NULL_IPC_CHANNEL_E 0xC1040012L

//
// MessageId: ITC_DS_CLIENTCONN_NULL_RDBUFFER_PTR_E
//
// MessageText:
//
//  DS: Can't read from IPC %1!08X!, NULL ReadBuffer Ptr
//
#define ITC_DS_CLIENTCONN_NULL_RDBUFFER_PTR_E 0xC1040013L

//
// MessageId: ITC_DS_CLIENTCONN_NULL_BYTESREAD_PTR_E
//
// MessageText:
//
//  DS: Can't read from IPC %1!08X!, NULL BytesRead Ptr
//
#define ITC_DS_CLIENTCONN_NULL_BYTESREAD_PTR_E 0xC1040014L

//
// MessageId: ITC_DS_CLIENTCONN_NULL_WRBUFFER_PTR_E
//
// MessageText:
//
//  DS: Can't write to IPC %1!08X!, NULL WriteBuffer Ptr
//
#define ITC_DS_CLIENTCONN_NULL_WRBUFFER_PTR_E 0xC1040015L

//
// MessageId: ITC_DS_CLIENTCONN_IPC_INCOMPLETE_READ_E
//
// MessageText:
//
//  DS: Incomplete read from IPC Channel %1!08X!.  Err: %2!08X!
//
#define ITC_DS_CLIENTCONN_IPC_INCOMPLETE_READ_E 0xC1040016L

//
// MessageId: ITC_DS_CLIENTCONN_IPC_READ_E
//
// MessageText:
//
//  DS: Read from IPC Channel %1!08X! failed.  Err: %2!08X!
//
#define ITC_DS_CLIENTCONN_IPC_READ_E     0xC1040017L

//
// MessageId: ITC_DS_CLIENTCONN_IPC_WRITE_E
//
// MessageText:
//
//  DS: Write to IPC Channel %1!08X! failed.  Err: %2!08X!
//
#define ITC_DS_CLIENTCONN_IPC_WRITE_E    0xC1040018L

//
// MessageId: ITC_DS_NULL_REQ_BUFFER_PTR_E
//
// MessageText:
//
//  DS: Can't process request, NULL Req Buffer Ptr
//
#define ITC_DS_NULL_REQ_BUFFER_PTR_E     0xC1040019L

//
// MessageId: ITC_DS_NULL_RSP_BUFFER_PTR_E
//
// MessageText:
//
//  DS: Can't process request, NULL Rsp Buffer Ptr
//
#define ITC_DS_NULL_RSP_BUFFER_PTR_E     0xC104001AL

//
// MessageId: ITC_DS_DEVCONN_INVALID_RSP_SIZE_E
//
// MessageText:
//
//  DS: Can't process request, insufficient response buffer size
//
#define ITC_DS_DEVCONN_INVALID_RSP_SIZE_E 0xC104001BL

//
// MessageId: ITC_DS_DEVCONN_QATTR_INVALID_ATTRIBUTE_E
//
// MessageText:
//
//  DS: Query Attribute failed, invalid attribute
//
#define ITC_DS_DEVCONN_QATTR_INVALID_ATTRIBUTE_E 0xC104001CL

//
// MessageId: ITC_DS_DEVCONN_SATTR_INVALID_ATTRIBUTE_E
//
// MessageText:
//
//  DS: Set Attribute failed, invalid attribute
//
#define ITC_DS_DEVCONN_SATTR_INVALID_ATTRIBUTE_E 0xC104001DL

//
// MessageId: ITC_DEVCONN_INVALID_REQUESTED_DATACLASS_E
//
// MessageText:
//
//  DS: Read request failed, invalid data class
//
#define ITC_DEVCONN_INVALID_REQUESTED_DATACLASS_E 0xC104001EL

//
// MessageId: ITC_DS_CLIENTCONN_CREATE_EVENT_E
//
// MessageText:
//
//  DS: Create req/RSP work event failed. Err: %1!08X!
//
#define ITC_DS_CLIENTCONN_CREATE_EVENT_E 0xC104001FL

//
// MessageId: ITC_DS_CLIENTCONN_UNINIT_DEVCONN_E
//
// MessageText:
//
//  DS: Attempt to issue request on unitialized device connection
//
#define ITC_DS_CLIENTCONN_UNINIT_DEVCONN_E 0xC1040020L

//
// MessageId: ITC_DS_CLIENTCONN_INITIALIZED_DEVCONN_E
//
// MessageText:
//
//  DS: Attempt to open device connection twice
//
#define ITC_DS_CLIENTCONN_INITIALIZED_DEVCONN_E 0xC1040021L

//
// MessageId: ITC_DS_DEVCONN_CLOSE_NULL_PTR_E
//
// MessageText:
//
//  DS: Device: %1!08X! Can't close connection, NULL device connection pointer
//
#define ITC_DS_DEVCONN_CLOSE_NULL_PTR_E  0xC1040022L

//
// MessageId: ITC_DS_CLIENTCONN_REQUEST_TIMEOUT_E
//
// MessageText:
//
//  DS: Timeout waiting to submit request to device
//
#define ITC_DS_CLIENTCONN_REQUEST_TIMEOUT_E 0xC1040023L

//
// MessageId: ITC_DS_CLIENTCONN_RESPONSE_TIMEOUT_E
//
// MessageText:
//
//  DS: Timeout waiting for response from device
//
#define ITC_DS_CLIENTCONN_RESPONSE_TIMEOUT_E 0xC1040024L

//
// MessageId: ITC_DS_CLIENTCONN_WAIT_REC_RSP_EVENT_E
//
// MessageText:
//
//  DS: Error waiting for event to receive response from device
//
#define ITC_DS_CLIENTCONN_WAIT_REC_RSP_EVENT_E 0xC1040025L

//
// MessageId: ITC_DS_CLIENTCONN_NULL_COMMUNICATION_BUFFER_PTR_E
//
// MessageText:
//
//  DS: ClientConn can't malloc buffer for communication channel
//
#define ITC_DS_CLIENTCONN_NULL_COMMUNICATION_BUFFER_PTR_E 0xC1040026L

//
// MessageId: ITC_DS_DEVMGR_ALLOCATE_DEVICE_OBJ_E
//
// MessageText:
//
//  DS: Error allocating Device Object memory
//
#define ITC_DS_DEVMGR_ALLOCATE_DEVICE_OBJ_E 0xC1040027L

//
// MessageId: ITC_DS_DEVMGR_DEVICE_HANDLER_LOAD_E
//
// MessageText:
//
//  DS:  Dev %1!08X! Failed to load Device Handler. Err: %2!08X!
//
#define ITC_DS_DEVMGR_DEVICE_HANDLER_LOAD_E 0xC1040028L

//
// MessageId: ITC_DS_DEVMGR_ADD_DEVICE_LIST_E
//
// MessageText:
//
//  DS: Failed to add Device to list
//
#define ITC_DS_DEVMGR_ADD_DEVICE_LIST_E  0xC1040029L

//
// MessageId: ITC_DS_DEVMGR_BUFFER_SERVICE_CREATE_E
//
// MessageText:
//
//  DS: Dev Mgr init failed, can't create Buffer Service.  Err: %1!08X!
//
#define ITC_DS_DEVMGR_BUFFER_SERVICE_CREATE_E 0xC104002AL

//
// MessageId: ITC_DS_DEVMGR_CREATE_DEVCONN_DEVNOTFOUND_E
//
// MessageText:
//
//  DS:  DevMgr can't create connection for invalid device
//
#define ITC_DS_DEVMGR_CREATE_DEVCONN_DEVNOTFOUND_E 0xC104002BL

//
// MessageId: ITC_DS_DEVMGR_CREATE_DEVCONN_NULL_PTR_E
//
// MessageText:
//
//  DS:  DevMgr can't create connection, NULL Connector Ptr
//
#define ITC_DS_DEVMGR_CREATE_DEVCONN_NULL_PTR_E 0xC104002CL

//
// MessageId: ITC_DS_DEVMGR_DELETE_DEVCONN_NULL_PTR_E
//
// MessageText:
//
//  DS:  DevMgr can't delete connection, NULL Connection Ptr
//
#define ITC_DS_DEVMGR_DELETE_DEVCONN_NULL_PTR_E 0xC104002DL

//
// MessageId: ITC_DS_DEVICE_CREATE_BAD_MAX_RA_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - initialize requests more than available RA connections.  Adjusted to: %2!d!
//
#define ITC_DS_DEVICE_CREATE_BAD_MAX_RA_E 0xC104002EL

//
// MessageId: ITC_DS_DEVICE_CREATE_DEVICE_RESPONSE_TOO_BIG_E
//
// MessageText:
//
//  DS: Dev Obj init failed, invalid max device response size %1!d!
//
#define ITC_DS_DEVICE_CREATE_DEVICE_RESPONSE_TOO_BIG_E 0xC104002FL

//
// MessageId: ITC_DS_DEVICE_CREATE_WORK_EVENT_E
//
// MessageText:
//
//  DS: Dev Obj init failed, failed to create event %1!d!
//
#define ITC_DS_DEVICE_CREATE_WORK_EVENT_E 0xC1040030L

//
// MessageId: ITC_DS_DEVICE_ALLOCATE_DEVCONN_E
//
// MessageText:
//
//  DS: Failed to allocate new device connection
//
#define ITC_DS_DEVICE_ALLOCATE_DEVCONN_E 0xC1040031L

//
// MessageId: ITC_DS_DEVICE_CREATE_RSP_THREAD_E
//
// MessageText:
//
//  DS: Dev Obj init failed, can't create dedicated thread. Err: %1!08X!
//
#define ITC_DS_DEVICE_CREATE_RSP_THREAD_E 0xC1040032L

//
// MessageId: ITC_DS_DEVICE_QUERY_RSP_THREAD_STATUS_E
//
// MessageText:
//
//  DS: Dev Obj can't query thread termination status. Err: %1!08X!
//
#define ITC_DS_DEVICE_QUERY_RSP_THREAD_STATUS_E 0xC1040033L

//
// MessageId: ITC_DS_DEVICE_RSP_THREAD_INVALID_DEVPTR_E
//
// MessageText:
//
//  DS: Dev Obj - Response thread received NULL Device Ptr. Thread exits
//
#define ITC_DS_DEVICE_RSP_THREAD_INVALID_DEVPTR_E 0xC1040034L

//
// MessageId: ITC_DS_DEVICE_ADD_DEVCONN_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - Unable to add Device Connection to list
//
#define ITC_DS_DEVICE_ADD_DEVCONN_E      0xC1040035L

//
// MessageId: ITC_DS_DEVICE_MAX_RA_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - Can't log on another RA, max RA already log on
//
#define ITC_DS_DEVICE_MAX_RA_E           0xC1040036L

//
// MessageId: ITC_DS_DEVICE_MAX_NRA_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - Can't log on another NRA, max NRA already log on
//
#define ITC_DS_DEVICE_MAX_NRA_E          0xC1040037L

//
// MessageId: ITC_DS_DEVICE_ALLOCATE_RESPONSE_ENTRY_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - Can't allocate memory for a response list entry.
//
#define ITC_DS_DEVICE_ALLOCATE_RESPONSE_ENTRY_E 0xC1040038L

//
// MessageId: ITC_DS_DEVICE_FREE_RESPONSE_ENTRY_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - Can't free response list entry memory.
//
#define ITC_DS_DEVICE_FREE_RESPONSE_ENTRY_E 0xC1040039L

//
// MessageId: ITC_DS_DEVICE_INVALID_FLAGS_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - Can't create device connection, invalid flag
//
#define ITC_DS_DEVICE_INVALID_FLAGS_E    0xC104003AL

//
// MessageId: ITC_DS_DEVICE_WAIT_BUFFER_POOL_TIMEOUT_W
//
// MessageText:
//
//  DS: Dev Obj - Timeout waiting for buffer pool space
//
#define ITC_DS_DEVICE_WAIT_BUFFER_POOL_TIMEOUT_W 0xC104003BL

//
// MessageId: ITC_DS_DEVCONN_NULL_DEVICE_PTR_E
//
// MessageText:
//
//  DS: DevConn init failed, NULL Device Ptr.
//
#define ITC_DS_DEVCONN_NULL_DEVICE_PTR_E 0xC104003CL

//
// MessageId: ITC_DS_DEVCONN_NULL_REQUEST_PTR_E
//
// MessageText:
//
//  DS: DevConn Process Client request failed, NULL request buffer
//
#define ITC_DS_DEVCONN_NULL_REQUEST_PTR_E 0xC104003DL

//
// MessageId: ITC_DS_DEVCONN_MAX_REQUEST_E
//
// MessageText:
//
//  DS: DevConn %1!08X! Process Client request failed, max pending requests
//
#define ITC_DS_DEVCONN_MAX_REQUEST_E     0xC104003EL

//
// MessageId: ITC_DS_DEVCONN_INVALID_REQUEST_TYPE_E
//
// MessageText:
//
//  DS: DevConn %1!08X! Process Client request failed, invalid type
//
#define ITC_DS_DEVCONN_INVALID_REQUEST_TYPE_E 0xC104003FL

//
// MessageId: ITC_DS_DEVCONN_ALLOCATE_RSP_BUFFER_E
//
// MessageText:
//
//  DS: DevConn failed to allocate response buffer
//
#define ITC_DS_DEVCONN_ALLOCATE_RSP_BUFFER_E 0xC1040040L

//
// MessageId: ITC_DS_DEVCONN_QATTR_NULL_PTR_E
//
// MessageText:
//
//  DS: QueryDataServer Attribute fails, NULL value pointer
//
#define ITC_DS_DEVCONN_QATTR_NULL_PTR_E  0xC1040041L

//
// MessageId: ITC_DS_DEVCONN_QATTR_NULL_LENGTH_PTR_E
//
// MessageText:
//
//  DS: QueryDataServer Attribute fails, NULL attribute length pointer
//
#define ITC_DS_DEVCONN_QATTR_NULL_LENGTH_PTR_E 0xC1040042L

//
// MessageId: ITC_DS_CANCEL_REQUEST_NULL_DEVCONN_E
//
// MessageText:
//
//  DS: CancelRequest fails, NULL Device Connection of cancelled request
//
#define ITC_DS_CANCEL_REQUEST_NULL_DEVCONN_E 0xC1040043L

//
// MessageId: ITC_DS_DEVCONN_FAILED_READ_E
//
// MessageText:
//
//  DS: ConnID %1!08X! Read failed, error: %20x!08X!
//
#define ITC_DS_DEVCONN_FAILED_READ_E     0xC1040044L

//
// MessageId: ITC_DS_DEVCONN_FAILED_WRITE_E
//
// MessageText:
//
//  DS: ConnID %1!08X! Write failed, error: %20x!08X!
//
#define ITC_DS_DEVCONN_FAILED_WRITE_E    0xC1040045L

//
// MessageId: ITC_DS_READ_CANCEL_E
//
// MessageText:
//
//  DS: Read request was cancelled
//
#define ITC_DS_READ_CANCEL_E             0xC1040046L

//
// MessageId: ITC_DS_DEVCONN_DEVICE_REINITIALIZED_E
//
// MessageText:
//
//  DS: ConnID %1!08X! Device is reinitialized
//
#define ITC_DS_DEVCONN_DEVICE_REINITIALIZED_E 0xC1040047L

//
// MessageId: ITC_DS_REQ_COMPLETE_E
//
// MessageText:
//
//  DS: Cancel request failed, request is already completed 
//
#define ITC_DS_REQ_COMPLETE_E            0xC1040048L

//
// MessageId: ITC_DS_REQ_UNIT_E
//
// MessageText:
//
//  DS: Cancel request failed, no outstanding request
//
#define ITC_DS_REQ_UNIT_E                0xC1040049L

//
// MessageId: ITC_DS_NULL_DEVCONN_PTR_E
//
// MessageText:
//
//  DS: Cancel request failed, null DevConn pointer
//
#define ITC_DS_NULL_DEVCONN_PTR_E        0xC104004AL

//
// MessageId: ITC_DS_GRID_NULL_DEVCONN_PTR_E
//
// MessageText:
//
//  DS: Grid initialize failed, null DevConn pointer
//
#define ITC_DS_GRID_NULL_DEVCONN_PTR_E   0xC104004BL

//
// MessageId: ITC_DS_DDGRID_BAD_GRID_BUFFER_E
//
// MessageText:
//
//  DS: Query/Set DD Grid failed, null Grid pointer
//
#define ITC_DS_DDGRID_BAD_GRID_BUFFER_E  0xC104004CL

//
// MessageId: ITC_DS_DDGRID_BAD_LENGTH_BUFFER_E
//
// MessageText:
//
//  DS: Query DD Grid failed, buffer too small
//
#define ITC_DS_DDGRID_BAD_LENGTH_BUFFER_E 0xC104004DL

//
// MessageId: ITC_DS_DIGRID_INVALID_LENGTH_E
//
// MessageText:
//
//  DS: Set DI Grid failed, new grid too big
//
#define ITC_DS_DIGRID_INVALID_LENGTH_E   0xC104004EL

//
// MessageId: ITC_DS_DIGRID_BAD_INPUT_PTR_E
//
// MessageText:
//
//  DS: Set DI Grid failed, bad reason buffer pointer
//
#define ITC_DS_DIGRID_BAD_INPUT_PTR_E    0xC104004FL

//
// MessageId: ITC_DS_DIGRID_BAD_GRID_BUFFER_E
//
// MessageText:
//
//  DS: Query/Set DI Grid failed, bad Grid Buffer
//
#define ITC_DS_DIGRID_BAD_GRID_BUFFER_E  0xC1040050L

//
// MessageId: ITC_DS_DIGRID_BAD_LENGTH_BUFFER_E
//
// MessageText:
//
//  DS: Query DI Grid failed, buffer too small
//
#define ITC_DS_DIGRID_BAD_LENGTH_BUFFER_E 0xC1040051L

//
// MessageId: ITC_DS_GRID_ALLOCATE_DDMASK_E
//
// MessageText:
//
//  DS: Set DD Grid failed, allocate buffer for new mask
//
#define ITC_DS_GRID_ALLOCATE_DDMASK_E    0xC1040052L

//
// MessageId: ITC_DS_GRID_NULL_LENGTH_PTR_E
//
// MessageText:
//
//  DS: Query Grid failed, NULL grid length pointer
//
#define ITC_DS_GRID_NULL_LENGTH_PTR_E    0xC1040053L

//
// MessageId: ITC_DS_DATACLASS_RA_ALREADY_SET_E
//
// MessageText:
//
//  DS: Set DataClass for RA client failed, data class already set
//
#define ITC_DS_DATACLASS_RA_ALREADY_SET_E 0xC1040054L

//
// MessageId: ITC_DS_GRID_DATACLASS_NULL_E
//
// MessageText:
//
//  DS: Query/Set DataClass failed, NULL DataClass Action pointer
//
#define ITC_DS_GRID_DATACLASS_NULL_E     0xC1040055L

//
// MessageId: ITC_DS_MULTI_CLIENT_FLAG_ALREADY_SET_E
//
// MessageText:
//
//  DS: MultiClient flag is already set once.
//
#define ITC_DS_MULTI_CLIENT_FLAG_ALREADY_SET_E 0xC1040056L

//
// MessageId: ITC_DS_REQUEST_ALREADY_EXECUTED_E
//
// MessageText:
//
//  DS: Cancel request failed, request already executed
//
#define ITC_DS_REQUEST_ALREADY_EXECUTED_E 0xC1040057L

//
// MessageId: ITC_DS_DEVICE_INITIALIZE_E
//
// MessageText:
//
//  DS: Dev: %1!08X! failed to initialize - failed to load DevHandler/BufferServices?
//
#define ITC_DS_DEVICE_INITIALIZE_E       0xC1040058L

//
// MessageId: ITC_DS_DEVICE_THREAD_GET_EXCEPTION_E
//
// MessageText:
//
//  DS: Dev: %1!08X! thread received exception code %2!08X!
//
#define ITC_DS_DEVICE_THREAD_GET_EXCEPTION_E 0xC1040059L

//
// MessageId: ITC_DS_DEVCONN_NO_PENDING_REQUEST_E
//
// MessageText:
//
//  DS: Conn: %1!08X! received a response for DataClass %2!08X! but no outstanding request.
//
#define ITC_DS_DEVCONN_NO_PENDING_REQUEST_E 0xC104005AL

//
// MessageId: ITC_DS_DEVCONN_DISTRIBUTE_RESPONSE_E
//
// MessageText:
//
//  DS: Conn: %1!08X! can't return response to client - Error: %2!08X!
//
#define ITC_DS_DEVCONN_DISTRIBUTE_RESPONSE_E 0xC104005BL

//
// MessageId: ITC_DS_ACCEPT_NEWCONN_ALLOC_E
//
// MessageText:
//
//  DS: CClientManager::AcceptConnectionThread unable to allocate memory for new CONNECTION_INFO
//
#define ITC_DS_ACCEPT_NEWCONN_ALLOC_E    0xC104005CL

//
// MessageId: ITC_DS_DEVICE_MAX_NON_DATA_CONNECTIONS_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - Can't log on another Non Data Collection, max NDC already log on
//
#define ITC_DS_DEVICE_MAX_NON_DATA_CONNECTIONS_E 0xC104005DL

//
// MessageId: ITC_DS_DEVICE_MAX_CANCEL_CONNECTIONS_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - Can't log on another Cancel Connections, max CANCEL connections already log on
//
#define ITC_DS_DEVICE_MAX_CANCEL_CONNECTIONS_E 0xC104005EL

//
// MessageId: ITC_DS_DEVICE_CREATE_BAD_MAX_NON_DATA_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - initialize requests more than available Non Data connections.  Adjusted to: %2!d!
//
#define ITC_DS_DEVICE_CREATE_BAD_MAX_NON_DATA_E 0xC104005FL

//
// MessageId: ITC_DS_DEVICE_CREATE_BAD_MAX_CANCEL_E
//
// MessageText:
//
//  DS: Dev: %1!08X! - initialize requests more than available Cancel connections.  Adjusted to: %2!d!
//
#define ITC_DS_DEVICE_CREATE_BAD_MAX_CANCEL_E 0xC1040060L

//
// MessageId: ITC_DEVCONN_READ_NON_DATA_E
//
// MessageText:
//
//  DS: Can't process read request using non-data connection
//
#define ITC_DEVCONN_READ_NON_DATA_E      0xC1040061L

//
// MessageId: ITC_DEVCONN_CANCEL_READ_NON_DATA_E
//
// MessageText:
//
//  DS: Can't process cancel read request on non-data connection
//
#define ITC_DEVCONN_CANCEL_READ_NON_DATA_E 0xC1040062L

//
// MessageId: ITC_DSDEV_DATA_LOST_E
//
// MessageText:
//
//  CDevice::DistributeResponse - DATA LOST! Grid did not match any client app
//
#define ITC_DSDEV_DATA_LOST_E            0xC1040063L

#endif
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCDataServer.mcs
//  COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCEventLog.mcs
//
//  AUTHOR:     J. Hunt
//
// COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_ITCEVENTLOG_MSG
#define INCLUDED_ITCEVENTLOG_MSG
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Informational
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_I 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_EVTLOG_INIT_S
//
// MessageText:
//
//  Event Log Init Successful
//
#define ITC_EVTLOG_INIT_S                0x01030000L

//
// MessageId: ITC_EVTLOG_S
//
// MessageText:
//
//  Success
//
#define ITC_EVTLOG_S                     0x01030001L

//Severity=Success
//SymbolicName=ITC_<facility acronym>_<msg name>_S 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Warning
//SymbolicName=ITC_<facility acronym>_<message acronym>_W 
//Language=English
//<message string>
//.
//
// MessageId: ITC_EVTLOG_NO_MORE_EVENTS_W
//
// MessageText:
//
//  No more events in queue
//
#define ITC_EVTLOG_NO_MORE_EVENTS_W      0x81030000L

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_EVTLOG_MAPVIEWOFFILE_E
//
// MessageText:
//
//  EVTLOG: MapViewOfFile Failed during init
//
#define ITC_EVTLOG_MAPVIEWOFFILE_E       0xC1030000L

//
// MessageId: ITC_EVTLOG_CREATEFILEMAPPING_E
//
// MessageText:
//
//  EVTLOG: CreateFileMapping failed.
//
#define ITC_EVTLOG_CREATEFILEMAPPING_E   0xC1030001L

//
// MessageId: ITC_EVTLOG_INVSEVMASK_E
//
// MessageText:
//
//  Invalid Severity Mask
//
#define ITC_EVTLOG_INVSEVMASK_E          0xC1030002L

//
// MessageId: ITC_EVTLOG_INVNUM_FACILITIES_E
//
// MessageText:
//
//  Invalid number of facilities filters
//
#define ITC_EVTLOG_INVNUM_FACILITIES_E   0xC1030003L

//
// MessageId: ITC_EVTLOG_INVNUM_EVENTS_E
//
// MessageText:
//
//  Invalid number of event filters
//
#define ITC_EVTLOG_INVNUM_EVENTS_E       0xC1030004L

//
// MessageId: ITC_EVTLOG_INVFACILITY_VALUE_E
//
// MessageText:
//
//  Invalid facility value
//
#define ITC_EVTLOG_INVFACILITY_VALUE_E   0xC1030005L

//
// MessageId: ITC_EVTLOG_EVTBUFF_TOOSMALL_E
//
// MessageText:
//
//  Event buffer too small
//
#define ITC_EVTLOG_EVTBUFF_TOOSMALL_E    0xC1030006L

//
// MessageId: ITC_EVTLOG_FACBUFF_TOOSMALL_E
//
// MessageText:
//
//  Facility buffer too small
//
#define ITC_EVTLOG_FACBUFF_TOOSMALL_E    0xC1030007L

//
// MessageId: ITC_EVTLOG_INPUTBUFFER_E
//
// MessageText:
//
//  Input buffer too small
//
#define ITC_EVTLOG_INPUTBUFFER_E         0xC1030008L

//
// MessageId: ITC_EVTLOG_CREATEEVENT_E
//
// MessageText:
//
//  Failed to create an event synchronization object
//
#define ITC_EVTLOG_CREATEEVENT_E         0xC1030009L

//
// MessageId: ITC_EVTLOG_CREATEMUTEX_E
//
// MessageText:
//
//  Failed to create a mutex
//
#define ITC_EVTLOG_CREATEMUTEX_E         0xC103000AL

//
// MessageId: ITC_EVTLOG_PUT_LOCKED_E
//
// MessageText:
//
//  The log is locked for too long 
//
#define ITC_EVTLOG_PUT_LOCKED_E          0xC103000BL

//
// MessageId: ITC_EVTLOG_MUTEX_AQUIRE_E
//
// MessageText:
//
//  Unable to acquire the event log mutex
//
#define ITC_EVTLOG_MUTEX_AQUIRE_E        0xC103000CL

//
// MessageId: ITC_EVTLOG_INVALIDEVENTTYPE_E
//
// MessageText:
//
//  Invalid event type specified
//
#define ITC_EVTLOG_INVALIDEVENTTYPE_E    0xC103000DL

//MessageId=
//SymbolicName=ITC_EVTLOG_<msg name>_E 
//Language=English
//<message string>
//.
#endif
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCEventLog.mcs
//  COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCIPCPipe.mcs
//
//  AUTHOR:
//
// COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_ITCIPCPIPE_MCS
#define INCLUDED_ITCIPCPIPE_MCS
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_IPC_CONSTRUCTOR_I
//
// MessageText:
//
//  IPC Service Object constructor. pUnknownOuter = %1!08X!
//
#define ITC_IPC_CONSTRUCTOR_I            0x41360000L

//
// MessageId: ITC_IPC_DESTRUCTOR_I
//
// MessageText:
//
//  IPC Service Object destructor
//
#define ITC_IPC_DESTRUCTOR_I             0x41360001L

//
// MessageId: ITC_IPC_CREATEINSTANCE_I
//
// MessageText:
//
//  ITCIPC::CreateInstance
//
#define ITC_IPC_CREATEINSTANCE_I         0x41360002L

//
// MessageId: ITC_IPC_NONDELEGATINGQUERYINTERFACE_I
//
// MessageText:
//
//  ITCIPC::NondelegatingQueryInterface
//
#define ITC_IPC_NONDELEGATINGQUERYINTERFACE_I 0x41360003L

//
// MessageId: ITC_IPC_INITIALIZESERVER_I
//
// MessageText:
//
//  CIPCService::InitializeServer
//
#define ITC_IPC_INITIALIZESERVER_I       0x41360004L

//
// MessageId: ITC_IPC_INITIALIZECLIENT_I
//
// MessageText:
//
//  ITCIPC - THIS EVENT CODE IS NOT TO BE USED!
//
#define ITC_IPC_INITIALIZECLIENT_I       0x41360005L

//
// MessageId: ITC_IPC_CLIENT_CONNECTED
//
// MessageText:
//
//  CIPCService::Accept
//
#define ITC_IPC_CLIENT_CONNECTED         0x41360006L

//
// MessageId: ITC_IPC_CLIENT_DISCONNECTED
//
// MessageText:
//
//  CIPCService::Accept - Client disconnected
//
#define ITC_IPC_CLIENT_DISCONNECTED      0x41360007L

//
// MessageId: ITC_IPC_CHANNEL_CLOSED
//
// MessageText:
//
//  CIPCChannel::Close - Client disconnected. Channel ID = %1!d!
//
#define ITC_IPC_CHANNEL_CLOSED           0x41360008L

//
// MessageId: ITC_IPC_SERVER_CONNECT_I
//
// MessageText:
//
//  CIPCServer::Accept - Client connected. Channel ID = %1!d!
//
#define ITC_IPC_SERVER_CONNECT_I         0x41360009L

//
// MessageId: ITC_IPC_SERVER_DISCONNECT_I
//
// MessageText:
//
//  CIPCServer::Accept - Client disconnected. Channel ID = %1!d!
//
#define ITC_IPC_SERVER_DISCONNECT_I      0x4136000AL

//
// MessageId: ITC_IPC_DEBUG_I
//
// MessageText:
//
//  ITCIPC Debug. %1!d! %2!d!
//
#define ITC_IPC_DEBUG_I                  0x4136000BL

//
// MessageId: ITC_IPC_CHANNELREAD_I
//
// MessageText:
//
//  CIPCChannel::Read Entry Buffer: 0x%1!08X!; Thread: 0x%2!08X!
//
#define ITC_IPC_CHANNELREAD_I            0x4136000CL

//
// MessageId: ITC_IPC_CHANNELWRITE_I
//
// MessageText:
//
//  CIPCChannel::Write Entry Buffer: 0x%1!08X!; Thread: 0x%2!08X!
//
#define ITC_IPC_CHANNELWRITE_I           0x4136000DL

//MessageId=
//SymbolicName=ITC_<facility acronym>_<msg name>_I 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Success
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_S 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Warning
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<message acronym>_W 
//Language=English
//<message string>
//.
//
// MessageId: ITC_IPC_EVENT_WAIT_TIMEOUT
//
// MessageText:
//
//  CIPCService::Event Wait Timeout
//
#define ITC_IPC_EVENT_WAIT_TIMEOUT       0x8136000EL

//
// MessageId: ITC_IPC_MUTEX_WAIT_TIMEOUT
//
// MessageText:
//
//  CIPCService::Mutex Wait Timeout
//
#define ITC_IPC_MUTEX_WAIT_TIMEOUT       0x8136000FL

//
// MessageId: ITC_IPC_BUFFER_TOO_SMALL
//
// MessageText:
//
//  CIPCService::Buffer too small
//
#define ITC_IPC_BUFFER_TOO_SMALL         0x81360010L

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_IPC_NAMETOOLONG_E
//
// MessageText:
//
//  CIPCService Name too long
//
#define ITC_IPC_NAMETOOLONG_E            0xC1360000L

//
// MessageId: ITC_IPC_SHAREDMEMALLOCFAILURE_E
//
// MessageText:
//
//  CIPCService Shared Memory Failure 
//
#define ITC_IPC_SHAREDMEMALLOCFAILURE_E  0xC1360001L

//
// MessageId: ITC_IPC_DUPLICATENAME_E
//
// MessageText:
//
//  CIPCService Already a service named
//
#define ITC_IPC_DUPLICATENAME_E          0xC1360002L

//
// MessageId: ITC_IPC_MEMORY_ALLOCATION_FAILURE
//
// MessageText:
//
//  CIPCService::Initialize - Memory Allocation error: %1!08X! 
//
#define ITC_IPC_MEMORY_ALLOCATION_FAILURE 0xC1360003L

//
// MessageId: ITC_IPC_EVENT_CREATE_FAILURE
//
// MessageText:
//
//  CIPCService::Initialize - CreateEvent error: %1!08X! 
//
#define ITC_IPC_EVENT_CREATE_FAILURE     0xC1360004L

//
// MessageId: ITC_IPC_EVENT_SET_FAILURE
//
// MessageText:
//
//  CIPCService::Initialize - SetEvent error: %1!08X! 
//
#define ITC_IPC_EVENT_SET_FAILURE        0xC1360005L

//
// MessageId: ITC_IPC_EVENT_WAIT_FAILURE
//
// MessageText:
//
//  CIPCService::Initialize - WaitForSingleObject error: %1!08X!
//
#define ITC_IPC_EVENT_WAIT_FAILURE       0xC1360006L

//
// MessageId: ITC_IPC_MUTEX_CREATE_FAILURE
//
// MessageText:
//
//  CIPCService::Initialize -  CreateMutex error: %1!08X!
//
#define ITC_IPC_MUTEX_CREATE_FAILURE     0xC1360007L

//
// MessageId: ITC_IPC_MUTEX_OPEN_FAILURE
//
// MessageText:
//
//  ITCIPC - THIS EVENT CODE IS NOT TO BE USED!
//
#define ITC_IPC_MUTEX_OPEN_FAILURE       0xC1360008L

//
// MessageId: ITC_IPC_MUTEX_WAIT_FAILURE
//
// MessageText:
//
//  ITCIPC - Mutex WaitForSignleObject error: %1!08X!
//
#define ITC_IPC_MUTEX_WAIT_FAILURE       0xC1360009L

//
// MessageId: ITC_IPC_TRANSFER_ABORTED
//
// MessageText:
//
//  CIPCChannel Write or Read.  Transfer Aborted
//
#define ITC_IPC_TRANSFER_ABORTED         0xC136000AL

//
// MessageId: ITC_IPC_NOSUCHNAME_E
//
// MessageText:
//
//  CIPCService::Initialize error: Invalid pszServiceName
//
#define ITC_IPC_NOSUCHNAME_E             0xC136000BL

//
// MessageId: ITC_IPC_NO_FREE_CHANNELS
//
// MessageText:
//
//  CIPCChannelDirectory :: RingAChannel error: No Free Channels
//
#define ITC_IPC_NO_FREE_CHANNELS         0xC136000CL

//
// MessageId: ITC_IPC_INCORRECT_CHANNEL
//
// MessageText:
//
//  CIPCChannelDirectory::DisconnectChannel.  Invalid channel: %1!08X!
//
#define ITC_IPC_INCORRECT_CHANNEL        0xC136000DL

//
// MessageId: ITC_IPC_INVALID_WRITE_ACCESS_E
//
// MessageText:
//
//  CIPCChannel::Read - Unable to write to input buffer - %1!08X! 
//
#define ITC_IPC_INVALID_WRITE_ACCESS_E   0xC136000EL

//
// MessageId: ITC_IPC_INVALID_READ_ACCESS
//
// MessageText:
//
//  ITCIPC - THIS EVENT CODE IS NOT TO BE USED!
//
#define ITC_IPC_INVALID_READ_ACCESS      0xC136000FL

//
// MessageId: ITC_IPC_INVNUM_CHNLLISTS_E
//
// MessageText:
//
//  CIPCChannelDirectory::CheckListIntegrity - List Number mismatch: Counted: %1!d!; Expected %2!d!
//
#define ITC_IPC_INVNUM_CHNLLISTS_E       0xC1360010L

//
// MessageId: ITC_IPC_FREE_LIST_E
//
// MessageText:
//
//  CIPCChannelDirectory::CheckOneList - Free List Corrupted
//
#define ITC_IPC_FREE_LIST_E              0xC1360011L

//
// MessageId: ITC_IPC_RINGING_LIST_E
//
// MessageText:
//
//  CIPCChannelDirectory::CheckOneList - Ringing List Corrupted
//
#define ITC_IPC_RINGING_LIST_E           0xC1360012L

//
// MessageId: ITC_IPC_CONNECTED_LIST_E
//
// MessageText:
//
//  CIPCChannelDirectory::CheckOneList - Connected List Corrupted
//
#define ITC_IPC_CONNECTED_LIST_E         0xC1360013L

//
// MessageId: ITC_IPC_CONNCHNL_INCORRECT_CHANNEL
//
// MessageText:
//
//  CIPCChannelDirectory::ConnectChannel.  Invalid channel: %1!08X!
//
#define ITC_IPC_CONNCHNL_INCORRECT_CHANNEL 0xC1360014L

//
// MessageId: ITC_IPC_CHNLWAKEUP_ALLOCATION_E
//
// MessageText:
//
//  CIPCServer::Initialize - unable to allocate memory for %1!d! event handles.
//
#define ITC_IPC_CHNLWAKEUP_ALLOCATION_E  0xC1360015L

//
// MessageId: ITC_IPC_SERVICE_ALREADY_INIT_E
//
// MessageText:
//
//  CIPCServer::Initialize - Service already initialized.
//
#define ITC_IPC_SERVICE_ALREADY_INIT_E   0xC1360016L

//
// MessageId: ITC_IPC_SERVICE_NOT_INIT_E
//
// MessageText:
//
//  CIPCServer - Connect or Accept:  Service not initialized
//
#define ITC_IPC_SERVICE_NOT_INIT_E       0xC1360017L

//
// MessageId: ITC_IPC_SERVICE_CANT_CREATE_DISCON_EVENT_E
//
// MessageText:
//
//  CIPCChannel::ClientSideChannelClose - Error creating disconnect event: 0x%1!08X!
//
#define ITC_IPC_SERVICE_CANT_CREATE_DISCON_EVENT_E 0xC1360018L

//
// MessageId: ITC_IPC_INVALID_READ_ACCESS_E
//
// MessageText:
//
//  CIPCChannel::Write - Unable to read input buffer - %1!08X! 
//
#define ITC_IPC_INVALID_READ_ACCESS_E    0xC1360019L

#endif  // THIS LINE MUST BE AFTER ANY MESSAGE DEFINITIONS.
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCIPCPipe.mcs
//  COPYRIGHT (c) 1997 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCUtilities.mcs
//
//  AUTHOR:
//
// $log$
// COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_ITCUTILITIES_MCS
#define INCLUDED_ITCUTILITIES_MCS
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Informational
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_I 
//Language=English
//<message string>
//.
//
// MessageId: ITC_UTIL_TAKING_SNAPSHOT_I
//
// MessageText:
//
//  CProcessSearch::Constructor: %1!08X!
//
#define ITC_UTIL_TAKING_SNAPSHOT_I       0x412E0000L

//
// MessageId: ITC_UTIL_PROCESS_ENTRY_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::Find(), Entry: %1!08X!
//
#define ITC_UTIL_PROCESS_ENTRY_I         0x412E0001L

//
// MessageId: ITC_UTIL_PROCESS_EXIT_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::Find(), Exit: %1!08X!
//
#define ITC_UTIL_PROCESS_EXIT_I          0x412E0002L

//
// MessageId: ITC_UTIL_BEGIN_SEARCH_ENTRY_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::BeginSearch(), Entry. : %1!08X!
//
#define ITC_UTIL_BEGIN_SEARCH_ENTRY_I    0x412E0003L

//
// MessageId: ITC_UTIL_BEGIN_SEARCH_EXIT_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::BeginSearch(), Exit. : %1!08X!
//
#define ITC_UTIL_BEGIN_SEARCH_EXIT_I     0x412E0004L

//
// MessageId: ITC_UTIL_INITIALIZE_PROCESS_LIST_ENTRY_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::InitializeProcessList(), Entry. : %1!08X!
//
#define ITC_UTIL_INITIALIZE_PROCESS_LIST_ENTRY_I 0x412E0005L

//
// MessageId: ITC_UTIL_INITIALIZE_PROCESS_LIST_EXIT_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::InitializeProcessList(), Entry. : %1!08X!
//
#define ITC_UTIL_INITIALIZE_PROCESS_LIST_EXIT_I 0x412E0006L

//
// MessageId: ITC_UTIL_FOUNDIT_ENTRY_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::FoundIt(), Entry. : %1!08X!
//
#define ITC_UTIL_FOUNDIT_ENTRY_I         0x412E0007L

//
// MessageId: ITC_UTIL_FOUNDIT_EXIT_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::FoundIt(), Exit. : %1!08X!
//
#define ITC_UTIL_FOUNDIT_EXIT_I          0x412E0008L

//
// MessageId: ITC_UTIL_SNAPSHOTPROCESSLIST_ENTRY_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::SnapshotProcessList(), Entry. : %1!08X!
//
#define ITC_UTIL_SNAPSHOTPROCESSLIST_ENTRY_I 0x412E0009L

//
// MessageId: ITC_UTIL_SNAPSHOTPROCESSLIST_EXIT_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::SnapshotProcessList(), Exit. : %1!08X!
//
#define ITC_UTIL_SNAPSHOTPROCESSLIST_EXIT_I 0x412E000AL

//
// MessageId: ITC_UTIL_HANDLESEARCHERROR_ENTRY_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::HandleSearchError(), Entry. : %1!08X!
//
#define ITC_UTIL_HANDLESEARCHERROR_ENTRY_I 0x412E000BL

//
// MessageId: ITC_UTIL_HANDLESEARCHERROR_EXIT_I
//
// MessageText:
//
//  CProcessSearch::CProcessSearch::HandleSearchError(), Exit. : %1!08X!
//
#define ITC_UTIL_HANDLESEARCHERROR_EXIT_I 0x412E000CL

//
// MessageId: ITC_UTIL_IVAPAL_DLLLOAD_I
//
// MessageText:
//
//  LoadIVAPAL loading PAL
//
#define ITC_UTIL_IVAPAL_DLLLOAD_I        0x412E000DL

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_UTIL_S
//
// MessageText:
//
//  Success
//
#define ITC_UTIL_S                       0x012E0000L

//MessageId=0
//Severity=Success
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_S 
//Language=English
//<message string>
//.
//
// MessageId: ITC_UTIL_PROCESS_FOUND_IN_FIRST_ENTRY_S
//
// MessageText:
//
//  CProcessSearch::Process was found in first entry: %1!08X!
//
#define ITC_UTIL_PROCESS_FOUND_IN_FIRST_ENTRY_S 0x012E0001L

//
// MessageId: ITC_UTIL_PROCESS_FOUND_S
//
// MessageText:
//
//  CProcessSearch::Process was found in subsequent call: %1!08X!
//
#define ITC_UTIL_PROCESS_FOUND_S         0x012E0002L

////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Warning
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<message acronym>_W 
//Language=English
//<message string>
//.
//
// MessageId: ITC_UTIL_PROCESS_NOT_FOUND_W
//
// MessageText:
//
//  CProcessSearch::Process not found: %1!08X!
//
#define ITC_UTIL_PROCESS_NOT_FOUND_W     0x812E0000L

//
// MessageId: ITC_UTIL_IVAPAL_DLLLOAD_W
//
// MessageText:
//
//  LoadIVAPAL using debug DLL
//
#define ITC_UTIL_IVAPAL_DLLLOAD_W        0x812E0001L

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_UTIL_INPUTBUFFER_E
//
// MessageText:
//
//  Input buffer size too small
//
#define ITC_UTIL_INPUTBUFFER_E           0xC12E0000L

//
// MessageId: ITC_UTIL_MAPVIEWOFFILE_E
//
// MessageText:
//
//  CSharedMemory::CreateSharedAccess - MapViewOfFile Failed during init.  Error: %1!08X!
//
#define ITC_UTIL_MAPVIEWOFFILE_E         0xC12E0001L

//
// MessageId: ITC_UTIL_CREATEFILEMAPPING_E
//
// MessageText:
//
//  CSharedMemory::CreateSharedAccess - CreateFileMapping failed. Error: %1!08X!
//
#define ITC_UTIL_CREATEFILEMAPPING_E     0xC12E0002L

//
// MessageId: ITC_UTIL_KEYSTOOLARGE_E
//
// MessageText:
//
//  SetKeyAndValue error: szKey + szSubKey too large.
//
#define ITC_UTIL_KEYSTOOLARGE_E          0xC12E0003L

//
// MessageId: ITC_UTIL_REGSETVALUEEX_E
//
// MessageText:
//
//  SetKeyAndValue error: RegSetValueEx failed.  Error: %1!08X!
//
#define ITC_UTIL_REGSETVALUEEX_E         0xC12E0004L

//
// MessageId: ITC_UTIL_REGCREATEKEYEX_E
//
// MessageText:
//
//  SetKeyAndValue error: RegCreateKeyEx failed.  Error: %1!08X!
//
#define ITC_UTIL_REGCREATEKEYEX_E        0xC12E0005L

//
// MessageId: ITC_UTIL_CLSID_TOOLONG_E
//
// MessageText:
//
//  CLSIDtochar error - CSLID too long.
//
#define ITC_UTIL_CLSID_TOOLONG_E         0xC12E0006L

//
// MessageId: ITC_UTIL_STRINGFROMCLSID_E
//
// MessageText:
//
//  CLSIDtochar error - StringFromCLSID() failed. Error: %1!08X!
//
#define ITC_UTIL_STRINGFROMCLSID_E       0xC12E0007L

//
// MessageId: ITC_UTIL_REGOPENKEYEX_E
//
// MessageText:
//
//  RecursiveDeleteKey error: RegOpenKeyEx() failed.  Error: %1!08X!
//
#define ITC_UTIL_REGOPENKEYEX_E          0xC12E0008L

//
// MessageId: ITC_UTIL_REGDELETEKEY_E
//
// MessageText:
//
//  RecursiveDeleteKey error: RegDeleteKey() failed. Error: %1!08X!
//
#define ITC_UTIL_REGDELETEKEY_E          0xC12E0009L

//
// MessageId: ITC_UTIL_REGCREATE_E
//
// MessageText:
//
//  CRegistry::Create error: 0x%1!08X!
//
#define ITC_UTIL_REGCREATE_E             0xC12E000AL

//
// MessageId: ITC_UTIL_REGSETVALUE_E
//
// MessageText:
//
//  CRegistry::SetValue error: RegSetValueEx() failed. Error: %1!08X!
//
#define ITC_UTIL_REGSETVALUE_E           0xC12E000BL

//
// MessageId: ITC_UTIL_REGQUERYVALUE_E
//
// MessageText:
//
//  CRegistry::QueryValue error: RegQueryValueEx Error: %1!08X!
//
#define ITC_UTIL_REGQUERYVALUE_E         0xC12E000CL

//
// MessageId: ITC_UTIL_REGQUERYVALUE_INVTYPE_E
//
// MessageText:
//
//  CRegistry::QueryValue error: String registry value expected.  Value type: 0x%1!08X!
//
#define ITC_UTIL_REGQUERYVALUE_INVTYPE_E 0xC12E000DL

//
// MessageId: ITC_UTIL_REGOPEN_E
//
// MessageText:
//
//  CRegistry::Open error: 0x%1!08X!
//
#define ITC_UTIL_REGOPEN_E               0xC12E000EL

//
// MessageId: ITC_UTIL_REGENUMVAL_E
//
// MessageText:
//
//  CRegistry::EnumStringValue error: 0x%1!08X!
//
#define ITC_UTIL_REGENUMVAL_E            0xC12E000FL

//
// MessageId: ITC_UTIL_INVALID_LIST_ELEMENT_E
//
// MessageText:
//
//  CPlex::Invalid list elements count
//
#define ITC_UTIL_INVALID_LIST_ELEMENT_E  0xC12E0010L

//
// MessageId: ITC_UTIL_INVALID_BLOCK_SIZE_E
//
// MessageText:
//
//  CPtrList::Invalid list block size
//
#define ITC_UTIL_INVALID_BLOCK_SIZE_E    0xC12E0011L

//
// MessageId: ITC_UTIL_INVALID_LIST_PTR_E
//
// MessageText:
//
//  CPtrList::List Pointer corrupted
//
#define ITC_UTIL_INVALID_LIST_PTR_E      0xC12E0012L

//
// MessageId: ITC_UTIL_INVALID_LIST_INDEX_E
//
// MessageText:
//
//  CPtrList::Invalid List index
//
#define ITC_UTIL_INVALID_LIST_INDEX_E    0xC12E0013L

//
// MessageId: ITC_UTIL_INVALID_HEAD_NODE_E
//
// MessageText:
//
//  CPtrList::InsertBefore - Invalid Head Node
//
#define ITC_UTIL_INVALID_HEAD_NODE_E     0xC12E0014L

//
// MessageId: ITC_UTIL_INVALID_TAIL_NODE_E
//
// MessageText:
//
//  CPtrList::InsertAfter - Invalid Tail Node
//
#define ITC_UTIL_INVALID_TAIL_NODE_E     0xC12E0015L

//
// MessageId: ITC_UTIL_INVALID_NODE_FREE_E
//
// MessageText:
//
//  CPtrList::NewNode - Invalid Node Free
//
#define ITC_UTIL_INVALID_NODE_FREE_E     0xC12E0016L

//
// MessageId: ITC_UTIL_INVALID_COUNT_E
//
// MessageText:
//
//  CPtrList::NewNode - Invalid Count
//
#define ITC_UTIL_INVALID_COUNT_E         0xC12E0017L

//
// MessageId: ITC_UTIL_LIST_NOT_EMPTY_E
//
// MessageText:
//
//  CPtrList::RemoveAll - List is not empty 
//
#define ITC_UTIL_LIST_NOT_EMPTY_E        0xC12E0018L

//
// MessageId: ITC_UTIL_LIST_EMPTY_E
//
// MessageText:
//
//  CPtrList::Remove - List is empty 
//
#define ITC_UTIL_LIST_EMPTY_E            0xC12E0019L

//
// MessageId: ITC_UTIL_INVALID_NEWLIST_PTR_E
//
// MessageText:
//
//  CPtrNewList::New List Pointer corrupted
//
#define ITC_UTIL_INVALID_NEWLIST_PTR_E   0xC12E001AL

//
// MessageId: ITC_UTIL_LED_CREATEFILE_E
//
// MessageText:
//
//  CLed::CLed - Unable to open LED Device Driver.  Error: 0x%1!08X! 
//
#define ITC_UTIL_LED_CREATEFILE_E        0xC12E001BL

//
// MessageId: ITC_UTIL_LED_CLEAR_DV_E
//
// MessageText:
//
//  CLed::ClearDataValidLed Error: 0x%1!08X! 
//
#define ITC_UTIL_LED_CLEAR_DV_E          0xC12E001CL

//
// MessageId: ITC_UTIL_LED_CLEAR_GR_E
//
// MessageText:
//
//  CLed::ClearGoodReadLed Error: 0x%1!08X! 
//
#define ITC_UTIL_LED_CLEAR_GR_E          0xC12E001DL

//
// MessageId: ITC_UTIL_LED_SET_DV_E
//
// MessageText:
//
//  CLed::SetDataValidLed Error: 0x%1!08X! 
//
#define ITC_UTIL_LED_SET_DV_E            0xC12E001EL

//
// MessageId: ITC_UTIL_LED_SET_GR_E
//
// MessageText:
//
//  CLed::SetGoodReadLed Error: 0x%1!08X! 
//
#define ITC_UTIL_LED_SET_GR_E            0xC12E001FL

//
// MessageId: ITC_UTIL_LED_CHANGE_CONFIG_E
//
// MessageText:
//
//  CLed::ConfigureEvent Error: 0x%1!08X!, ConfigCmd: 0x%2!08X!
//
#define ITC_UTIL_LED_CHANGE_CONFIG_E     0xC12E0020L

//
// MessageId: ITC_UTIL_LED_SETBLINK_DURATION_E
//
// MessageText:
//
//  CLed::SetBlinkDuration Error: 0x%1!08X!, Blink Duration: %2!d!
//
#define ITC_UTIL_LED_SETBLINK_DURATION_E 0xC12E0021L

//
// MessageId: ITC_UTIL_LED_SIGNAL_EVENT_E
//
// MessageText:
//
//  CLed::SignalEvent Error: 0x%1!08X!, EventID: %2!d!
//
#define ITC_UTIL_LED_SIGNAL_EVENT_E      0xC12E0022L

//
// MessageId: ITC_UTIL_LED_ALLOC_EVENT_E
//
// MessageText:
//
//  CLedEvent::AllocEvent  - An event has already been allocated
//
#define ITC_UTIL_LED_ALLOC_EVENT_E       0xC12E0023L

//
// MessageId: ITC_UTIL_LED_CREATE_THREAD_E
//
// MessageText:
//
//  CLedEvent::AllocEvent  - CreateThread error: 0x%1!08X!
//
#define ITC_UTIL_LED_CREATE_THREAD_E     0xC12E0024L

//
// MessageId: ITC_UTIL_LED_CREATE_EVENT_E
//
// MessageText:
//
//  CLedEvent::AllocEvent  - CreateEvent error: 0x%1!08X!
//
#define ITC_UTIL_LED_CREATE_EVENT_E      0xC12E0025L

//
// MessageId: ITC_UTIL_LED_GET_EVENT_E
//
// MessageText:
//
//  CLed::GetEvent Error: 0x%1!08X!
//
#define ITC_UTIL_LED_GET_EVENT_E         0xC12E0026L

//
// MessageId: ITC_UTIL_LED_FREE_EVENT_E
//
// MessageText:
//
//  CLed::FreeEvent Error: 0x%1!08X!; EventID: %2!d!
//
#define ITC_UTIL_LED_FREE_EVENT_E        0xC12E0027L

//
// MessageId: ITC_UTIL_LED_FREE_EVENT_NOTOWNED_E
//
// MessageText:
//
//  CLedEvent::FreeEvent - Can't free event.  Event not allocated.
//
#define ITC_UTIL_LED_FREE_EVENT_NOTOWNED_E 0xC12E0028L

//
// MessageId: ITC_UTIL_LED_SET_EVENT_OWNED_E
//
// MessageText:
//
//  CLedEvent::SetEvent - Can't overwrite owned event ID: %1!d!
//
#define ITC_UTIL_LED_SET_EVENT_OWNED_E   0xC12E0029L

//
// MessageId: ITC_UTIL_LED_SIGNAL_EVENT_NOWOWNED_E
//
// MessageText:
//
//  CLedEvent::SignalEvent - Can't signal event: Event not owned
//
#define ITC_UTIL_LED_SIGNAL_EVENT_NOWOWNED_E 0xC12E002AL

//
// MessageId: ITC_UTIL_LED_GET_EVENT_CONFIG_E
//
// MessageText:
//
//  CLed::GetEventConfiguration Error: 0x%1!08X!; EventID: %2!d!
//
#define ITC_UTIL_LED_GET_EVENT_CONFIG_E  0xC12E002BL

//
// MessageId: ITC_UTIL_TRIG_CREATEFILE_E
//
// MessageText:
//
//  CTrigger::CTrigger - CreateFile error: 0x%1!08X!
//
#define ITC_UTIL_TRIG_CREATEFILE_E       0xC12E002CL

//
// MessageId: ITC_UTIL_TRIG_GETIDS_E
//
// MessageText:
//
//  CTrigger::CTrigger - Error getting EventIDs: 0x%1!08X!
//
#define ITC_UTIL_TRIG_GETIDS_E           0xC12E002DL

//
// MessageId: ITC_UTIL_LED_STARTBLINK_DV_E
//
// MessageText:
//
//  CLed::StartBlinkDataValidLed Error: 0x%1!08X!
//
#define ITC_UTIL_LED_STARTBLINK_DV_E     0xC12E002EL

//
// MessageId: ITC_UTIL_LED_STOPBLINK_DV_E
//
// MessageText:
//
//  CLed::StartBlinkDataValidLed Error: 0x%1!08X!
//
#define ITC_UTIL_LED_STOPBLINK_DV_E      0xC12E002FL

//
// MessageId: ITC_UTIL_LED_STARTBLINK_GR_E
//
// MessageText:
//
//  CLed::StartBlinkGoodReadLed Error: 0x%1!08X!
//
#define ITC_UTIL_LED_STARTBLINK_GR_E     0xC12E0030L

//
// MessageId: ITC_UTIL_LED_STOPBLINK_GR_E
//
// MessageText:
//
//  CLed::StopBlinkGoodReadLed Error: 0x%1!08X!
//
#define ITC_UTIL_LED_STOPBLINK_GR_E      0xC12E0031L

//
// MessageId: ITC_UTIL_PTRARRAYDYN_NEW_E
//
// MessageText:
//
//  PtrArrayDyn<T>::Initialize "new" failed to allocation memory
//
#define ITC_UTIL_PTRARRAYDYN_NEW_E       0xC12E0032L

//
// MessageId: ITC_UTIL_REG_GETSUBKEYS_E
//
// MessageText:
//
//  CRegistry::GetNumSubKeys RegQueryInfoKey error: 0x%1!08X!
//
#define ITC_UTIL_REG_GETSUBKEYS_E        0xC12E0033L

//
// MessageId: ITC_UTIL_REG_GETNUMVALUES_E
//
// MessageText:
//
//  CRegistry::GetNumValues RegQueryInfoKey error: 0x%1!08X!
//
#define ITC_UTIL_REG_GETNUMVALUES_E      0xC12E0034L

//
// MessageId: ITC_UTIL_PROCESSNEXT_E
//
// MessageText:
//
//  CProcessSearch::HandleSearchError(), Process32Next() error: %1!08X!
//
#define ITC_UTIL_PROCESSNEXT_E           0xC12E0035L

//
// MessageId: ITC_UTIL_INPUT_PARAM_E
//
// MessageText:
//
//  CProcessSearch::Input param not valid: %1!08X!
//
#define ITC_UTIL_INPUT_PARAM_E           0xC12E0036L

//
// MessageId: ITC_UTIL_TOOLHELPSNAPSHOT_E
//
// MessageText:
//
//  CProcessSearch::CreateToolhelp32Snapshot(), failed: %1!08X!
//
#define ITC_UTIL_TOOLHELPSNAPSHOT_E      0xC12E0037L

//
// MessageId: ITC_UTIL_COULD_NOT_FIND_PROCESS_E
//
// MessageText:
//
//  CProcessSearch::HandleSearchError(), Process32Next() Could not find process: %1!08X!
//
#define ITC_UTIL_COULD_NOT_FIND_PROCESS_E 0xC12E0038L

//
// MessageId: ITC_UTIL_EXCEPTION_E
//
// MessageText:
//
//  CProcessSearch::Find(), Exception: %1!08X!
//
#define ITC_UTIL_EXCEPTION_E             0xC12E0039L

//
// MessageId: ITC_UTIL_IVAPAL_DLLLOAD_E
//
// MessageText:
//
//  LoadIVAPAL failed to load DLL
//
#define ITC_UTIL_IVAPAL_DLLLOAD_E        0xC12E003AL

//
// MessageId: ITC_UTIL_IVAPAL_FUNCLOAD_E
//
// MessageText:
//
//  LoadIVAPAL failed to load function
//
#define ITC_UTIL_IVAPAL_FUNCLOAD_E       0xC12E003BL

#endif  // THIS LINE MUST BE AFTER ANY MESSAGE DEFINITIONS.
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCUtilities.mcs
// COPYRIGHT (c) 1998 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ITCVirtualWedge.mcs
//
//  AUTHOR:
//
//  Rev 1.3 02 Feb 2007               GWright
//  Addition for grid {} macro implementation
//
//
//  Rev 1.3 02 Feb 2007               GWright
//  Additions for Target App Adapter
//
//   Rev 1.2   18 Sep 1998 14:43:48   BReed
//Changes from VW code review.
//
//   Rev 1.1   04 Sep 1998 16:56:16   BReed
//Original code review date postponed.
//This revision reflects work product reviewed
//at later date.
//
//   Rev 1.1   04 Sep 1998 16:50:12   BReed
// 
//
//   Rev 1.0   20 Jul 1998 17:36:56   BReed
//Initial revision.  Code review version.
// COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_ITCVIRTUALWEDGE_MCS
#define INCLUDED_ITCVIRTUALWEDGE_MCS
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Informational
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_E 
//Language=English
//<message string>
//.
//
// MessageId: ITC_VW_TRACE_I
//
// MessageText:
//
//  %1!08X! %2!08X!
//
#define ITC_VW_TRACE_I                   0x41020000L

//
// MessageId: ITC_VW_SETDG_BEFORECANCEL_I
//
// MessageText:
//
//  CVirtualWedgeDevice::SetDataGrid Before PH->CancelReadRequest
//
#define ITC_VW_SETDG_BEFORECANCEL_I      0x41020001L

//
// MessageId: ITC_VW_SETDG_AFTERCANCEL_I
//
// MessageText:
//
//  CVirtualWedgeDevice::SetDataGrid After PH->CancelReadRequest Status: %1!08X!
//
#define ITC_VW_SETDG_AFTERCANCEL_I       0x41020002L

//
// MessageId: ITC_VW_WINDOW_NAME_FOUND_I
//
// MessageText:
//
//  CAppSetContainer::FindAppWithFocus - Application window name found.
//
#define ITC_VW_WINDOW_NAME_FOUND_I       0x41020003L

//
// MessageId: ITC_VW_CLASS_NAME_FOUND_I
//
// MessageText:
//
//  CAppSetContainer::FindAppWithFocus - Application class name found.
//
#define ITC_VW_CLASS_NAME_FOUND_I        0x41020004L

//
// MessageId: ITC_VW_NO_APP_FOUND_I
//
// MessageText:
//
//  CAppSetContainer::FindAppWithFocus - No application recognized.
//
#define ITC_VW_NO_APP_FOUND_I            0x41020005L

//
// MessageId: ITC_VW_LOG_STRING_I
//
// MessageText:
//
//  CKeystrokeBuffer::TransmitKeys - Grid macro.
//
#define ITC_VW_LOG_STRING_I              0x41020006L

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Success
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_E 
//Language=English
//<message string>
//.
//
// MessageId: ITC_VW_DEVICE_INITIALIZED_S
//
// MessageText:
//
//  Device %1!08X! Successfully Initialized. Type = %2!08X!
//
#define ITC_VW_DEVICE_INITIALIZED_S      0x01020000L

//
// MessageId: ITC_VW_PLATFORM_TYPE_FOUND_S
//
// MessageText:
//
//  CKeystrokeBuffer::GetPlatformType - Platform type found.
//
#define ITC_VW_PLATFORM_TYPE_FOUND_S     0x01020001L

////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_VW_OUT_OF_RANGE_W
//
// MessageText:
//
//  Out of range
//
#define ITC_VW_OUT_OF_RANGE_W            0x81020002L

//
// MessageId: ITC_VW_INVALID_UNICODE_CHAR_W
//
// MessageText:
//
//  Invalid Unicode character
//
#define ITC_VW_INVALID_UNICODE_CHAR_W    0x81020003L

//
// MessageId: ITC_VW_PACKET_NOT_ALLOWED_W
//
// MessageText:
//
//  CXmitKeySeqEvent::ProcessChar - PACKET not allowed with keybd_event.
//
#define ITC_VW_PACKET_NOT_ALLOWED_W      0x81020004L

//
// MessageId: ITC_VW_PLATFORM_TYPE_NOT_FOUND_W
//
// MessageText:
//
//  CKeystrokeBuffer::GetPlatformType - Warning 0x%1!08X!
//
#define ITC_VW_PLATFORM_TYPE_NOT_FOUND_W 0x81020005L

//
// MessageId: ITC_VW_MUTEX_NOT_FOUND_W
//
// MessageText:
//
//  CKeystrokeBuffer::TransmitKeys - Mutex not found.
//
#define ITC_VW_MUTEX_NOT_FOUND_W         0x81020006L

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Error
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_E 
//Language=English
//<message string>
//.
//
// MessageId: ITC_VW_OUT_OF_MEMORY_E
//
// MessageText:
//
//  Memory allocation failure
//
#define ITC_VW_OUT_OF_MEMORY_E           0xC1020000L

//
// MessageId: ITC_VW_INVALID_CLSID_E
//
// MessageText:
//
//  Invalid class ID
//
#define ITC_VW_INVALID_CLSID_E           0xC1020001L

//
// MessageId: ITC_VW_DEVICE_CREATE_FAIL_E
//
// MessageText:
//
//  Device create failure. Device ID = %1!08X!
//
#define ITC_VW_DEVICE_CREATE_FAIL_E      0xC1020002L

//
// MessageId: ITC_VW_DEVICE_INITIALIZE_FAILURE_E
//
// MessageText:
//
//  Device initialize failure. Device ID = %1!08X!
//
#define ITC_VW_DEVICE_INITIALIZE_FAILURE_E 0xC1020003L

//
// MessageId: ITC_VW_DEVICE_CONTROL_FAILURE_E
//
// MessageText:
//
//  Device control failure. Device ID = %1!08X!
//
#define ITC_VW_DEVICE_CONTROL_FAILURE_E  0xC1020004L

//
// MessageId: ITC_VW_NOSUCHDEVICE_E
//
// MessageText:
//
//  No such device as ID %1!08X!
//
#define ITC_VW_NOSUCHDEVICE_E            0xC1020005L

//
// MessageId: ITC_VW_INVALID_WRITE_ACCESS
//
// MessageText:
//
//  Bad write pointer. Status = %1!08X!
//
#define ITC_VW_INVALID_WRITE_ACCESS      0xC1020006L

//
// MessageId: ITC_VW_INVALID_READ_ACCESS
//
// MessageText:
//
//  Bad read pointer. Status = %1!08X!
//
#define ITC_VW_INVALID_READ_ACCESS       0xC1020007L

//
// MessageId: ITC_VW_BUFFER_TOO_SMALL
//
// MessageText:
//
//  Insufficient buffer size. Max Bytes allowed: %1!d!; Bytes Requested: %2!d!
//
#define ITC_VW_BUFFER_TOO_SMALL          0xC1020008L

//
// MessageId: ITC_VW_CODEPAGE_NOT_PRESENT
//
// MessageText:
//
//  Attempted to set invalid code page.
//
#define ITC_VW_CODEPAGE_NOT_PRESENT      0xC1020009L

//
// MessageId: ITC_VW_UNICODE_TRANSLATION_ERROR
//
// MessageText:
//
//  Unicode translation error.
//
#define ITC_VW_UNICODE_TRANSLATION_ERROR 0xC102000AL

//
// MessageId: ITC_VW_KBD_PIPE_OPEN_E
//
// MessageText:
//
//  Failed to open keyboard pipe.
//
#define ITC_VW_KBD_PIPE_OPEN_E           0xC102000BL

//
// MessageId: ITC_COM_INITIALIZE_EX_E
//
// MessageText:
//
//  COM Initialize EX failure.
//
#define ITC_COM_INITIALIZE_EX_E          0xC102000CL

//
// MessageId: ITC_VW_WRITE_KEYBOARD_FAIL_E
//
// MessageText:
//
//  Failure to write to keyboard
//
#define ITC_VW_WRITE_KEYBOARD_FAIL_E     0xC102000DL

//
// MessageId: ITC_VW_CREATE_THREAD_FAILURE_E
//
// MessageText:
//
//  Create thread failure.  Status = %1!08X!
//
#define ITC_VW_CREATE_THREAD_FAILURE_E   0xC102000EL

//
// MessageId: ITC_VW_INVALID_DEVICE_TYPE
//
// MessageText:
//
//  Invalid device type: %1!4d!
//
#define ITC_VW_INVALID_DEVICE_TYPE       0xC102000FL

//
// MessageId: ITC_VW_INVALID_KEYSTROKE
//
// MessageText:
//
//  Invalid keystroke: %1!8X!
//
#define ITC_VW_INVALID_KEYSTROKE         0xC1020010L

//
// MessageId: ITC_VW_ALLOCATE_CREGISTRY_FAIL_E
//
// MessageText:
//
//  CVirtualWedge::AddDevice - failed to allocate CRegistry object
//
#define ITC_VW_ALLOCATE_CREGISTRY_FAIL_E 0xC1020011L

//
// MessageId: ITC_VW_SET_GRID_WEDGE_DISABLE_E
//
// MessageText:
//
//  CVirtualWedgeDevice::SetDataGrid - Device Wedging is disabled
//
#define ITC_VW_SET_GRID_WEDGE_DISABLE_E  0xC1020012L

//
// MessageId: ITC_VW_SET_GRID_ERROR_E
//
// MessageText:
//
//  CVirtualWedgeDevice::SetDataGrid - Error 0x%1!08X!
//
#define ITC_VW_SET_GRID_ERROR_E          0xC1020013L

//
// MessageId: ITC_VW_GET_GRID_ERROR_E
//
// MessageText:
//
//  CVirtualWedgeDevice::GetDataGrid - Error 0x%1!08X!
//
#define ITC_VW_GET_GRID_ERROR_E          0xC1020014L

//
// MessageId: ITC_VW_QUEUE_TIMEOUT_E
//
// MessageText:
//
//  CXmitKeySeqPost::PostKey - Queue timout!
//
#define ITC_VW_QUEUE_TIMEOUT_E           0xC1020015L

#endif  // THIS LINE MUST BE AFTER ANY MESSAGE DEFINITIONS.
////////////////////////////////////////////////////////////////////
// END OF FILE:  ITCVirtualWedge.mcs
//  COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  ReaderCommandSnmpGateway.mcs
//
//  AUTHOR:  Randy Sales
//
//  COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_READERCOMMANDSNMPGATEWAY_MCS
#define INCLUDED_READERCOMMANDSNMPGATEWAY_MCS
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_RCSG_CONSTRUCTOR_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::CReaderCommandSnmpGateway - Function entry
//
#define ITC_RCSG_CONSTRUCTOR_ENTRY_I     0x41470000L

//
// MessageId: ITC_RCSG_DESTRUCTOR_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::~CReaderCommandSnmpGateway - Function entry
//
#define ITC_RCSG_DESTRUCTOR_ENTRY_I      0x41470001L

//
// MessageId: ITC_RCSG_PROCESSREADERCOMMAND_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessReaderCommand - Function entry
//
#define ITC_RCSG_PROCESSREADERCOMMAND_ENTRY_I 0x41470002L

//
// MessageId: ITC_RCSG_QUERYREADERCONFIG_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::QueryReaderConfig - Function entry
//
#define ITC_RCSG_QUERYREADERCONFIG_ENTRY_I 0x41470003L

//
// MessageId: ITC_RCSG_SETREADERCONFIG_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::SetReaderConfig - Function entry
//
#define ITC_RCSG_SETREADERCONFIG_ENTRY_I 0x41470004L

//
// MessageId: ITC_RCSG_RDR_WCOMMAND_VALUE_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupRdrCommand - wCommand = 0x%1!04X!
//
#define ITC_RCSG_RDR_WCOMMAND_VALUE_I    0x41470005L

//
// MessageId: ITC_RCSG_CFG_WCOMMAND_VALUE_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupCfgCommand - wCommand = 0x%1!04X!
//
#define ITC_RCSG_CFG_WCOMMAND_VALUE_I    0x41470006L

//
// MessageId: ITC_RCSG_LOOKUPRDRCOMMAND_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupRdrCommand - Function entry
//
#define ITC_RCSG_LOOKUPRDRCOMMAND_ENTRY_I 0x41470007L

//
// MessageId: ITC_RCSG_LOOKUPCFGCOMMAND_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupCfgCommand - Function entry
//
#define ITC_RCSG_LOOKUPCFGCOMMAND_ENTRY_I 0x41470008L

//
// MessageId: ITC_RCSG_VERIFYORIGIN_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::VerifyOrigin - Function entry
//
#define ITC_RCSG_VERIFYORIGIN_ENTRY_I    0x41470009L

//
// MessageId: ITC_RCSG_GETPARAMETERS_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Function entry
//
#define ITC_RCSG_GETPARAMETERS_ENTRY_I   0x4147000AL

//
// MessageId: ITC_RCSG_GETPARAMETERS_EXIT_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - bDoneParsing set, function exit
//
#define ITC_RCSG_GETPARAMETERS_EXIT_I    0x4147000BL

//
// MessageId: ITC_RCSG_GETANDUNPACKAGEDATA_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetAndUnpackageData - Function entry
//
#define ITC_RCSG_GETANDUNPACKAGEDATA_ENTRY_I 0x4147000CL

//
// MessageId: ITC_RCSG_PACKAGEANDSENDDATA_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::PackageAndSendData - Function entry
//
#define ITC_RCSG_PACKAGEANDSENDDATA_ENTRY_I 0x4147000DL

//
// MessageId: ITC_RCSG_PERFORMADDITIONALPARSING_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::PerformAdditionalParsing - Function entry
//
#define ITC_RCSG_PERFORMADDITIONALPARSING_ENTRY_I 0x4147000EL

//
// MessageId: ITC_RCSG_APGETCONFIG_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APGetConfig - Function entry
//
#define ITC_RCSG_APGETCONFIG_ENTRY_I     0x4147000FL

//
// MessageId: ITC_RCSG_APSETCONFIG_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APSetConfig - Function entry
//
#define ITC_RCSG_APSETCONFIG_ENTRY_I     0x41470010L

//
// MessageId: ITC_RCSG_APAPPENDRDRENGIDX_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APAppendRdrEngIdx - Function entry
//
#define ITC_RCSG_APAPPENDRDRENGIDX_ENTRY_I 0x41470011L

//
// MessageId: ITC_RCSG_INITIALIZE_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::Initialize - Function entry
//
#define ITC_RCSG_INITIALIZE_ENTRY_I      0x41470012L

//
// MessageId: ITC_RCSG_STATE_IDLE_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Entering case STATE_IDLE
//
#define ITC_RCSG_STATE_IDLE_I            0x41470013L

//
// MessageId: ITC_RCSG_STATE_QUOTE_ONE_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Entering case STATE_QUOTE_ONE
//
#define ITC_RCSG_STATE_QUOTE_ONE_I       0x41470014L

//
// MessageId: ITC_RCSG_STATE_QUOTE_TWO_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Entering case STATE_QUOTE_TWO
//
#define ITC_RCSG_STATE_QUOTE_TWO_I       0x41470015L

//
// MessageId: ITC_RCSG_STATE_NON_QUOTE_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Entering case STATE_NON_QUOTE
//
#define ITC_RCSG_STATE_NON_QUOTE_I       0x41470016L

//
// MessageId: ITC_RCSG_STATE_EMBEDDED_QUOTE_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Entering case STATE_EMBEDDED_QUOTE
//
#define ITC_RCSG_STATE_EMBEDDED_QUOTE_I  0x41470017L

//
// MessageId: ITC_RCSG_DEVICE_INDEX_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::Initialize - Device index located in registry (%1!d!)
//
#define ITC_RCSG_DEVICE_INDEX_I          0x41470018L

//
// MessageId: ITC_RCSG_TABLESIZE_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::Initialize - RcsgLookupTable contains %1!d! entries
//
#define ITC_RCSG_TABLESIZE_I             0x41470019L

//
// MessageId: ITC_RCSG_STATE_LOOP_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Loop number %1!d!
//
#define ITC_RCSG_STATE_LOOP_I            0x4147001AL

//
// MessageId: ITC_RCSG_CREATEINSTANCE_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::CreateInstance - Function entry
//
#define ITC_RCSG_CREATEINSTANCE_I        0x4147001BL

//
// MessageId: ITC_RCSG_NONDELEGATINGQUERYINTERFACE_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::NondelegatingQueryInterface - Function entry
//
#define ITC_RCSG_NONDELEGATINGQUERYINTERFACE_I 0x4147001CL

//
// MessageId: ITC_RCSG_APBACKLIGHTCONTROL_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APBacklightControl - Function entry
//
#define ITC_RCSG_APBACKLIGHTCONTROL_ENTRY_I 0x4147001DL

//
// MessageId: ITC_RCSG_APSCANNERBEAMON_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APScannerBeamOn - Function entry
//
#define ITC_RCSG_APSCANNERBEAMON_ENTRY_I 0x4147001EL

//
// MessageId: ITC_RCSG_APSCANNERBEAMOFF_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APScannerBeamOff - Function entry
//
#define ITC_RCSG_APSCANNERBEAMOFF_ENTRY_I 0x4147001FL

//
// MessageId: ITC_RCSG_APSCANNERBEAM_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APScannerBeam - Function entry
//
#define ITC_RCSG_APSCANNERBEAM_ENTRY_I   0x41470020L

//
// MessageId: ITC_RCSG_APDATETIME_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APDateTime - Function entry
//
#define ITC_RCSG_APDATETIME_ENTRY_I      0x41470021L

//
// MessageId: ITC_RCSG_AP_ADD_DOT_ONE_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APAddDotOne - Function entry
//
#define ITC_RCSG_AP_ADD_DOT_ONE_ENTRY_I  0x41470022L

//
// MessageId: ITC_RCSG_CONFIG_COMMAND_FOUND_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommand - Config command found
//
#define ITC_RCSG_CONFIG_COMMAND_FOUND_I  0x41470023L

//
// MessageId: ITC_RCSG_PROCESSCONFIGCOMMAND_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommand - Function entry
//
#define ITC_RCSG_PROCESSCONFIGCOMMAND_ENTRY_I 0x41470024L

//
// MessageId: ITC_RCSG_DSCOINITIALIZE_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::DscoInitialize - Function entry
//
#define ITC_RCSG_DSCOINITIALIZE_ENTRY_I  0x41470025L

//
// MessageId: ITC_RCSG_DSCOPROCESSREADERCOMMAND_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::DscoProcessReaderCommand - Function entry
//
#define ITC_RCSG_DSCOPROCESSREADERCOMMAND_ENTRY_I 0x41470026L

//
// MessageId: ITC_RCSG_PROCESSCONFIGCOMMANDDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco - Function entry
//
#define ITC_RCSG_PROCESSCONFIGCOMMANDDSCO_ENTRY_I 0x41470027L

//
// MessageId: ITC_RCSG_DSCO_GETOPERATION_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco - Performing a get operation
//
#define ITC_RCSG_DSCO_GETOPERATION_I     0x41470028L

//
// MessageId: ITC_RCSG_DSCO_SETOPERATION_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco - Performing a set operation
//
#define ITC_RCSG_DSCO_SETOPERATION_I     0x41470029L

//
// MessageId: ITC_RCSG_PROCESSTWOOFFIVEDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessTwoOfFiveDsco - Function entry
//
#define ITC_RCSG_PROCESSTWOOFFIVEDSCO_ENTRY_I 0x4147002AL

//
// MessageId: ITC_RCSG_PROCESSINTERLEAVED2OF5DSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessInterleaved2of5 - Function entry
//
#define ITC_RCSG_PROCESSINTERLEAVED2OF5DSCO_ENTRY_I 0x4147002BL

//
// MessageId: ITC_RCSG_PROCESSCODE93DSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessCode93Dsco - Function entry
//
#define ITC_RCSG_PROCESSCODE93DSCO_ENTRY_I 0x4147002CL

//
// MessageId: ITC_RCSG_PROCESSCODABARDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessCodabarDsco - Function entry
//
#define ITC_RCSG_PROCESSCODABARDSCO_ENTRY_I 0x4147002DL

//
// MessageId: ITC_RCSG_PROCESSCODE11DSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessCode11Dsco - Function entry
//
#define ITC_RCSG_PROCESSCODE11DSCO_ENTRY_I 0x4147002EL

//
// MessageId: ITC_RCSG_PROCESSCODE49DSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessCode49Dsco - Function entry
//
#define ITC_RCSG_PROCESSCODE49DSCO_ENTRY_I 0x4147002FL

//
// MessageId: ITC_RCSG_PROCESSMSIDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessMsiDsco - Function entry
//
#define ITC_RCSG_PROCESSMSIDSCO_ENTRY_I  0x41470030L

//
// MessageId: ITC_RCSG_PROCESSLOWBEEPDURATIONDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessLowBeepDurationDsco - Function entry
//
#define ITC_RCSG_PROCESSLOWBEEPDURATIONDSCO_ENTRY_I 0x41470031L

//
// MessageId: ITC_RCSG_PROCESSHIGHBEEPDURATIONDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessHighBeepDurationDsco - Function entry
//
#define ITC_RCSG_PROCESSHIGHBEEPDURATIONDSCO_ENTRY_I 0x41470032L

//
// MessageId: ITC_RCSG_PROCESSLOWBEEPFREQUENCYDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessLowBeepFrequencyDsco - Function entry
//
#define ITC_RCSG_PROCESSLOWBEEPFREQUENCYDSCO_ENTRY_I 0x41470033L

//
// MessageId: ITC_RCSG_PROCESSHIGHBEEPFREQUENCYDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessHighBeepFrequencyDsco - Function entry
//
#define ITC_RCSG_PROCESSHIGHBEEPFREQUENCYDSCO_ENTRY_I 0x41470034L

//
// MessageId: ITC_RCSG_PROCESSCODE39DSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessCode39Dsco - Function entry
//
#define ITC_RCSG_PROCESSCODE39DSCO_ENTRY_I 0x41470035L

//
// MessageId: ITC_RCSG_PROCESSCODE16KDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessCode16KDsco - Function entry
//
#define ITC_RCSG_PROCESSCODE16KDSCO_ENTRY_I 0x41470036L

//
// MessageId: ITC_RCSG_PROCESSDECODESECURITYLEVELDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessDecodeSecurityLevelDsco - Function entry
//
#define ITC_RCSG_PROCESSDECODESECURITYLEVELDSCO_ENTRY_I 0x41470037L

//
// MessageId: ITC_RCSG_PROCESSSCANNERMODEDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessScannerModeDsco - Function entry
//
#define ITC_RCSG_PROCESSSCANNERMODEDSCO_ENTRY_I 0x41470038L

//
// MessageId: ITC_RCSG_PROCESSSCANNERTRIGGERMODEDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessScannerTriggerModeDsco - Function entry
//
#define ITC_RCSG_PROCESSSCANNERTRIGGERMODEDSCO_ENTRY_I 0x41470039L

//
// MessageId: ITC_RCSG_PROCESSSCANNERREDUNDANCYDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessScannerRedundancyDsco - Function entry
//
#define ITC_RCSG_PROCESSSCANNERREDUNDANCYDSCO_ENTRY_I 0x4147003AL

//
// MessageId: ITC_RCSG_PROCESSUPCEANDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessUpcEanDsco - Function entry
//
#define ITC_RCSG_PROCESSUPCEANDSCO_ENTRY_I 0x4147003BL

//
// MessageId: ITC_RCSG_PROCESSCODE128DSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessCode128Dsco - Function entry
//
#define ITC_RCSG_PROCESSCODE128DSCO_ENTRY_I 0x4147003CL

//
// MessageId: ITC_RCSG_PROCESSSCANNERTIMEOUTDSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessScannerTimeoutDsco - Function entry
//
#define ITC_RCSG_PROCESSSCANNERTIMEOUTDSCO_ENTRY_I 0x4147003DL

//
// MessageId: ITC_RCSG_PROCESSPDF417DSCO_ENTRY_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessPDF417Dsco - Function entry
//
#define ITC_RCSG_PROCESSPDF417DSCO_ENTRY_I 0x4147003EL

//
// MessageId: ITC_RCSG_INVALID_READER_COMMAND_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupRdrCommand - Invalid reader command (%1!04X!)
//
#define ITC_RCSG_INVALID_READER_COMMAND_I 0x4147003FL

//
// MessageId: ITC_RCSG_INSUFFICIENT_BYTES_IN_RDR_CMD_STRING_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupRdrCommand - Insufficient bytes ( < 2 ) in reader command to continue parsing
//
#define ITC_RCSG_INSUFFICIENT_BYTES_IN_RDR_CMD_STRING_I 0x41470040L

//
// MessageId: ITC_RCSG_INVALID_CONFIG_COMMAND_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupCfgCommand - Invalid configuration command (%1!04X!)
//
#define ITC_RCSG_INVALID_CONFIG_COMMAND_I 0x41470041L

//
// MessageId: ITC_RCSG_INSUFFICIENT_BYTES_IN_CFG_CMD_STRING_I
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupCfgCommand - Insufficient bytes ( < 2 ) in configuration command to continue parsing
//
#define ITC_RCSG_INSUFFICIENT_BYTES_IN_CFG_CMD_STRING_I 0x41470042L

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Success
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_S 
//Language=English
//<message string>
//.
//
// MessageId: ITC_RCSG_ALL_CONFIGCOMMANDS_PARSED_S
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupCfgCommand - All configuration commands parsed
//
#define ITC_RCSG_ALL_CONFIGCOMMANDS_PARSED_S 0x01470000L

//
// MessageId: ITC_RCSG_ALL_READERCOMMANDS_PARSED_S
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupRdrCommand - All reader commands parsed
//
#define ITC_RCSG_ALL_READERCOMMANDS_PARSED_S 0x01470001L

//
// MessageId: ITC_RCSG_THIS_COMMAND_PROCESSING_COMPLETED_S
//
// MessageText:
//
//  CReaderCommandSnmpGateway::PerformAdditionalParsing - Processing for this reader or config command completed
//
#define ITC_RCSG_THIS_COMMAND_PROCESSING_COMPLETED_S 0x01470002L

//
// MessageId: ITC_RCSG_DSCOINITIALIZE_SUCCESS_S
//
// MessageText:
//
//  CReaderCommandSnmpGateway::DscoInitialize - Initialize completed successfully
//
#define ITC_RCSG_DSCOINITIALIZE_SUCCESS_S 0x01470003L

////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_RCSG_NO_PARAMETERS_TO_SEND_W
//
// MessageText:
//
//  CReaderCommandSnmpGateway::PackageAndSendData - Immediate return, no parameters to send
//
#define ITC_RCSG_NO_PARAMETERS_TO_SEND_W 0x81470000L

//
// MessageId: ITC_RCSG_NO_PARAMETERS_W
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - No parameters found (not an error condition, there are just no parameters attached to this configuration command)
//
#define ITC_RCSG_NO_PARAMETERS_W         0x81470001L

//
// MessageId: ITC_RCSG_ALREADY_INITIALIZED_W
//
// MessageText:
//
//  CReaderCommandSnmpGateway::Initialize - Init was previously called with a successful result
//
#define ITC_RCSG_ALREADY_INITIALIZED_W   0x81470002L

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_RCSG_INVALID_READER_COMMAND_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupRdrCommand - Invalid reader command (%1!04X!)
//
#define ITC_RCSG_INVALID_READER_COMMAND_E 0xC1470000L

//
// MessageId: ITC_RCSG_INSUFFICIENT_BYTES_IN_RDR_CMD_STRING_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupRdrCommand - Insufficient bytes ( < 2 ) in reader command to continue parsing
//
#define ITC_RCSG_INSUFFICIENT_BYTES_IN_RDR_CMD_STRING_E 0xC1470001L

//
// MessageId: ITC_RCSG_PROBABLE_PREMATURE_INSUFFICIENT_BYTES_IN_CFG_CMD_STRING_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupCfgCommand - Premature insufficient bytes ( < 2 ) in configuration command to continue parsing
//
#define ITC_RCSG_PROBABLE_PREMATURE_INSUFFICIENT_BYTES_IN_CFG_CMD_STRING_E 0xC1470002L

//
// MessageId: ITC_RCSG_INVALID_CONFIG_COMMAND_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::LookupCfgCommand - Invalid configuration command (%1!04X!)
//
#define ITC_RCSG_INVALID_CONFIG_COMMAND_E 0xC1470003L

//
// MessageId: ITC_RCSG_INVALID_ORIGIN_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::VerifyOrigin - Invalid origin, origin for this gateway: 0x%1!08X!, valid origins for this reader command: 0x%2!08X!, reader command: 0x%3!04X!
//
#define ITC_RCSG_INVALID_ORIGIN_E        0xC1470004L

//
// MessageId: ITC_RCSG_MORE_THAN_ONE_VARBIND_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetAndUnpackageData - sendAndWait call resulted in PDU with more than one varbind (only one varbind permitted per OID)
//
#define ITC_RCSG_MORE_THAN_ONE_VARBIND_E 0xC1470005L

//
// MessageId: ITC_RCSG_AP_PROTOCOL_VILOATION_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::PerformAdditionalParsing - Additional parsing function returned 0x%1!08X!, appropriate return values are S_OK and ITC_RCSG_THIS_COMMAND_PROCESSING_COMPLETED_S, otherwise must call RaiseException()
//
#define ITC_RCSG_AP_PROTOCOL_VILOATION_E 0xC1470006L

//
// MessageId: ITC_RCSG_SET_PARM_NO_END_QUOTE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Set configuration command includes unbalanced quotes
//
#define ITC_RCSG_SET_PARM_NO_END_QUOTE_E 0xC1470007L

//
// MessageId: ITC_RCSG_SET_PARM_NO_DOUBLE_QUOTE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Set configuration command includes embedded quote with no matching second quote
//
#define ITC_RCSG_SET_PARM_NO_DOUBLE_QUOTE_E 0xC1470008L

//
// MessageId: ITC_RCSG_SET_PARM_INVALID_STATE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetParameters - Entered invalid state while parsing parameters (should never happen)
//
#define ITC_RCSG_SET_PARM_INVALID_STATE_E 0xC1470009L

//
// MessageId: ITC_RCSG_INIT_WSASTARTUP_FAILURE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::Initialize - WSAStartup returned a non-zero value (0x%1!08X!)
//
#define ITC_RCSG_INIT_WSASTARTUP_FAILURE_E 0xC147000AL

//
// MessageId: ITC_RCSG_READER_COMMAND_TABLE_FORMAT_ERROR_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::Initialize - The reader command table (RcsgLookupTable) does not contain the approriate end table placeholders
//
#define ITC_RCSG_READER_COMMAND_TABLE_FORMAT_ERROR_E 0xC147000BL

//
// MessageId: ITC_RCSG_NO_DATA_TYPE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::PackageAndSendData - No data type provided
//
#define ITC_RCSG_NO_DATA_TYPE_E          0xC147000CL

//
// MessageId: ITC_RCSG_UNRECOGNIZED_DATA_TYPE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::PackageAndSendData - Unrecognized data type (%1!d!)
//
#define ITC_RCSG_UNRECOGNIZED_DATA_TYPE_E 0xC147000DL

//
// MessageId: ITC_RCSG_NO_DEVICE_INDEX_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::Initialize - No device index could be located in the registry
//
#define ITC_RCSG_NO_DEVICE_INDEX_E       0xC147000EL

//
// MessageId: ITC_RCSG_SENDDATA_SENDANDWAIT_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::PackageAndSendData - itc_SnmpTarget::getErrorStatus() returned error (%1!d!) after calling itc_SnmpTarget::sendAndWait
//
#define ITC_RCSG_SENDDATA_SENDANDWAIT_E  0xC147000FL

//
// MessageId: ITC_RCSG_GETDATA_SENDANDWAIT_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetAndUnpackageData - itc_SnmpTarget::getErrorStatus() returned error (%1!d!) after calling itc_SnmpTarget::sendAndWait
//
#define ITC_RCSG_GETDATA_SENDANDWAIT_E   0xC1470010L

//
// MessageId: ITC_RCSG_GETDATA_VARBIND_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetAndUnpackageData - varbind contains error status of %1!d!
//
#define ITC_RCSG_GETDATA_VARBIND_E       0xC1470011L

//
// MessageId: ITC_RCSG_INIT_FAILED_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway - Init has been attempted and failed
//
#define ITC_RCSG_INIT_FAILED_E           0xC1470012L

//
// MessageId: ITC_RCSG_UNINITIALIZED_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway - This object has not yet been initialized by a successful call to CReaderCommandSnmpGateway::Initialize()
//
#define ITC_RCSG_UNINITIALIZED_E         0xC1470013L

//
// MessageId: ITC_RCSG_PREVIOUS_INIT_ATTEMPT_FAILED_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::Initialize - Init has already been called and failed, init aborted
//
#define ITC_RCSG_PREVIOUS_INIT_ATTEMPT_FAILED_E 0xC1470014L

//
// MessageId: ITC_RCSG_OUT_OF_MEMORY_E
//
// MessageText:
//
//  System out of memory.  "new" failed to create CReaderCommandSnmpGateway object.
//
#define ITC_RCSG_OUT_OF_MEMORY_E         0xC1470015L

//
// MessageId: ITC_RCSG_INVALID_SOCKET_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::Initialize - the call to socket(PF_INET, SOCK_DGRAM, 17) returned %1!d!
//
#define ITC_RCSG_INVALID_SOCKET_E        0xC1470016L

//
// MessageId: ITC_RCSG_NULL_DATA_RETREIVED_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetAndUnpackageData - A successful SNMP get returned no data
//
#define ITC_RCSG_NULL_DATA_RETREIVED_E   0xC1470017L

//
// MessageId: ITC_RCSG_DATE_TIME_INVALID_LENGTH_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APDateTime - Date/time string length is invalid
//
#define ITC_RCSG_DATE_TIME_INVALID_LENGTH_E 0xC1470018L

//
// MessageId: ITC_RCSG_DSCO_INSUFFICIENT_OUTPUT_BUFFER_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - Insufficient space to store requested info in output buffer provided by DscoProcessReaderCommand function
//
#define ITC_RCSG_DSCO_INSUFFICIENT_OUTPUT_BUFFER_E 0xC1470019L

//
// MessageId: ITC_RCSG_DSCO_INVALID_SET_PARAMATER_VALUE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - Invalid parameter value on a set operation, parameter number: %1!d!, parameter value: %2!d!, ITC_READER_COMMAND_TYPE: %3!d!
//
#define ITC_RCSG_DSCO_INVALID_SET_PARAMATER_VALUE_E 0xC147001AL

//
// MessageId: ITC_RCSG_DSCO_TOO_FEW_PARAMATERS_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - Two few parameters on a set operation, min parameters for this reader command type: %1!d!, actual number of parameters supplied: %2!d!, ITC_READER_COMMAND_TYPE: %3!d!
//
#define ITC_RCSG_DSCO_TOO_FEW_PARAMATERS_E 0xC147001BL

//
// MessageId: ITC_RCSG_DSCO_TOO_MANY_PARAMATERS_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - Two many parameters on a set operation, max parameters for this reader command type: %1!d!, actual number of parameters supplied: %2!d!, ITC_READER_COMMAND_TYPE: %3!d!
//
#define ITC_RCSG_DSCO_TOO_MANY_PARAMATERS_E 0xC147001CL

//
// MessageId: ITC_RCSG_DSCO_UNSUPPORTED_READER_COMMAND_TYPE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco - A reader command that is not supported by this implemetation has been requested: ITC_READER_COMMAND_TYPE: %1!d!
//
#define ITC_RCSG_DSCO_UNSUPPORTED_READER_COMMAND_TYPE_E 0xC147001DL

//
// MessageId: ITC_RCSG_DSCO_IDSCOCMDMAPPER_GET_FAILURE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - IDscoCmdMapper get failure, ITC_READER_COMMAND_TYPE: %1!d!, failing hr value: 0x%2!08X!
//
#define ITC_RCSG_DSCO_IDSCOCMDMAPPER_GET_FAILURE_E 0xC147001EL

//
// MessageId: ITC_RCSG_DSCO_IDSCOCMDMAPPER_SET_FAILURE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - IDscoCmdMapper set failure, ITC_READER_COMMAND_TYPE: %1!d!, failing hr value: 0x%2!08X!
//
#define ITC_RCSG_DSCO_IDSCOCMDMAPPER_SET_FAILURE_E 0xC147001FL

//
// MessageId: ITC_RCSG_DSCO_IDSCOCMDMAPPER_GET_PARAMETER_INVALID_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - IDscoCmdMapper get failure, ITC_READER_COMMAND_TYPE: %1!d!, failing parameter number: %2!d!, failing parameter value: %3!d!
//
#define ITC_RCSG_DSCO_IDSCOCMDMAPPER_GET_PARAMETER_INVALID_E 0xC1470020L

//
// MessageId: ITC_RCSG_DSCO_SET_INVALID_PARAMATER_COMBINATION_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - Invalid combination of parameters on a set operation, ITC_READER_COMMAND_TYPE: %1!d!
//
#define ITC_RCSG_DSCO_SET_INVALID_PARAMATER_COMBINATION_E 0xC1470021L

//
// MessageId: ITC_RCSG_DSCO_INSUFFICIENT_PARAMETERS_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - IDscoCmdMapper set failure, ITC_READER_COMMAND_TYPE: %1!d!, actual number of parameters: %2!d!, minimum parameters required: %3!d!
//
#define ITC_RCSG_DSCO_INSUFFICIENT_PARAMETERS_E 0xC1470022L

//
// MessageId: ITC_RCSG_DSCO_INITIALIZE_QI_FAILURE_E
//
// MessageText:
//
//  In CReaderCommandSnmpGateway::DscoInitialize(), pIUnk->QueryInterface(IID_IDscoCmdMapper,(void**)&m_pIDscoCmdMapper) failed, return value of: 0x%1!04X!
//
#define ITC_RCSG_DSCO_INITIALIZE_QI_FAILURE_E 0xC1470023L

//
// MessageId: ITC_RCSG_DSCO_INITIALIZE_IUNKNOWN_NULL_E
//
// MessageText:
//
//  In CReaderCommandSnmpGateway::DscoInitialize(), IUnknown* (pIUnk) is NULL
//
#define ITC_RCSG_DSCO_INITIALIZE_IUNKNOWN_NULL_E 0xC1470024L

//
// MessageId: ITC_RCSG_DSCO_GET_INVALID_PARAMATER_COMBINATION_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessConfigCommandDsco subcall - Invalid combination of parameters received on a get operation, ITC_READER_COMMAND_TYPE: %1!d!
//
#define ITC_RCSG_DSCO_GET_INVALID_PARAMATER_COMBINATION_E 0xC1470025L

//
// MessageId: ITC_RCSG_DSCO_TOO_FEW_PARAMS_BASED_ON_PARAM_INTERACTION_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessCode128Dsco - Too few parameters received based on parameter interaction, first param involved: %1!d!, last param required: %2!d!, actual number of parameters supplied: %3!d!, ITC_READER_COMMAND_TYPE: %4!d!
//
#define ITC_RCSG_DSCO_TOO_FEW_PARAMS_BASED_ON_PARAM_INTERACTION_E 0xC1470026L

//
// MessageId: ITC_RCSG_INPUT_LABEL_TOO_LONG_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessReaderCommand - Input buffer too long: in_len:0x%1!08X!, max_len:0x%1!08X!
//
#define ITC_RCSG_INPUT_LABEL_TOO_LONG_E  0xC1470027L

//
// MessageId: ITC_RCSG_SYMID_NO_ISCP_TABLE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessIscpCommand - No ISCP table
//
#define ITC_RCSG_SYMID_NO_ISCP_TABLE_E   0xC1470028L

//
// MessageId: ITC_RCSG_SYMID_TOO_MANY_CONFIG_CMD_PARAMS_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessIscpCommand - Too many configuation command parameters
//
#define ITC_RCSG_SYMID_TOO_MANY_CONFIG_CMD_PARAMS_E 0xC1470029L

//
// MessageId: ITC_RCSG_SYMID_NO_PARAMS_ON_A_SET_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessIscpCommand - No params provided on a set
//
#define ITC_RCSG_SYMID_NO_PARAMS_ON_A_SET_E 0xC147002AL

//
// MessageId: ITC_RCSG_SYMID_NO_NSTRING_RETURNED_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessIscpCommand - No N-string returned from SNMP get
//
#define ITC_RCSG_SYMID_NO_NSTRING_RETURNED_E 0xC147002BL

//
// MessageId: ITC_RCSG_SYMID_NO_DATA_IN_NSTRING_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessIscpCommand - No data in N-string returned from SNMP get
//
#define ITC_RCSG_SYMID_NO_DATA_IN_NSTRING_E 0xC147002CL

//
// MessageId: ITC_RCSG_SYMID_BAD_SET_PARAMETERS_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessIscpCommand - One or more provided set parameters are not valid
//
#define ITC_RCSG_SYMID_BAD_SET_PARAMETERS_E 0xC147002DL

//
// MessageId: ITC_RCSG_SYMID_GET_PARAMS_INCOMPLETE_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessIscpCommand - Parameters are invalid or incomplete
//
#define ITC_RCSG_SYMID_GET_PARAMS_INCOMPLETE_E 0xC147002EL

//
// MessageId: ITC_RCSG_SYMID_CY_INVALID_ARGS_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY - CY command has invalid arguements
//
#define ITC_RCSG_SYMID_CY_INVALID_ARGS_E 0xC147002FL

//
// MessageId: ITC_RCSG_SYMID_CY_UNSUPPORTED_CONFIG_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY - Requested CY configuration is not supported
//
#define ITC_RCSG_SYMID_CY_UNSUPPORTED_CONFIG_E 0xC1470030L

//
// MessageId: ITC_RCSG_SYMID_CY_INVALID_ISCP_PARAM_NUM_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY - Invalid ISCP parameter number
//
#define ITC_RCSG_SYMID_CY_INVALID_ISCP_PARAM_NUM_E 0xC1470031L

//
// MessageId: ITC_RCSG_SYMID_CFGCMD_NOT_SUPPORTED_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY - Associated configuration command not supported
//
#define ITC_RCSG_SYMID_CFGCMD_NOT_SUPPORTED_E 0xC1470032L

//
// MessageId: ITC_RCSG_SYMID_INVALID_CONTEXT_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway - Invalid context (must be set or get)
//
#define ITC_RCSG_SYMID_INVALID_CONTEXT_E 0xC1470033L

//
// MessageId: ITC_RCSG_SYMID_INSUFFICIENT_ISCP_DATA_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY_Get - Insufficient ISCP data returned
//
#define ITC_RCSG_SYMID_INSUFFICIENT_ISCP_DATA_E 0xC1470034L

//
// MessageId: ITC_RCSG_SYMID_GET_INVALID_NUM_OF_USERDEF_CHARS_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY_Get - Invalid number of user defined characters returned (must be 1-4)
//
#define ITC_RCSG_SYMID_GET_INVALID_NUM_OF_USERDEF_CHARS_E 0xC1470035L

//
// MessageId: ITC_RCSG_SYMID_CY00_NO_CONFIG_CHAR_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY_Get - CY00 did not return a configuration character (0, 1 or 2)
//
#define ITC_RCSG_SYMID_CY00_NO_CONFIG_CHAR_E 0xC1470036L

//
// MessageId: ITC_RCSG_SYMID_GET_INVALID_CONFIG_PARAM_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY_Get - Invalid configuration param returned (must be 0,1 or 2)
//
#define ITC_RCSG_SYMID_GET_INVALID_CONFIG_PARAM_E 0xC1470037L

//
// MessageId: ITC_RCSG_SYMID_SET_INVALID_NUM_OF_USERDEF_CHARS_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY_Set - Invalid number of user defined characters (must be 1-4)
//
#define ITC_RCSG_SYMID_SET_INVALID_NUM_OF_USERDEF_CHARS_E 0xC1470038L

//
// MessageId: ITC_RCSG_SYMID_SET_INVALID_CONFIG_PARAM_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::APIscpSymbologyID_CY_Set - Invalid configuration param (must be 0,1 or 2)
//
#define ITC_RCSG_SYMID_SET_INVALID_CONFIG_PARAM_E 0xC1470039L

//
// MessageId: ITC_RCSG_OUTPUT_BUFFER_OVERRUN_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::WriteByteToOutputBuffer - Insufficient output buffer provided to receive results
//
#define ITC_RCSG_OUTPUT_BUFFER_OVERRUN_E 0xC147003AL

//
// MessageId: ITC_RCSG_INPUT_BUFFER_PREMATURELY_EMTPY_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::GetCurrentByteFromInputBuffer - Input buffer prematurely empty
//
#define ITC_RCSG_INPUT_BUFFER_PREMATURELY_EMTPY_E 0xC147003BL

//
// MessageId: ITC_RCSG_SYMID_TOO_MANY_INPUT_ROWS_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::ProcessIscpCommand - Maximum number of input rows exceeded, MAX_INPUT_ROWS must be increased
//
#define ITC_RCSG_SYMID_TOO_MANY_INPUT_ROWS_E 0xC147003CL

//
// MessageId: ITC_RCSG_REG_BUFFSIZE_OPEN_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::RegGetDword - Could not open maximum processing buffer size.  Default to 4096.
//
#define ITC_RCSG_REG_BUFFSIZE_OPEN_E     0xC147003DL

//
// MessageId: ITC_RCSG_REG_BUFFSIZE_READ_E
//
// MessageText:
//
//  CReaderCommandSnmpGateway::RegGetDword - Could not read maximum processing buffer size.  Default to 4096.
//
#define ITC_RCSG_REG_BUFFSIZE_READ_E     0xC147003EL

#endif  // THIS LINE MUST BE AFTER ANY MESSAGE DEFINITIONS.
////////////////////////////////////////////////////////////////////
//  END OF FILE:  ReaderCommandSnmpGateway.mcs
//  COPYRIGHT (c) 1998 INTERMEC CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  S9CDeviceHandler.mcs
//
//  AUTHOR:     
//
// COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_S9CDeviceHandler_MSG
#define INCLUDED_S9CDeviceHandler_MSG
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_S9CDH_INITENTRY_I
//
// MessageText:
//
//  CS9CDH::Initialize Entry
//
#define ITC_S9CDH_INITENTRY_I            0x414C0000L

//
// MessageId: ITC_S9CDH_READENTRY_I
//
// MessageText:
//
//  CS9CDH::Read Entry
//
#define ITC_S9CDH_READENTRY_I            0x414C0001L

//
// MessageId: ITC_S9CDH_INITEXIT_I
//
// MessageText:
//
//  CS9CDH::Initialize Exit. Status: 0x%1!08X!
//
#define ITC_S9CDH_INITEXIT_I             0x414C0002L

//
// MessageId: ITC_S9CDH_READEXIT_I
//
// MessageText:
//
//  CS9CDH::Read Exit. Status: %1!08X!
//
#define ITC_S9CDH_READEXIT_I             0x414C0003L

//
// MessageId: ITC_S9CDH_OPENENTRY_I
//
// MessageText:
//
//  CS9CDH::Open Entry *pwClientHandle: 0x%1!08X!
//
#define ITC_S9CDH_OPENENTRY_I            0x414C0004L

//
// MessageId: ITC_S9CDH_OPENEXIT_I
//
// MessageText:
//
//  CS9CDH::Open Exit *pwClientHandle: 0x%1!08X!
//
#define ITC_S9CDH_OPENEXIT_I             0x414C0005L

//
// MessageId: ITC_S9CDH_CLOSEENTRYEXIT_I
//
// MessageText:
//
//  CS9CDH::Close Entry/Exit. bClientHandle: %1!d!
//
#define ITC_S9CDH_CLOSEENTRYEXIT_I       0x414C0006L

//
// MessageId: ITC_S9CDH_READDCENTRYEXIT_I
//
// MessageText:
//
//  CS9CDH::ReadDataClass Entry/Exit
//
#define ITC_S9CDH_READDCENTRYEXIT_I      0x414C0007L

//
// MessageId: ITC_S9CDH_CANCELREQUEST_ENTRYEXIT_I
//
// MessageText:
//
//  CS9CDH::CancelRequest Entry/Exit. bClientHandle: %1!d!
//
#define ITC_S9CDH_CANCELREQUEST_ENTRYEXIT_I 0x414C0008L

//
// MessageId: ITC_S9CDH_WRITEENTRY_I
//
// MessageText:
//
//  CS9CDH::Write Entry.  Bytes to write: %1!d!; Cmd: %2!d! 
//
#define ITC_S9CDH_WRITEENTRY_I           0x414C0009L

//
// MessageId: ITC_S9CDH_WRITEEXIT_I
//
// MessageText:
//
//  CS9CDH::Write Exit. hrStatus: 0x0x%1!08X!; Bytes returned: %2!d!
//
#define ITC_S9CDH_WRITEEXIT_I            0x414C000AL

//
// MessageId: ITC_S9CDH_TRIGSTATE_I
//
// MessageText:
//
//  CS9CProtocol::TriggerThread Trigger State: %1!d!
//
#define ITC_S9CDH_TRIGSTATE_I            0x414C000BL

//
// MessageId: ITC_S9CDH_S9CEEPROM_WAIT_I
//
// MessageText:
//
//  CS9CProtocol::PowerDownS9C waiting %1!d! msecs for S9C to drop DSR.
//
#define ITC_S9CDH_S9CEEPROM_WAIT_I       0x414C000CL

//
// MessageId: ITC_S9CDH_SETSCANPOWER_I
//
// MessageText:
//
//  CSysIO::SetScanPower Setting Scan Power to %1!d!
//
#define ITC_S9CDH_SETSCANPOWER_I         0x414C000DL

//
// MessageId: ITC_S9CDH_ENTER_PWRDWNS9C_I
//
// MessageText:
//
//  S9CPower::PowerDown Enter.
//
#define ITC_S9CDH_ENTER_PWRDWNS9C_I      0x414C000EL

//
// MessageId: ITC_S9CDH_ENTER_PWRUPS9C_I
//
// MessageText:
//
//  CS9CPower::PowerUp Enter.
//
#define ITC_S9CDH_ENTER_PWRUPS9C_I       0x414C000FL

//
// MessageId: ITC_S9CDH_SETSCANFLASHENABLE_I
//
// MessageText:
//
//  CSysIO::SetScanFlashEnable Setting S9C Scan Flash enable to %1!d!
//
#define ITC_S9CDH_SETSCANFLASHENABLE_I   0x414C0010L

//
// MessageId: ITC_S9CDH_SETSCANLED_I
//
// MessageText:
//
//  CSysIO::SetScanLED Setting Scan LED enable to %1!d!
//
#define ITC_S9CDH_SETSCANLED_I           0x414C0011L

//
// MessageId: ITC_S9CDH_GETSCANLED_I
//
// MessageText:
//
//  CSysIO::GetScanLED Scan LED enable is %1!d!
//
#define ITC_S9CDH_GETSCANLED_I           0x414C0012L

//
// MessageId: ITC_S9CDH_VALIDATEANDSETCONFIG_ENTRY_I
//
// MessageText:
//
//  CS9CDH::ValidateAndSetConfig Entry: 0x%1!08X!
//
#define ITC_S9CDH_VALIDATEANDSETCONFIG_ENTRY_I 0x414C0013L

//
// MessageId: ITC_S9CDH_VALIDATEANDSETCONFIG_EXIT_I
//
// MessageText:
//
//  CS9CDH::ValidateAndSetConfig Exit hr: 0x%1!08X!
//
#define ITC_S9CDH_VALIDATEANDSETCONFIG_EXIT_I 0x414C0014L

//
// MessageId: ITC_S9CDH_UPDATECONFIG_ENTRY_I
//
// MessageText:
//
//  CS9CDH::UpdateConfig Entry: 0x%1!08X!
//
#define ITC_S9CDH_UPDATECONFIG_ENTRY_I   0x414C0015L

//
// MessageId: ITC_S9CDH_UPDATECONFIG_EXIT_I
//
// MessageText:
//
//  CS9CDH::UpdateConfig Exit hr: 0x%1!08X!
//
#define ITC_S9CDH_UPDATECONFIG_EXIT_I    0x414C0016L

//
// MessageId: ITC_S9CDH_HANDLESETCONFIG_ENTRY_I
//
// MessageText:
//
//  CS9CDH::HandleSetConfig Entry: 0x%1!08X!
//
#define ITC_S9CDH_HANDLESETCONFIG_ENTRY_I 0x414C0017L

//
// MessageId: ITC_S9CDH_HANDLEGETCONFIG_ENTRY_I
//
// MessageText:
//
//  CS9CDH::HandleGetConfig Entry: 0x%1!08X!
//
#define ITC_S9CDH_HANDLEGETCONFIG_ENTRY_I 0x414C0018L

//
// MessageId: ITC_S9CDH_HANDLESETCONFIG_EXIT_I
//
// MessageText:
//
//  CS9CDH::HandleSetConfig Exit, hr: 0x%1!08X!
//
#define ITC_S9CDH_HANDLESETCONFIG_EXIT_I 0x414C0019L

//
// MessageId: ITC_S9CDH_HANDLEGETCONFIG_EXIT_I
//
// MessageText:
//
//  CS9CDH::HandleGetConfig Exit, hr: 0x%1!08X!
//
#define ITC_S9CDH_HANDLEGETCONFIG_EXIT_I 0x414C001AL

//
// MessageId: ITC_S9CDH_GETCONFIG_ENTRY_I
//
// MessageText:
//
//  CS9CDH::GetConfig Entry: 0x%1!08X!
//
#define ITC_S9CDH_GETCONFIG_ENTRY_I      0x414C001BL

//
// MessageId: ITC_S9CDH_GETCONFIG_EXIT_I
//
// MessageText:
//
//  CS9CDH::GetConfig EXIT, hr: 0x%1!08X!
//
#define ITC_S9CDH_GETCONFIG_EXIT_I       0x414C001CL

//
// MessageId: ITC_S9CDH_SENDS9CCONFIG_ENTRY_I
//
// MessageText:
//
//  CS9CDH::SendS9CConfig Entry:  0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_SENDS9CCONFIG_ENTRY_I  0x414C001DL

//
// MessageId: ITC_S9CDH_SENDS9CCONFIG_EXIT_I
//
// MessageText:
//
//  CS9CDH::SendS9CConfig EXIT:  Time in this function: 0x%1!08X! msec, 0x%2!08X!
//
#define ITC_S9CDH_SENDS9CCONFIG_EXIT_I   0x414C001EL

//
// MessageId: ITC_S9CDH_SENDS9CCONFIG_LOOP_I
//
// MessageText:
//
//  CS9CDH::SendS9CConfig:  Loop #: 0x%1!08X!,  0x%2!08X!
//
#define ITC_S9CDH_SENDS9CCONFIG_LOOP_I   0x414C001FL

//
// MessageId: ITC_S9CDH_INITS9C_ENTRY_I
//
// MessageText:
//
//  CS9CDH::InitS9C Entry:  0x%1!08X!,  0x%2!08X!
//
#define ITC_S9CDH_INITS9C_ENTRY_I        0x414C0020L

//
// MessageId: ITC_S9CDH_INITS9C_EXIT_I
//
// MessageText:
//
//  CS9CDH::InitS9C Exit:  0x%1!08X!,  0x%2!08X!
//
#define ITC_S9CDH_INITS9C_EXIT_I         0x414C0021L

//
// MessageId: ITC_S9CDH_READLABEL_ENTRY_I
//
// MessageText:
//
//  CS9CDH::ReadLabel Entry:  0x%1!08X!,  0x%2!08X!
//
#define ITC_S9CDH_READLABEL_ENTRY_I      0x414C0022L

//
// MessageId: ITC_S9CDH_READLABEL_EXIT_I
//
// MessageText:
//
//  CS9CDH::ReadLabel Exit:  0x%1!08X!,  0x%2!08X!
//
#define ITC_S9CDH_READLABEL_EXIT_I       0x414C0023L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_EXIT_I
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd Exit:  0x%1!08X!,  0x%2!08X!
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_EXIT_I 0x414C0024L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_ENTRY_I
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd Entry:  0x%1!08X!,  0x%2!08X!
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_ENTRY_I 0x414C0025L

//
// MessageId: ITC_S9CDH_WRITEPACKET_I
//
// MessageText:
//
//  CProtocol::WritePacket: #bytes actually written: %1!d!, #bytes requested to write: %2!d!
//
#define ITC_S9CDH_WRITEPACKET_I          0x414C0026L

//
// MessageId: ITC_S9CDH_WRITEFILE_BYTES_I
//
// MessageText:
//
//  CProtocol::WritePacket data: 0x%1!08x! 0x%2!08x!
//
#define ITC_S9CDH_WRITEFILE_BYTES_I      0x414C0027L

//
// MessageId: ITC_S9CDH_GETVERSIONINFO_ENTRY_I
//
// MessageText:
//
//  CS9CDH::GetVersionInfo Entry: 0x%1!08x! 0x%2!08x!
//
#define ITC_S9CDH_GETVERSIONINFO_ENTRY_I 0x414C0028L

//
// MessageId: ITC_S9CDH_GETVERSIONINFO_EXIT_I
//
// MessageText:
//
//  CS9CDH::GetVersionInfo Exit: 0x%1!08x! 0x%2!08x!
//
#define ITC_S9CDH_GETVERSIONINFO_EXIT_I  0x414C0029L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_BEFORE_ENTER_CRITICAL_SECTION_I
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd - Before EnterCriticalSection, LoadLibrary returned with: 0x%1!08x!
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_BEFORE_ENTER_CRITICAL_SECTION_I 0x414C002AL

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_AFTER_ENTER_CRITICAL_SECTION_I
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd - EnterCriticalSection Successfully.
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_AFTER_ENTER_CRITICAL_SECTION_I 0x414C002BL

//
// MessageId: ITC_S9CDH_READPACKET_I
//
// MessageText:
//
//  CProtocol::ReadPacket: #bytes actually read: %1!d!,  #bytes requested to read: %2!d!
//
#define ITC_S9CDH_READPACKET_I           0x414C002CL

//
// MessageId: ITC_S9CDH_READPACKET_BYTES_I
//
// MessageText:
//
//  CProtocol::ReadPacket data: 0x%1!08x! 0x%2!08x!
//
#define ITC_S9CDH_READPACKET_BYTES_I     0x414C002DL

//
// MessageId: ITC_S9CDH_READLABEL_AFTER_ENTERCRITICALSECTION_I
//
// MessageText:
//
//  CS9CDH::ReadLabel After EnterCriticalSection :  #%1!d!  
//
#define ITC_S9CDH_READLABEL_AFTER_ENTERCRITICALSECTION_I 0x414C002EL

//
// MessageId: ITC_S9CDH_READLABEL_AFTER_LEAVECRITICALSECTION_I
//
// MessageText:
//
//  CS9CDH::ReadLabel After LeaveCriticalSection :  #%1!d!  
//
#define ITC_S9CDH_READLABEL_AFTER_LEAVECRITICALSECTION_I 0x414C002FL

//
// MessageId: ITC_S9CDH_SETREADTIMEOUT_I
//
// MessageText:
//
//  CS9CProtocol::SetReadTimeout =  %1!d! msec
//
#define ITC_S9CDH_SETREADTIMEOUT_I       0x414C0030L

//
// MessageId: ITC_S9CDH_DEVICEENABLED_ENTRY_I
//
// MessageText:
//
//  CS9CDH::DeviceEnabled, *fpEnabled:  %1!d!
//
#define ITC_S9CDH_DEVICEENABLED_ENTRY_I  0x414C0031L

//
// MessageId: ITC_S9CDH_DEVICEENABLED_EXIT_I
//
// MessageText:
//
//  CS9CDH::DeviceEnabled Exit, hrStatus:  0x%1!08x!
//
#define ITC_S9CDH_DEVICEENABLED_EXIT_I   0x414C0032L

//
// MessageId: ITC_S9CDH_SETATTRIBUTE_EXIT_I
//
// MessageText:
//
//  CS9CDH::SetAttribute Exit, hrStatus:  0x%1!08x!
//
#define ITC_S9CDH_SETATTRIBUTE_EXIT_I    0x414C0033L

//
// MessageId: ITC_S9CDH_SETATTRIBUTE_ENTRY_I
//
// MessageText:
//
//  CS9CDH::DeviceEnabled, eAttribID:  %1!d!
//
#define ITC_S9CDH_SETATTRIBUTE_ENTRY_I   0x414C0034L

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_DISABLE_EXIT_I
//
// MessageText:
//
//  CS9CProtocol::Enable Exit. hrStatus:  0x%1!08x!
//
#define ITC_S9CDH_CS9CPROTOCOL_DISABLE_EXIT_I 0x414C0035L

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_DISABLE_ENTRY_I
//
// MessageText:
//
//  CS9CProtocol::Enable Entry.
//
#define ITC_S9CDH_CS9CPROTOCOL_DISABLE_ENTRY_I 0x414C0036L

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_OPENCOMMPORT_EXIT_I
//
// MessageText:
//
//  CS9CProtocol::OpenCommPort Exit. hrStatus:  0x%1!08x!
//
#define ITC_S9CDH_CS9CPROTOCOL_OPENCOMMPORT_EXIT_I 0x414C0037L

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_OPENCOMMPORT_ENTRY_I
//
// MessageText:
//
//  CS9CProtocol::OpenCommPort Entry.
//
#define ITC_S9CDH_CS9CPROTOCOL_OPENCOMMPORT_ENTRY_I 0x414C0038L

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_ENABLE_EXIT_I
//
// MessageText:
//
//  CS9CProtocol::Enable Exit. hrStatus:  0x%1!08x!
//
#define ITC_S9CDH_CS9CPROTOCOL_ENABLE_EXIT_I 0x414C0039L

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_ENABLE_ENTRY_I
//
// MessageText:
//
//  CS9CProtocol::Enable Entry.
//
#define ITC_S9CDH_CS9CPROTOCOL_ENABLE_ENTRY_I 0x414C003AL

//
// MessageId: ITC_S9CDH_AIMID_NOT_XMIT_I
//
// MessageText:
//
//  CS9CDH::: SetSymbology - S9C did not transmitted AIM Id. First byte: %1!d!;  %2!d!
//
#define ITC_S9CDH_AIMID_NOT_XMIT_I       0x414C003BL

//
// MessageId: ITC_S9CDH_READTIMEOUT_I
//
// MessageText:
//
//  CS9CProtocol::Read Timeout error. Timeout = %1!d! msec
//
#define ITC_S9CDH_READTIMEOUT_I          0x414C003CL

//
// MessageId: ITC_S9CDH_FILTERREADDATA_ENTRY_I
//
// MessageText:
//
//  CS9CDH::FilterReadData Entry. %1!d! total bytes in, %2!d! data bytes.
//
#define ITC_S9CDH_FILTERREADDATA_ENTRY_I 0x414C003DL

//
// MessageId: ITC_S9CDH_FILTERREADDATA_EXIT_I
//
// MessageText:
//
//  CS9CDH::FilterReadData Exit. Status: 0x%1!08x!, %2!d! total bytes out.
//
#define ITC_S9CDH_FILTERREADDATA_EXIT_I  0x414C003EL

//
// MessageId: ITC_S9CDH_READ_FILTERREJECT_I
//
// MessageText:
//
//  CS9CDH::Read Data rejected by filter
//
#define ITC_S9CDH_READ_FILTERREJECT_I    0x414C003FL

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_RELEASE_ENTRY_I
//
// MessageText:
//
//  CS9CProtocol::ReleaseResource Entry: 0x%1!08x!
//
#define ITC_S9CDH_CS9CPROTOCOL_RELEASE_ENTRY_I 0x414C0040L

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_RELEASE_EXIT_I
//
// MessageText:
//
//  CS9CProtocol::ReleaseResource Exit: 0x%1!08x!
//
#define ITC_S9CDH_CS9CPROTOCOL_RELEASE_EXIT_I 0x414C0041L

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_S9CDH_RDR_CMD_INIT_S
//
// MessageText:
//
//  CS9CDH::Initialize: Succeeded initializing the RCSG, 0x%1!08x! 0x%2!08x!
//
#define ITC_S9CDH_RDR_CMD_INIT_S         0x014C0000L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_DOWNLOAD_S
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd: Firmware Upgrade Function is complete with successfull status.
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_DOWNLOAD_S 0x014C0001L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_LOADLIBRARY_S
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd: LoadLibray S9CUpgrade.dll returned a successfull Status, 0x%1!08x! 
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_LOADLIBRARY_S 0x014C0002L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_GETPROCADDRESS_S
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd: GetProAddress of Firmware Upgrade Function is successfull. Firmware upgrade is in progress. Please wait...
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_GETPROCADDRESS_S 0x014C0003L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_FREELIBRARY_S
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd: FreeLibray of S9CUpgrade.dll returned a successfull status, 0x%1!08x! 
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_FREELIBRARY_S 0x014C0004L

//
// MessageId: ITC_S9CDH_GETVERSIONINFO_SENT_VOLUMEOFF_CMD_S
//
// MessageText:
//
//  CS9CDH::GetVersionInfo: Sent S9C Volume Off Cmd successfull, 0x%1!08x! 
//
#define ITC_S9CDH_GETVERSIONINFO_SENT_VOLUMEOFF_CMD_S 0x014C0005L

//
// MessageId: ITC_S9CDH_GETVERSIONINFO_SENT_GETVERSIONINFO_CMD_S
//
// MessageText:
//
//  CS9CDH::GetVersionInfo: Sent S9C Get Version Info Cmd successfull, 0x%1!08x! 
//
#define ITC_S9CDH_GETVERSIONINFO_SENT_GETVERSIONINFO_CMD_S 0x014C0006L

//
// MessageId: ITC_S9CDH_GETVERSIONINFO_READPACKETET_RETURNED_S
//
// MessageText:
//
//  CS9CDH::GetVersionInfo: ReadPacket returned with dwBytesReturned = %1!d! bytes 
//
#define ITC_S9CDH_GETVERSIONINFO_READPACKETET_RETURNED_S 0x014C0007L

////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_S9CDH_SETFILTER_COCI_W
//
// MessageText:
//
//  CS9CDH::SetFilter CoCI Failed 0x%1!08x!
//
#define ITC_S9CDH_SETFILTER_COCI_W       0x814C0008L

//
// MessageId: ITC_S9CDH_SETFILTER_COMPILE_W
//
// MessageText:
//
//  CS9CDH::SetFilter Compile Failed 0x%1!08x!
//
#define ITC_S9CDH_SETFILTER_COMPILE_W    0x814C0009L

//
// MessageId: ITC_S9CDH_NO_PREDEFINED_GET_ALL_ISCP_CMD_W
//
// MessageText:
//
//  S9CDH - CheckForAll. No Predefined GET ALL for Gid: 0x%1!08x!
//
#define ITC_S9CDH_NO_PREDEFINED_GET_ALL_ISCP_CMD_W 0x814C000AL

//
// MessageId: ITC_S9CDH_COMMANDVALID_NOT_FOUND_W
//
// MessageText:
//
//  CIscpToEasysetFrame::CommandValid, not found: GidFid: 0x%1!08x!
//
#define ITC_S9CDH_COMMANDVALID_NOT_FOUND_W 0x814C000BL

//
// MessageId: ITC_S9CDH_READPACKET_REQUEST_ABORT_W
//
// MessageText:
//
//  CS9CProtocol::ReadPacket - Abort request.
//
#define ITC_S9CDH_READPACKET_REQUEST_ABORT_W 0x814C000CL

//
// MessageId: ITC_S9CDH_WRITEPACKET_REQUEST_ABORT_W
//
// MessageText:
//
//  CS9CProtocol::WritePacket - Abort request.
//
#define ITC_S9CDH_WRITEPACKET_REQUEST_ABORT_W 0x814C000DL

//
// MessageId: ITC_S9CDH_GETOVERLAPPEDRESULT_W
//
// MessageText:
//
//  CS9CProtocol::ReadPacket - GetOverlappedResult error: dwLastError: 0x%1!08x!
//
#define ITC_S9CDH_GETOVERLAPPEDRESULT_W  0x814C000EL

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_S9CDH_READ_INVDATADETAILS_E
//
// MessageText:
//
//  CS9CDH::Read Invalid Data Details structure size. Required size: %1!d!; pass in size:  %2!d!
//
#define ITC_S9CDH_READ_INVDATADETAILS_E  0xC14C0000L

//
// MessageId: ITC_S9CDH_CREATEFILE_E
//
// MessageText:
//
//  S9CProtocol::InitCommPort CreateFile Error: 0x%1!08X!
//
#define ITC_S9CDH_CREATEFILE_E           0xC14C0001L

//
// MessageId: ITC_S9CDH_SETCOMMSTATE_E
//
// MessageText:
//
//  S9CProtocol::InitCommPort SetCommState Error: 0x%1!08X!
//
#define ITC_S9CDH_SETCOMMSTATE_E         0xC14C0002L

//
// MessageId: ITC_S9CDH_SETTIMOUT_E
//
// MessageText:
//
//  S9CProtocol::InitCommPort SetCommState Error: 0x%1!08X!
//
#define ITC_S9CDH_SETTIMOUT_E            0xC14C0003L

//
// MessageId: ITC_S9CDH_SETREAD_SETTIMOUT_E
//
// MessageText:
//
//  S9CProtocol::SetReadTimeout SetCommState Error: 0x%1!08X!
//
#define ITC_S9CDH_SETREAD_SETTIMOUT_E    0xC14C0004L

//
// MessageId: ITC_S9CDH_SETREAD_GETCOMMTIMEOUT_E
//
// MessageText:
//
//  S9CProtocol::SetReadTimeout GetCommTimeout Error: 0x%1!08X!
//
#define ITC_S9CDH_SETREAD_GETCOMMTIMEOUT_E 0xC14C0005L

//
// MessageId: ITC_S9CDH_READFILE_E
//
// MessageText:
//
//  S9CProtocol::ReadPacket ReadFile Error: 0x%1!08X!
//
#define ITC_S9CDH_READFILE_E             0xC14C0006L

//
// MessageId: ITC_S9CDH_READFILE_TIMEOUT_E
//
// MessageText:
//
//  S9CProtocol::ReadPacket ReadFile Timeout Error: 0x%1!08X!
//
#define ITC_S9CDH_READFILE_TIMEOUT_E     0xC14C0007L

//
// MessageId: ITC_S9CDH_WRITEFILE_E
//
// MessageText:
//
//  S9CProtocol::WritePacket WriteFile Error: 0x%1!08X!
//
#define ITC_S9CDH_WRITEFILE_E            0xC14C0008L

//
// MessageId: ITC_S9CDH_CREATETHREAD_E
//
// MessageText:
//
//  S9CProtocol::Initialize CreateThread Error: 0x%1!08X!
//
#define ITC_S9CDH_CREATETHREAD_E         0xC14C0009L

//
// MessageId: ITC_S9CDH_GRID_RTNDATA_E
//
// MessageText:
//
//  CS9CDH::MatchGrid Response data integrity error. Expected: %1!d!; Actual: %2!d!
//
#define ITC_S9CDH_GRID_RTNDATA_E         0xC14C000AL

//
// MessageId: ITC_S9CDH_GRID_GRIDSIZE_E
//
// MessageText:
//
//  CS9CDH::MatchGrid Response data integrity error. Expected: %1!d!; Actual: %2!d!
//
#define ITC_S9CDH_GRID_GRIDSIZE_E        0xC14C000BL

//
// MessageId: ITC_S9CDH_BUFFER_TOOSMALL_E
//
// MessageText:
//
//  CS9CProtocol::ReadPacket Buffer of size %1!d! bytes is too small to hold data.
//
#define ITC_S9CDH_BUFFER_TOOSMALL_E      0xC14C000CL

//
// MessageId: ITC_S9CDH_SYSIO_CREATEFILE_E
//
// MessageText:
//
//  CSysIO::CSysIO CreateFile error: 0x%1!08X!
//
#define ITC_S9CDH_SYSIO_CREATEFILE_E     0xC14C000DL

//
// MessageId: ITC_S9CDH_SYSIO_SCANFLASH_IOCTL_E
//
// MessageText:
//
//  CSysIO::SetScanFlashEnable DeviceIoControl error: 0x%1!08X!
//
#define ITC_S9CDH_SYSIO_SCANFLASH_IOCTL_E 0xC14C000EL

//
// MessageId: ITC_S9CDH_INDEX_OUTOFRANGE_E
//
// MessageText:
//
//  CS9CDH::SetSymbology Index mapping out of range error. Calculated Index: %1!d! %2!d!
//
#define ITC_S9CDH_INDEX_OUTOFRANGE_E     0xC14C000FL

//
// MessageId: ITC_S9CDH_INV_WRITEMSG_E
//
// MessageText:
//
//  CS9CDH::Write Invalid Message Type. m_eCommand: %1!d! 
//
#define ITC_S9CDH_INV_WRITEMSG_E         0xC14C0010L

//
// MessageId: ITC_S9CDH_S9CDSRERROR_E
//
// MessageText:
//
//  CS9CDH::PowerDownS9C S9C failed to deassert DSR in %1!d! milliseconds.
//
#define ITC_S9CDH_S9CDSRERROR_E          0xC14C0011L

//
// MessageId: ITC_S9CDH_SYSIO_SCANPOWER_IOCTL_E
//
// MessageText:
//
//  CS9CDH::SetScanPower DeviceIoControl error: 0x%1!08X!
//
#define ITC_S9CDH_SYSIO_SCANPOWER_IOCTL_E 0xC14C0012L

//
// MessageId: ITC_S9CDH_SYSIO_SETSCANLED_IOCTL_E
//
// MessageText:
//
//  CSysIO::SetScanLED DeviceIoControl error: 0x%1!08X!
//
#define ITC_S9CDH_SYSIO_SETSCANLED_IOCTL_E 0xC14C0013L

//
// MessageId: ITC_S9CDH_SYSIO_GETSCANLED_IOCTL_E
//
// MessageText:
//
//  CSysIO::GetScanLED DeviceIoControl error: 0x%1!08X!
//
#define ITC_S9CDH_SYSIO_GETSCANLED_IOCTL_E 0xC14C0014L

//
// MessageId: ITC_S9CDH_CS9CPM_CREATETHREAD_E
//
// MessageText:
//
//  CS9CProtocol::InitCommPort CreateThread error: 0x%1!08X!
//
#define ITC_S9CDH_CS9CPM_CREATETHREAD_E  0xC14C0015L

//
// MessageId: ITC_S9CDH_VALIDATEANDSETCONFIG_INVALIDARG_E
//
// MessageText:
//
//  CS9CDH::ValidateAndSetConfig invalid command: 0x%1!08X!
//
#define ITC_S9CDH_VALIDATEANDSETCONFIG_INVALIDARG_E 0xC14C0016L

//
// MessageId: ITC_S9CDH_VALIDATEANDSETCONFIG_FAILED_UPDATECONFIG_E
//
// MessageText:
//
//  CS9CDH::ValidateAndSetConfig error returned from UpdateConfig hr: 0x%1!08X!
//
#define ITC_S9CDH_VALIDATEANDSETCONFIG_FAILED_UPDATECONFIG_E 0xC14C0017L

//
// MessageId: ITC_S9CDH_UPDATECONFIG_REGISTRY_E
//
// MessageText:
//
//  CS9CDH::UpdateConfig - Registry sub system throw exception with hr: 0x%1!08X!
//
#define ITC_S9CDH_UPDATECONFIG_REGISTRY_E 0xC14C0018L

//
// MessageId: ITC_S9CDH_HANDLESETCONFIG_INVALIDARG_E
//
// MessageText:
//
//  CS9CDH::HandleSetConfig - Error! Invalid configuration id enum: %1!d!
//
#define ITC_S9CDH_HANDLESETCONFIG_INVALIDARG_E 0xC14C0019L

//
// MessageId: ITC_S9CDH_HANDLEGETCONFIG_INVALIDARG_E
//
// MessageText:
//
//  CS9CDH::HandleGetConfig - Error! Invalid configuration id enum: %1!d!
//
#define ITC_S9CDH_HANDLEGETCONFIG_INVALIDARG_E 0xC14C001AL

//
// MessageId: ITC_S9CDH_GETCONFIG_BUFFER_TOOSMALL_E
//
// MessageText:
//
//  CS9CDH::HandleSetConfig - Error! Buffer is too small: dwIndex: %1!d! > allocated: %2!d!
//
#define ITC_S9CDH_GETCONFIG_BUFFER_TOOSMALL_E 0xC14C001BL

//
// MessageId: ITC_S9CDH_GETCONFIG_ENUMVALUE_E
//
// MessageText:
//
//  CS9CDH::HandleGetConfig - Error returned from EnumValue(), hr: 0x%1!08X!
//
#define ITC_S9CDH_GETCONFIG_ENUMVALUE_E  0xC14C001CL

//
// MessageId: ITC_S9CDH_SETCONFIGCMDBUFFER_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  CS9CDH::CS9CRequestGetConfig::SetConfigCmdBuffer - Error! Buffer is too small: dataLength: %1!d! > allocated: %2!d!
//
#define ITC_S9CDH_SETCONFIGCMDBUFFER_BUFFER_TOO_SMALL_E 0xC14C001DL

//
// MessageId: ITC_S9CDH_SENDS9CCONFIG_ENUMVALUE_E
//
// MessageText:
//
//  CS9CDH::SendS9CConfig - Error returned from RegEnumValue! :0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_SENDS9CCONFIG_ENUMVALUE_E 0xC14C001EL

//
// MessageId: ITC_S9CDH_DOWNLOADCMD_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  CS9CDH::CS9CDownLoadCmd  - Error! Buffer is too small: nFileNames: %1!d! > allocated: %2!d!
//
#define ITC_S9CDH_DOWNLOADCMD_BUFFER_TOO_SMALL_E 0xC14C001FL

//
// MessageId: ITC_S9CDH_ENUMTOVALUENAME_SUBID_E
//
// MessageText:
//
//  CS9CDH::EnumToValueName - Error! No matching registry value name for eSubId: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_ENUMTOVALUENAME_SUBID_E 0xC14C0020L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_GETPROCADDRESS_E
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd - GetProcAddress GetLastError: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_GETPROCADDRESS_E 0xC14C0021L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_LOADLIBRARY_E
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd - LoadLibrary GetLastError: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_LOADLIBRARY_E 0xC14C0022L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_FREELIBRARY_E
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd - FreeLibrary GetLastError: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_FREELIBRARY_E 0xC14C0023L

//
// MessageId: ITC_S9CDH_DOWNLOADCMD_FILENAMES_NULL_E
//
// MessageText:
//
//  CS9CDH::CS9CDownLoadCmd  - Error! FileNames buffer is NULL: nFileNames: %1!d!, %2!d!
//
#define ITC_S9CDH_DOWNLOADCMD_FILENAMES_NULL_E 0xC14C0024L

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_FILENAMES_NULL_E
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd - Some null file names: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_FILENAMES_NULL_E 0xC14C0025L

//
// MessageId: ITC_S9CDH_DOWNLOADCMD_BAD_FORMAT_E
//
// MessageText:
//
//  CS9CDH::CS9CDownLoadCmd - File names string has bad format, no comma delimiters: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_DOWNLOADCMD_BAD_FORMAT_E 0xC14C0026L

//
// MessageId: ITC_S9CDH_INIT_READERCMD_E
//
// MessageText:
//
//  CS9CDH::Initialize - Failed to initialize IReaderCommand, hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_INIT_READERCMD_E       0xC14C0027L

//
// MessageId: ITC_S9CDH_COCI_READERCMD_E
//
// MessageText:
//
//  CS9CDH::Initialize - Failed to CoCreateInstance IReaderCommand, hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_COCI_READERCMD_E       0xC14C0028L

//
// MessageId: ITC_S9CDH_NORCSGCLSID_E
//
// MessageText:
//
//  CS9CDH::Initialize - Failed to CLSIDFromProgID of RCSG, hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_NORCSGCLSID_E          0xC14C0029L

//
// MessageId: ITC_S9CDH_GETVERSIONINFO_REGISTRY_E
//
// MessageText:
//
//  CS9CDH::GetVersionInfo - Error Returned From CRegistry, hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_GETVERSIONINFO_REGISTRY_E 0xC14C002AL

//
// MessageId: ITC_S9CDH_HANDLEDOWNLOADCMD_DOWNLOAD_E
//
// MessageText:
//
//  CS9CDH::HandleDownLoadCmd - S9CUpgrade Function returned an error: 0x%1!08X!, 0x%2!08X!
//
#define ITC_S9CDH_HANDLEDOWNLOADCMD_DOWNLOAD_E 0xC14C002BL

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_CREATEFILE_E
//
// MessageText:
//
//  CS9CProtocol::OpenCommPort CreateFile Error: 0x%1!08X!
//
#define ITC_S9CDH_CS9CPROTOCOL_CREATEFILE_E 0xC14C002CL

//
// MessageId: ITC_S9CDH_CS9CPROTOCOL_DISABLE_CLOSE_COMMPORT_E
//
// MessageText:
//
//  CS9CProtocol::Disable CloseHandle Error: 0x%1!08X!
//
#define ITC_S9CDH_CS9CPROTOCOL_DISABLE_CLOSE_COMMPORT_E 0xC14C002DL

//
// MessageId: ITC_S9CDH_QUERYATTRIBUTESIZE_E
//
// MessageText:
//
//  CS9CDH::QueryAttribute: Error: object size is %1!d!, dwBufferSize is %2!d!. 
//
#define ITC_S9CDH_QUERYATTRIBUTESIZE_E   0xC14C002EL

//
// MessageId: ITC_S9CDH_READSIZE_E
//
// MessageText:
//
//  CS9CDH::FilterReadData: Error: data size is %1!d!, buffer size is %2!d!. 
//
#define ITC_S9CDH_READSIZE_E             0xC14C002FL

//
// MessageId: ITC_S9CDH_INVALID_BARCODE_LEN_E
//
// MessageText:
//
//  CIscpToEasysetFrame::ToFixedLenEasysetFmt: Invalid Barcode Length. 
//
#define ITC_S9CDH_INVALID_BARCODE_LEN_E  0xC14C0030L

//
// MessageId: ITC_S9CDH_INVALID_ISCP_TYPE_E
//
// MessageText:
//
//  CIscpToEasysetFrame::ProcessRequest. Invalid ISCP Type:  %1!d!
//
#define ITC_S9CDH_INVALID_ISCP_TYPE_E    0xC14C0031L

//
// MessageId: ITC_S9CDH_PRODUCT_IDENTIFICATION_FAILED_E
//
// MessageText:
//
//  CS9CProtocol::AutoBaudDetection: Product Identification Failed on Port: %1!d!
//
#define ITC_S9CDH_PRODUCT_IDENTIFICATION_FAILED_E 0xC14C0032L

//
// MessageId: ITC_S9CDH_VALIDATEITEM_INVALID_ARG_E
//
// MessageText:
//
//  CIscpToEasysetFrame::ValidateItem: Invalid Argument: %1!d!
//
#define ITC_S9CDH_VALIDATEITEM_INVALID_ARG_E 0xC14C0033L

//
// MessageId: ITC_S9CDH_ASCIITOPARAM_E
//
// MessageText:
//
//  CIscpToEasysetFrame::AsciiToParam: ASCII value not support: %1!x!
//
#define ITC_S9CDH_ASCIITOPARAM_E         0xC14C0034L

//
// MessageId: ITC_S9CDH_WRITEFILE_TIMEOUT_E
//
// MessageText:
//
//  S9CProtocol::WritePacket WriteFile Timeout Error: Req:%1!d! bytes, Written:%2!d! bytes
//
#define ITC_S9CDH_WRITEFILE_TIMEOUT_E    0xC14C0035L

//
// MessageId: ITC_S9CDH_SETUP_WRITE_CONFIG_NOT_FOUND_E
//
// MessageText:
//
//  CIscpToEasysetFrame::ToEasysetCmd - Cannot find matching dwGidFid in the table: %1!x!
//
#define ITC_S9CDH_SETUP_WRITE_CONFIG_NOT_FOUND_E 0xC14C0036L

//
// MessageId: ITC_S9CDH_SETUP_READ_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  CIscpToEasysetFrame::HandleSetupRead - Resp buffer Too Small: Resp size %1!d!, Expected size: %2!d!
//
#define ITC_S9CDH_SETUP_READ_BUFFER_TOO_SMALL_E 0xC14C0037L

//
// MessageId: ITC_S9CDH_TOEASYSETCMD_SETB_FIXEDUP_INVALID_PARAMETER_E
//
// MessageText:
//
//  CIscpToEasysetFrame::ToEasysetCmd - Invalid Parameter: parm: %1!d!, Range (%2!d!, %3!d!)
//
#define ITC_S9CDH_TOEASYSETCMD_SETB_FIXEDUP_INVALID_PARAMETER_E 0xC14C0038L

//
// MessageId: ITC_S9CDH_FIXEDUPISCPCMD_NO_FUNCTION_E
//
// MessageText:
//
//  CIscpToEasysetFrame::FixedUpIscpCmd - No FixedUp function for Gid: %1!x!
//
#define ITC_S9CDH_FIXEDUPISCPCMD_NO_FUNCTION_E 0xC14C0039L

//
// MessageId: ITC_S9CDH_FIXEDUPISCPCMD_NO_MATCHING_GID_E
//
// MessageText:
//
//  CIscpToEasysetFrame::FixedUpIscpCmd - No matching Gid: %1!x! in the Fixedup Funtion Table
//
#define ITC_S9CDH_FIXEDUPISCPCMD_NO_MATCHING_GID_E 0xC14C003AL

//
// MessageId: ITC_S9CDH_READ_RETURNED_ZERO_BYTE_E
//
// MessageText:
//
//  S9CProtocol::Read Error: 0x%1!08X!
//
#define ITC_S9CDH_READ_RETURNED_ZERO_BYTE_E 0xC14C003BL

//
// MessageId: ITC_S9CDH_ESCAPECOMMFUNCTION_E
//
// MessageText:
//
//  S9CProtocol::Enable. EscapeCommFunction error: GetLastError: 0x%1!08X!
//
#define ITC_S9CDH_ESCAPECOMMFUNCTION_E   0xC14C003CL

//
// MessageId: ITC_S9CDH_UDSI_BUFFER_TOO_SMALL_E
//
// MessageText:
//
//  CCustomIdMgr - Response Buffer is too small.
//
#define ITC_S9CDH_UDSI_BUFFER_TOO_SMALL_E 0xC14C003DL

#endif
////////////////////////////////////////////////////////////////////
// END OF FILE:  S9CDeviceHandler.mcs
//  COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////
//
//  FILE NAME:  S9CISCPPH.mcs
//
//  AUTHOR:     
//
// COPYRIGHT (c) 2001 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
//
////////////////////////////////////////////////////////////////////
#ifndef INCLUDED_S9CISCPPH_MSG
#define INCLUDED_S9CISCPPH_MSG
////////////////////////////////////////////////////////////////////
//
//  Informational Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_ISCPPH_INITENTRY_I
//
// MessageText:
//
//  CISCPPH::Initialize Entry
//
#define ITC_ISCPPH_INITENTRY_I           0x41560000L

//
// MessageId: ITC_ISCPPH_INITEXIT_I
//
// MessageText:
//
//  CISCPPH::Initialize Exit.  Status: 0x%1!08X!
//
#define ITC_ISCPPH_INITEXIT_I            0x41560001L

//
// MessageId: ITC_ISCPPH_READENTRY_I
//
// MessageText:
//
//  CISCPPH::Read Entry
//
#define ITC_ISCPPH_READENTRY_I           0x41560002L

//
// MessageId: ITC_ISCPPH_READEXIT_I
//
// MessageText:
//
//  CISCPPH::Read Exit.  Status: 0x%1!08X!
//
#define ITC_ISCPPH_READEXIT_I            0x41560003L

//
// MessageId: ITC_ISCPPH_CANCELREADENTRY_I
//
// MessageText:
//
//  CISCPPH::CancelReadRequest Entry
//
#define ITC_ISCPPH_CANCELREADENTRY_I     0x41560004L

//
// MessageId: ITC_ISCPPH_SETATTRENTRY_I
//
// MessageText:
//
//  CISCPPH::SetAttribute Entry. Attribute ID: %1!d!
//
#define ITC_ISCPPH_SETATTRENTRY_I        0x41560005L

//
// MessageId: ITC_ISCPPH_SETATTREXIT_I
//
// MessageText:
//
//  CISCPPH::SetAttribute Exit.  Status: 0x%1!08X!
//
#define ITC_ISCPPH_SETATTREXIT_I         0x41560006L

//
// MessageId: ITC_ISCPPH_QUERYATTRENTRY_I
//
// MessageText:
//
//  CISCPPH::QueryAttribute Entry. Attribute ID: %1!d!
//
#define ITC_ISCPPH_QUERYATTRENTRY_I      0x41560007L

//
// MessageId: ITC_ISCPPH_QUERYATTREXIT_I
//
// MessageText:
//
//  CISCPPH::QueryAttribute Exit.  Status: 0x%1!08X!
//
#define ITC_ISCPPH_QUERYATTREXIT_I       0x41560008L

//
// MessageId: ITC_ISCPPH_QUERYDATA_ENTRY_I
//
// MessageText:
//
//  CISCPPH::QueryData Entry. 
//
#define ITC_ISCPPH_QUERYDATA_ENTRY_I     0x41560009L

//
// MessageId: ITC_ISCPPH_QUERYDATAEXIT_I
//
// MessageText:
//
//  CISCPPH::QueryData Exit.  Status: 0x%1!08X!; Bytes Buffered: %2!d!
//
#define ITC_ISCPPH_QUERYDATAEXIT_I       0x4156000AL

//
// MessageId: ITC_ISCPPH_IBCREAD_ENTRY_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::Read Entry
//
#define ITC_ISCPPH_IBCREAD_ENTRY_I       0x4156000BL

//
// MessageId: ITC_ISCPPH_IBCREAD_EXIT_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::Read Exit Status: 0x%1!08X!
//
#define ITC_ISCPPH_IBCREAD_EXIT_I        0x4156000CL

//
// MessageId: ITC_ISCPPH_IBCCANCELREAD_ENTRY_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::CancelReadRequest Entry
//
#define ITC_ISCPPH_IBCCANCELREAD_ENTRY_I 0x4156000DL

//
// MessageId: ITC_ISCPPH_IBCCANCELREAD_EXIT_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::CancelReadRequest Exit Status: 0x%1!08X!
//
#define ITC_ISCPPH_IBCCANCELREAD_EXIT_I  0x4156000EL

//
// MessageId: ITC_ISCPPH_IBCQUERYATTR_ENTRY_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::QueryAttribute Entry Attribute: %1!d!
//
#define ITC_ISCPPH_IBCQUERYATTR_ENTRY_I  0x4156000FL

//
// MessageId: ITC_ISCPPH_IBCQUERYATTR_EXIT_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::QueryAttribute Exit Status: 0x%1!08X!
//
#define ITC_ISCPPH_IBCQUERYATTR_EXIT_I   0x41560010L

//
// MessageId: ITC_ISCPPH_IBCSETATTR_ENTRY_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::SetAttribute Entry Attribute: %1!d!
//
#define ITC_ISCPPH_IBCSETATTR_ENTRY_I    0x41560011L

//
// MessageId: ITC_ISCPPH_IBCSETATTR_EXIT_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::SetAttribute Exit Status: 0x%1!08X!
//
#define ITC_ISCPPH_IBCSETATTR_EXIT_I     0x41560012L

//
// MessageId: ITC_ISCPPH_IBCTRIGSCANNER_ENTRY_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::TriggerScanner Entry
//
#define ITC_ISCPPH_IBCTRIGSCANNER_ENTRY_I 0x41560013L

//
// MessageId: ITC_ISCPPH_IBCTRIGSCANNER_EXIT_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::TriggerScanner Exit Status: 0x%1!08X!
//
#define ITC_ISCPPH_IBCTRIGSCANNER_EXIT_I 0x41560014L

//
// MessageId: ITC_ISCPPH_IBCCONTROLLED_ENTRY_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::ControlLED Entry. LED on: %1!d!
//
#define ITC_ISCPPH_IBCCONTROLLED_ENTRY_I 0x41560015L

//
// MessageId: ITC_ISCPPH_IBCCONTROLLED_EXIT_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::ControlLED Exit Status: 0x%1!08X!
//
#define ITC_ISCPPH_IBCCONTROLLED_EXIT_I  0x41560016L

//
// MessageId: ITC_ISCPPH_GETCONFIG_ENTRY_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::GetConfig Entry: 0x%1!08X!, 0x%2!08X!
//
#define ITC_ISCPPH_GETCONFIG_ENTRY_I     0x41560017L

//
// MessageId: ITC_ISCPPH_GETCONFIG_EXIT_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControlGetConfig Exit, hrStatus: 0x%1!08X!, dwReplyBuffSize: 0x%2!08X!
//
#define ITC_ISCPPH_GETCONFIG_EXIT_I      0x41560018L

//
// MessageId: ITC_ISCPPH_SETCONFIG_ENTRY_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::SetConfig Entry: eRequestConfigId: 0x%1!08X!, nConfigBytes:0x%2!08X!
//
#define ITC_ISCPPH_SETCONFIG_ENTRY_I     0x41560019L

//
// MessageId: ITC_ISCPPH_SETCONFIG_EXIT_I
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::SetConfig Exit, hrStatus: 0x%1!08X!, dwReplyBuffSize: 0x%2!08X!
//
#define ITC_ISCPPH_SETCONFIG_EXIT_I      0x4156001AL

//
// MessageId: ITC_ISCPPH_SETXX_ENTRY_I
//
// MessageText:
//
//  CISCPPH::Setxx Entry: FunctionID: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETXX_ENTRY_I         0x4156001BL

//
// MessageId: ITC_ISCPPH_SETXX_EXIT_I
//
// MessageText:
//
//  CISCPPH::Setxx Exit: FunctionID: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETXX_EXIT_I          0x4156001CL

//
// MessageId: ITC_ISCPPH_GETCODE93_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetCode93 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODE93_ENTRY_I     0x4156001DL

//
// MessageId: ITC_ISCPPH_GETCODE93_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetCode93 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODE93_EXIT_I      0x4156001EL

//
// MessageId: ITC_ISCPPH_TOSETCONFIGFMTLEN_ENTRY_I
//
// MessageText:
//
//  CISCPPH::ToSetConfigFmtLen Entry: Parm1 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_TOSETCONFIGFMTLEN_ENTRY_I 0x4156001FL

//
// MessageId: ITC_ISCPPH_TOSETCONFIGFMTLEN_EXIT_I
//
// MessageText:
//
//  CISCPPH::ToSetConfigFmtLen Exit: Parm1 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_TOSETCONFIGFMTLEN_EXIT_I 0x41560020L

//
// MessageId: ITC_ISCPPH_SETCODE93_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetCode93Decode Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETCODE93_ENTRY_I     0x41560021L

//
// MessageId: ITC_ISCPPH_SETCODE93_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetCode93Decode Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETCODE93_EXIT_I      0x41560022L

//
// MessageId: ITC_ISCPPH_SETCODE39_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetCode39 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETCODE39_ENTRY_I     0x41560023L

//
// MessageId: ITC_ISCPPH_SETCODE39_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetCode39 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETCODE39_EXIT_I      0x41560024L

//
// MessageId: ITC_ISCPPH_GETCODE39_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetCode39 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODE39_ENTRY_I     0x41560025L

//
// MessageId: ITC_ISCPPH_GETCODE39_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetCode39 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODE39_EXIT_I      0x41560026L

//
// MessageId: ITC_ISCPPH_GETCODABAR_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetCodabar Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODABAR_ENTRY_I    0x41560027L

//
// MessageId: ITC_ISCPPH_GETCODABAR_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetCodabar Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODABAR_EXIT_I     0x41560028L

//
// MessageId: ITC_ISCPPH_GETCODE128_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetCode128 Entry
//
#define ITC_ISCPPH_GETCODE128_ENTRY_I    0x41560029L

//
// MessageId: ITC_ISCPPH_GETCODE128_EXIT1_I
//
// MessageText:
//
//  CISCPPH::GetCode128 Exit: hrStatus: 0x%1!08X!, *peDecode: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODE128_EXIT1_I    0x4156002AL

//
// MessageId: ITC_ISCPPH_GETCODE128_EXIT2_I
//
// MessageText:
//
//  CISCPPH::GetCode128 Exit: *peIdent: 0x%1!08X!, *peState: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODE128_EXIT2_I    0x4156002BL

//
// MessageId: ITC_ISCPPH_GETCODE128_EXIT3_I
//
// MessageText:
//
//  CISCPPH::GetCode128 Exit: *pbFNC1: 0x%1!08X!, *pdwLength: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODE128_EXIT3_I    0x4156002CL

//
// MessageId: ITC_ISCPPH_GETI2OF5_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetI2of5 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETI2OF5_ENTRY_I      0x4156002DL

//
// MessageId: ITC_ISCPPH_GETI2OF5_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetI2of5 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETI2OF5_EXIT_I       0x4156002EL

//
// MessageId: ITC_ISCPPH_SETCODABAR_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetCodabar Entry/Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETCODABAR_ENTRY_I    0x4156002FL

//
// MessageId: ITC_ISCPPH_SETCODABAR_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetCodabar Entry/Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETCODABAR_EXIT_I     0x41560030L

//
// MessageId: ITC_ISCPPH_SETCODE128_ENTRY1_I
//
// MessageText:
//
//  CISCPPH::SetCode128 Entry: eDecode: 0x%1!08X!, eIdent: 0x%2!08X!
//
#define ITC_ISCPPH_SETCODE128_ENTRY1_I   0x41560031L

//
// MessageId: ITC_ISCPPH_SETCODE128_ENTRY2_I
//
// MessageText:
//
//  CISCPPH::SetCode128 Entry: eState: 0x%1!08X!, byteFNC1: 0x%2!08X!
//
#define ITC_ISCPPH_SETCODE128_ENTRY2_I   0x41560032L

//
// MessageId: ITC_ISCPPH_SETCODE128_ENTRY3_I
//
// MessageText:
//
//  CISCPPH::SetCode128 Entry: dwLength: 0x%1!08X!
//
#define ITC_ISCPPH_SETCODE128_ENTRY3_I   0x41560033L

//
// MessageId: ITC_ISCPPH_SETCODE128_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetCode128 Exit: hrStatus: 0x%1!08X!
//
#define ITC_ISCPPH_SETCODE128_EXIT_I     0x41560034L

//
// MessageId: ITC_ISCPPH_SETMATRIX2OF5_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetMatrix2of5 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETMATRIX2OF5_ENTRY_I 0x41560035L

//
// MessageId: ITC_ISCPPH_SETMATRIX2OF5_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetMatrix2of5 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETMATRIX2OF5_EXIT_I  0x41560036L

//
// MessageId: ITC_ISCPPH_SETMSI_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetMSI Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETMSI_ENTRY_I        0x41560037L

//
// MessageId: ITC_ISCPPH_SETMSI_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetMSI Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETMSI_EXIT_I         0x41560038L

//
// MessageId: ITC_ISCPPH_SETPLESSEY_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetPlessey Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETPLESSEY_ENTRY_I    0x41560039L

//
// MessageId: ITC_ISCPPH_SETPLESSEY_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetPlessey Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETPLESSEY_EXIT_I     0x4156003AL

//
// MessageId: ITC_ISCPPH_GETTELEPEN_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetTelepen Entry: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETTELEPEN_ENTRY_I    0x4156003BL

//
// MessageId: ITC_ISCPPH_GETTELEPEN_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetTelepen Exit; ITC_TELEPEN_DECODING =  0x%1!08X!; ITC_TELEPEN_FORMAT = 0x%2!08X!
//
#define ITC_ISCPPH_GETTELEPEN_EXIT_I     0x4156003CL

//
// MessageId: ITC_ISCPPH_SETTELEPEN_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetTelepen Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETTELEPEN_ENTRY_I    0x4156003DL

//
// MessageId: ITC_ISCPPH_SETTELEPEN_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetTelepen Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETTELEPEN_EXIT_I     0x4156003EL

//
// MessageId: ITC_ISCPPH_TOSETCONFIGFMTFIXEDLEN_ENTRY_I
//
// MessageText:
//
//  CISCPPH::ToSetConfigFmtFixedLen Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_TOSETCONFIGFMTFIXEDLEN_ENTRY_I 0x4156003FL

//
// MessageId: ITC_ISCPPH_TOSETCONFIGFMTFIXEDLEN_EXIT_I
//
// MessageText:
//
//  CISCPPH::ToSetConfigFmtFixedLen Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_TOSETCONFIGFMTFIXEDLEN_EXIT_I 0x41560040L

//
// MessageId: ITC_ISCPPH_SETI2OF5_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetI2of5 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETI2OF5_ENTRY_I      0x41560041L

//
// MessageId: ITC_ISCPPH_SETI2OF5_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetI2of5 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETI2OF5_EXIT_I       0x41560042L

//
// MessageId: ITC_ISCPPH_GETMATRIX2OF5_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetMatrix2of5 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETMATRIX2OF5_ENTRY_I 0x41560043L

//
// MessageId: ITC_ISCPPH_GETMATRIX2OF5_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetMatrix2of5 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETMATRIX2OF5_EXIT_I  0x41560044L

//
// MessageId: ITC_ISCPPH_GETMSI_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetMSI Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETMSI_ENTRY_I        0x41560045L

//
// MessageId: ITC_ISCPPH_GETMSI_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetMSI Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETMSI_EXIT_I         0x41560046L

//
// MessageId: ITC_ISCPPH_GETPDF417_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetPDF417 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETPDF417_ENTRY_I     0x41560047L

//
// MessageId: ITC_ISCPPH_GETPDF417_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetPDF417 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETPDF417_EXIT_I      0x41560048L

//
// MessageId: ITC_ISCPPH_SETPDF417_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetPDF417 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETPDF417_ENTRY_I     0x41560049L

//
// MessageId: ITC_ISCPPH_SETPDF417_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetPDF417 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETPDF417_EXIT_I      0x4156004AL

//
// MessageId: ITC_ISCPPH_GETPLESSEY_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetPlessey Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETPLESSEY_ENTRY_I    0x4156004BL

//
// MessageId: ITC_ISCPPH_GETPLESSEY_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetPlessey Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETPLESSEY_EXIT_I     0x4156004CL

//
// MessageId: ITC_ISCPPH_SETSTANDARD2OF5_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetStandard2of5 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETSTANDARD2OF5_ENTRY_I 0x4156004DL

//
// MessageId: ITC_ISCPPH_SETSTANDARD2OF5_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetStandard2of5 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_SETSTANDARD2OF5_EXIT_I 0x4156004EL

//
// MessageId: ITC_ISCPPH_GETSTANDARD2OF5_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetStandard2of5 Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETSTANDARD2OF5_ENTRY_I 0x4156004FL

//
// MessageId: ITC_ISCPPH_GETSTANDARD2OF5_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetStandard2of5 Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETSTANDARD2OF5_EXIT_I 0x41560050L

//
// MessageId: ITC_ISCPPH_GETUPCEAN_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetUpcEan Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETUPCEAN_ENTRY_I     0x41560051L

//
// MessageId: ITC_ISCPPH_GETUPCEAN_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetUpcEan Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_GETUPCEAN_EXIT_I      0x41560052L

//
// MessageId: ITC_ISCPPH_SETUPCEAN_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetUpcEan Entry 
//
#define ITC_ISCPPH_SETUPCEAN_ENTRY_I     0x41560053L

//
// MessageId: ITC_ISCPPH_SETUPCEAN_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetUpcEan Exit
//
#define ITC_ISCPPH_SETUPCEAN_EXIT_I      0x41560054L

//
// MessageId: ITC_ISCPPH_TOFIXEDLENFMT_ENTRY_I
//
// MessageText:
//
//  CISCPPH::ToFixedLenFmt Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_TOFIXEDLENFMT_ENTRY_I 0x41560055L

//
// MessageId: ITC_ISCPPH_TOFIXEDLENFMT_EXIT_I
//
// MessageText:
//
//  CISCPPH::ToFixedLenFmt Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_TOFIXEDLENFMT_EXIT_I  0x41560056L

//
// MessageId: ITC_ISCPPH_DOWNLOADBARCODEREADER_EXIT_I
//
// MessageText:
//
//  CISCPPH::DownloadBarCodeReader Exit: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_DOWNLOADBARCODEREADER_EXIT_I 0x41560057L

//
// MessageId: ITC_ISCPPH_DOWNLOADBARCODEREADER_ENTRY_I
//
// MessageText:
//
//  CISCPPH::DownloadBarCodeReader Entry: Parm1: 0x%1!08X!, Parm2: 0x%2!08X!
//
#define ITC_ISCPPH_DOWNLOADBARCODEREADER_ENTRY_I 0x41560058L

//
// MessageId: ITC_ISCPPH_GETCODE11_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetCode11 Entry
//
#define ITC_ISCPPH_GETCODE11_ENTRY_I     0x41560059L

//
// MessageId: ITC_ISCPPH_GETCODE11_EXIT1_I
//
// MessageText:
//
//  CISCPPH::GetCode11 Exit: *peDecode: 0x%1!08X!, *peCheck: 0x%2!08X!
//
#define ITC_ISCPPH_GETCODE11_EXIT1_I     0x4156005AL

//
// MessageId: ITC_ISCPPH_GETCODE11_EXIT2_I
//
// MessageText:
//
//  CISCPPH::GetCode11 Exit: *peVer: 0x%1!08X!
//
#define ITC_ISCPPH_GETCODE11_EXIT2_I     0x4156005BL

//
// MessageId: ITC_ISCPPH_SETCODE11_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetCode11 Exit
//
#define ITC_ISCPPH_SETCODE11_EXIT_I      0x4156005CL

//
// MessageId: ITC_ISCPPH_SETCODE11_ENTRY1_I
//
// MessageText:
//
//  CISCPPH::SetCode11 Entry: *peDecode: 0x%1!08X!, *peCheck: 0x%2!08X!
//
#define ITC_ISCPPH_SETCODE11_ENTRY1_I    0x4156005DL

//
// MessageId: ITC_ISCPPH_SETCODE11_ENTRY2_I
//
// MessageText:
//
//  CISCPPH::SetCode11 Entry: *peVer: 0x%1!08X!
//
#define ITC_ISCPPH_SETCODE11_ENTRY2_I    0x4156005EL

//
// MessageId: ITC_ISCPPH_GETSYMIDXMIT_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetSymIdXmit option Entry.
//
#define ITC_ISCPPH_GETSYMIDXMIT_ENTRY_I  0x4156005FL

//
// MessageId: ITC_ISCPPH_GETSYMIDXMIT_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetSymIdXmit option Exit. *peSymIdXmit: 0x%1!08X!, hr: 0x%2!08X!
//
#define ITC_ISCPPH_GETSYMIDXMIT_EXIT_I   0x41560060L

//
// MessageId: ITC_ISCPPH_SETSYMIDXMIT_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetSymIdXmit option Entry. eSymIdXmit: 0x%1!08X!
//
#define ITC_ISCPPH_SETSYMIDXMIT_ENTRY_I  0x41560061L

//
// MessageId: ITC_ISCPPH_SETSYMIDXMIT_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetSymIdXmit option Exit. hr: 0x%1!08X!
//
#define ITC_ISCPPH_SETSYMIDXMIT_EXIT_I   0x41560062L

//
// MessageId: ITC_ISCPPH_GETCUSTOMSYMIDS_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetCustomSymIds Entry. 
//
#define ITC_ISCPPH_GETCUSTOMSYMIDS_ENTRY_I 0x41560063L

//
// MessageId: ITC_ISCPPH_GETCUSTOMSYMIDS_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetCustomSymIds Exit. hr: 0x%1!08X!
//
#define ITC_ISCPPH_GETCUSTOMSYMIDS_EXIT_I 0x41560064L

//
// MessageId: ITC_ISCPPH_SETCUSTOMSYMIDS_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetCustomSymIds Entry. dwNumElements: %1!d!
//
#define ITC_ISCPPH_SETCUSTOMSYMIDS_ENTRY_I 0x41560065L

//
// MessageId: ITC_ISCPPH_SETCUSTOMSYMIDS_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetCustomSymIds Exit. hr: 0x%1!08X!
//
#define ITC_ISCPPH_SETCUSTOMSYMIDS_EXIT_I 0x41560066L

//
// MessageId: ITC_ISCPPH_GETGLOBALAMBLE_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetGlobalAmble Exit. hr: 0x%1!08X!, *pdwBufferSize: %2!d!
//
#define ITC_ISCPPH_GETGLOBALAMBLE_EXIT_I 0x41560067L

//
// MessageId: ITC_ISCPPH_GETGLOBALAMBLE_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetGlobalAmble Entry. eAmbleId: %1!d!, dwBufferSize: %2!d!
//
#define ITC_ISCPPH_GETGLOBALAMBLE_ENTRY_I 0x41560068L

//
// MessageId: ITC_ISCPPH_SETGLOBALAMBLE_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetGlobalAmble Entry. eAmbleId: %1!d!, dwBufferSize: %2!d!
//
#define ITC_ISCPPH_SETGLOBALAMBLE_ENTRY_I 0x41560069L

//
// MessageId: ITC_ISCPPH_SETGLOBALAMBLE_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetGlobalAmble Exit. hr: 0x%1!08X!
//
#define ITC_ISCPPH_SETGLOBALAMBLE_EXIT_I 0x4156006AL

//
// MessageId: ITC_ISCPPH_SETMICROPDF417_ENTRY_I
//
// MessageText:
//
//  CISCPPH::SetMicroPdf417 Entry. eDecode: %1!d!
//
#define ITC_ISCPPH_SETMICROPDF417_ENTRY_I 0x4156006BL

//
// MessageId: ITC_ISCPPH_SETMICROPDF417_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetMicroPdf417 Exit. hr: 0x%1!08X!
//
#define ITC_ISCPPH_SETMICROPDF417_EXIT_I 0x4156006CL

//
// MessageId: ITC_ISCPPH_GETMICROPDF417_ENTRY_I
//
// MessageText:
//
//  CISCPPH::GetMicroPdf417 Entry. 
//
#define ITC_ISCPPH_GETMICROPDF417_ENTRY_I 0x4156006DL

//
// MessageId: ITC_ISCPPH_GETMICROPDF417_EXIT_I
//
// MessageText:
//
//  CISCPPH::GetMicroPdf417 Exit. *peDecode: %1!d!
//
#define ITC_ISCPPH_GETMICROPDF417_EXIT_I 0x4156006EL

//
// MessageId: ITC_ISCPPH_SETBEEPLEDWORDFMT_ENTRY_I
//
// MessageText:
//
//  CISCPPH::Read Entry. eAttrID: %1!d!, *pdwValue: %2!d!
//
#define ITC_ISCPPH_SETBEEPLEDWORDFMT_ENTRY_I 0x4156006FL

//
// MessageId: ITC_ISCPPH_SETBEEPLEDWORDFMT_EXIT_I
//
// MessageText:
//
//  CISCPPH::SetBeepLEDWordFmt Exit.  Status: 0x%1!08X!
//
#define ITC_ISCPPH_SETBEEPLEDWORDFMT_EXIT_I 0x41560070L

////////////////////////////////////////////////////////////////////
//
//  Success Messages
//
////////////////////////////////////////////////////////////////////
//MessageId=0
//Severity=Success
//Facility=<facility name>
//SymbolicName=ITC_<facility acronym>_<msg name>_I 
//Language=English
//<message string>
//.
////////////////////////////////////////////////////////////////////
//
//  Warning Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_ISCPPH_INVALID_DATADETAILS_W
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::Read. Invalid ITC_BARCODE_DATA_DETAILS size of: %1!d!. Valid size: %2!d!
//
#define ITC_ISCPPH_INVALID_DATADETAILS_W 0x81560000L

////////////////////////////////////////////////////////////////////
//
//  Error Messages
//
////////////////////////////////////////////////////////////////////
//
// MessageId: ITC_ISCPPH_CCI_DSAPI_E
//
// MessageText:
//
//  CISCPPH::Initialize CoCreateInstance failed. Status: 0x%1!08X!
//
#define ITC_ISCPPH_CCI_DSAPI_E           0xC1560000L

//
// MessageId: ITC_ISCPPH_DSAPI_NOTPRESENT_E
//
// MessageText:
//
//  CISCPPH::  DataServerAPI object not created
//
#define ITC_ISCPPH_DSAPI_NOTPRESENT_E    0xC1560001L

//
// MessageId: ITC_ISCPPH_DATAVALIDLED_NOTPRESENT_E
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::ControlLED Data Valid LED not present
//
#define ITC_ISCPPH_DATAVALIDLED_NOTPRESENT_E 0xC1560002L

//
// MessageId: ITC_ISCPPH_QUERYATTRIB_OUTBUFTOOSMALL_E
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::QueryAttribute Output buffer for attrib %1!d!;  Need minimum of %2!d! bytes.
//
#define ITC_ISCPPH_QUERYATTRIB_OUTBUFTOOSMALL_E 0xC1560003L

//
// MessageId: ITC_ISCPPH_GETCONFIG_BAD_WRITE_PTR_E
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::GetConfig Bad Write Pointer Error, nConfigBufferSize: %1!d!
//
#define ITC_ISCPPH_GETCONFIG_BAD_WRITE_PTR_E 0xC1560004L

//
// MessageId: ITC_ISCPPH_GETCONFIG_RESPONSE_E
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::GetConfig Response Error, hrStatus:0x%1!08X!
//
#define ITC_ISCPPH_GETCONFIG_RESPONSE_E  0xC1560005L

//
// MessageId: ITC_ISCPPH_GETCONFIG_REQUEST_E
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::GetConfig DataServer Write Failed, hrStatus:0x%1!08X!
//
#define ITC_ISCPPH_GETCONFIG_REQUEST_E   0xC1560006L

//
// MessageId: ITC_ISCPPH_SETCONFIG_RESPONSE_E
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::SetConfig Response Error, hrStatus:0x%1!08X!
//
#define ITC_ISCPPH_SETCONFIG_RESPONSE_E  0xC1560007L

//
// MessageId: ITC_ISCPPH_QRYATTR_GRID_E
//
// MessageText:
//
//  CISCPPH::CISCPPHConfigControl::QueryAttribute Buffer size %1!d! too small; Must be %2!d! or larger.
//
#define ITC_ISCPPH_QRYATTR_GRID_E        0xC1560008L

//
// MessageId: ITC_ISCPPH_SET_INVALIDARG_E
//
// MessageText:
//
//  CISCPPH::Setxx error, FunctionID: 0x%1!08X!, Invalid Arg: 0x%2!08X!
//
#define ITC_ISCPPH_SET_INVALIDARG_E      0xC1560009L

//
// MessageId: ITC_ISCPPH_GETCONFIG_ERROR_E
//
// MessageText:
//
//  CISCPPH::Getxx, Error: hr returned from GetConfig: 0x%1!08X!, 0x%2!08X!
//
#define ITC_ISCPPH_GETCONFIG_ERROR_E     0xC156000AL

//
// MessageId: ITC_ISCPPH_INCORRECT_NUM_COMMANDS_E
//
// MessageText:
//
//  CISCPPH::Getxx, Error: Incorrect dwCommands from GetConfig:  %1!d!, 0x%2!08X!
//
#define ITC_ISCPPH_INCORRECT_NUM_COMMANDS_E 0xC156000BL

//
// MessageId: ITC_ISCPPH_SET_INVALID_LEN_E
//
// MessageText:
//
//  CISCPPH::Setxx, FunctionID: 0x%1!08X!, Invalid dwLength:  %2!d!
//
#define ITC_ISCPPH_SET_INVALID_LEN_E     0xC156000CL

//
// MessageId: ITC_ISCPPH_INVALID_BARCODE_LEN_E
//
// MessageText:
//
//  CISCPPH::ToSetConfigFmtLen, Invalid dwLength: %1!d!
//
#define ITC_ISCPPH_INVALID_BARCODE_LEN_E 0xC156000DL

//
// MessageId: ITC_ISCPPH_VALID_BARCODE_LEN_E
//
// MessageText:
//
//  CISCPPH::ToSetConfigFmtLen, valid BC Length: Any Length and range: %1!d! - %2!d!
//
#define ITC_ISCPPH_VALID_BARCODE_LEN_E   0xC156000EL

//
// MessageId: ITC_ISCPPH_GETCODE39_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetCode39 Invalid S9C Response: SID: 0x%1!08X!, SID Param: 0x%2!08X!
//  
//
#define ITC_ISCPPH_GETCODE39_MISMATCH_COMMAND_E 0xC156000FL

//
// MessageId: ITC_ISCPPH_GETCODABAR_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetCodabar buffer mismated error: Loop: %1!d!, nCmdBytes: %2!d!
//
#define ITC_ISCPPH_GETCODABAR_MISMATCH_COMMAND_E 0xC1560010L

//
// MessageId: ITC_ISCPPH_GETCODE128_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetCode128 buffer mismated error: Loop: %1!d!, nCmdBytes: %2!d!
//
#define ITC_ISCPPH_GETCODE128_MISMATCH_COMMAND_E 0xC1560011L

//
// MessageId: ITC_ISCPPH_GETI2OF5_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetI2of5 buffer mismated error: Loop: %1!d!, nCmdBytes: %2!d!
//
#define ITC_ISCPPH_GETI2OF5_MISMATCH_COMMAND_E 0xC1560012L

//
// MessageId: ITC_ISCPPH_GETSTD2OF5_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetStd2of5 buffer mismated error: Loop: %1!d!, nCmdBytes: %2!d!
//
#define ITC_ISCPPH_GETSTD2OF5_MISMATCH_COMMAND_E 0xC1560013L

//
// MessageId: ITC_ISCPPH_INVALID_ARG_E
//
// MessageText:
//
//  CISCPPH::Setxxx - Invalid Option: 0x%1!08X!, 0x%2!08X!
//
#define ITC_ISCPPH_INVALID_ARG_E         0xC1560014L

//
// MessageId: ITC_ISCPPH_GETCODE39_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetCode39 Error: Not all requested Parameters have valid values: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETCODE39_NOT_ALL_COMMANDS_PROCESSED_E 0xC1560015L

//
// MessageId: ITC_ISCPPH_GETCODE93_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetCode93 Error: Not all requested Parameters have valid values: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETCODE93_NOT_ALL_COMMANDS_PROCESSED_E 0xC1560016L

//
// MessageId: ITC_ISCPPH_GETCODABAR_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetCodabar Error: Not all requested Parameters have valid values: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETCODABAR_NOT_ALL_COMMANDS_PROCESSED_E 0xC1560017L

//
// MessageId: ITC_ISCPPH_GETCODE128_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetCode128 Error: Not all requested Parameters have valid values
//
#define ITC_ISCPPH_GETCODE128_NOT_ALL_COMMANDS_PROCESSED_E 0xC1560018L

//
// MessageId: ITC_ISCPPH_GETI2OF5_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetI2of5 Error: Not all requested Parameters have valid values: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETI2OF5_NOT_ALL_COMMANDS_PROCESSED_E 0xC1560019L

//
// MessageId: ITC_ISCPPH_GETMATRIX2OF5_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetMatrix2of5 Error: Not all requested Parameters have valid values: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETMATRIX2OF5_NOT_ALL_COMMANDS_PROCESSED_E 0xC156001AL

//
// MessageId: ITC_ISCPPH_GETMSI_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetMSI Error: Not all requested Parameters have valid values: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETMSI_NOT_ALL_COMMANDS_PROCESSED_E 0xC156001BL

//
// MessageId: ITC_ISCPPH_GETPDF417_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetPDF417 Error: Not all requested Parameters have valid values.
//
#define ITC_ISCPPH_GETPDF417_NOT_ALL_COMMANDS_PROCESSED_E 0xC156001CL

//
// MessageId: ITC_ISCPPH_GETPLESSEY_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetPlessey Error: Not all requested Parameters have valid values: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETPLESSEY_NOT_ALL_COMMANDS_PROCESSED_E 0xC156001DL

//
// MessageId: ITC_ISCPPH_GETSTD2OF5_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetStd2of5 Error: Not all requested Parameters have valid values: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETSTD2OF5_NOT_ALL_COMMANDS_PROCESSED_E 0xC156001EL

//
// MessageId: ITC_ISCPPH_GETTELEPEN_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetTelepen Error: Not all requested Parameters have valid values: ITC_TELEPEN_DECODING= %1!d!; ITC_TELEPEN_FORMAT= %2!d!
//
#define ITC_ISCPPH_GETTELEPEN_NOT_ALL_COMMANDS_PROCESSED_E 0xC156001FL

//
// MessageId: ITC_ISCPPH_GETUPCEAN_NOT_ALL_COMMANDS_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetUpcEan Error: Not all requested Parameters have valid values: Parm1: %1!d!, Parm2: %2!d!
//
#define ITC_ISCPPH_GETUPCEAN_NOT_ALL_COMMANDS_PROCESSED_E 0xC1560020L

//
// MessageId: ITC_ISCPPH_PARAMTOASCII_E
//
// MessageText:
//
//  CISCPPH::ParamToAscii: Invalid value: Byte0: 0x%1!08X!, Byte1: 0x%2!08X!
//
#define ITC_ISCPPH_PARAMTOASCII_E        0xC1560021L

//
// MessageId: ITC_ISCPPH_ASCIITOPARAM_E
//
// MessageText:
//
//  CISCPPH::AsciiToParam: Invalid input Ascii value: byChar: 0x%1!08X!, Parm2 0x%2!08X!
//
#define ITC_ISCPPH_ASCIITOPARAM_E        0xC1560022L

//
// MessageId: ITC_ISCPPH_GETPDF417_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetPdf417 buffer mismated error: Loop: %1!d!, nCmdBytes: %2!d!
//
#define ITC_ISCPPH_GETPDF417_MISMATCH_COMMAND_E 0xC1560023L

//
// MessageId: ITC_ISCPPH_GETMSI_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetMsi buffer mismated error: Loop: %1!d!, nCmdBytes: %2!d!
//
#define ITC_ISCPPH_GETMSI_MISMATCH_COMMAND_E 0xC1560024L

//
// MessageId: ITC_ISCPPH_GETPLESSEY_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetPlessey buffer mismated error: Loop: %1!d!, nCmdBytes: %2!d!
//
#define ITC_ISCPPH_GETPLESSEY_MISMATCH_COMMAND_E 0xC1560025L

//
// MessageId: ITC_ISCPPH_GETTELEPEN_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetTelepen buffer mismated error: Loop: %1!d!, nCmdBytes: %2!d!
//
#define ITC_ISCPPH_GETTELEPEN_MISMATCH_COMMAND_E 0xC1560026L

//
// MessageId: ITC_ISCPPH_GETUPCEAN_MISMATCH_COMMAND_E
//
// MessageText:
//
//  CISCPPH::GetUpcEan buffer mismated error: Loop: %1!d!, nCmdBytes: %2!d!
//
#define ITC_ISCPPH_GETUPCEAN_MISMATCH_COMMAND_E 0xC1560027L

//
// MessageId: ITC_ISCPPH_DOWNLOADBARCODEREADER_RESPONSE_E
//
// MessageText:
//
//  CISCPPH::DownLoadBarcodeReader response error: hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_ISCPPH_DOWNLOADBARCODEREADER_RESPONSE_E 0xC1560028L

//
// MessageId: ITC_ISCPPH_DOWNLOADBARCODEREADER_E
//
// MessageText:
//
//  CISCPPH::DownLoadBarcodeReader received this error: hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_ISCPPH_DOWNLOADBARCODEREADER_E 0xC1560029L

//
// MessageId: ITC_ISCPPH_SETCONFIG_E
//
// MessageText:
//
//  CISCPPH::SetConfig received this error: hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_ISCPPH_SETCONFIG_E           0xC156002AL

//
// MessageId: ITC_ISCPPH_GETCONFIG_E
//
// MessageText:
//
//  CISCPPH::GetConfig received this error: hr: 0x%1!08X!, 0x%2!08X!
//
#define ITC_ISCPPH_GETCONFIG_E           0xC156002BL

//
// MessageId: ITC_ISCPPH_INVALID_BARCODE_FIXEDLEN_E
//
// MessageText:
//
//  CISCPPH::ToSetConfigFmtFixedLen, Invalid byLength: %1!d!
//
#define ITC_ISCPPH_INVALID_BARCODE_FIXEDLEN_E 0xC156002CL

//
// MessageId: ITC_ISCPPH_VALID_BARCODE_FIXEDLEN_E
//
// MessageText:
//
//  CISCPPH::ToSetConfigFmtFixedLen, valid fixed length range: %1!d! - %2!d!
//
#define ITC_ISCPPH_VALID_BARCODE_FIXEDLEN_E 0xC156002DL

//
// MessageId: ITC_ISCPPH_ISCPWRITE_RSPDATA_E
//
// MessageText:
//
//  CISCPPH::ISCPWrite received too few bytes from DS. Bytes received: %1!d!; ObjectSize: %2!d!
//
#define ITC_ISCPPH_ISCPWRITE_RSPDATA_E   0xC156002EL

//
// MessageId: ITC_ISCPPH_ISCPWRITE_HRESULT_E
//
// MessageText:
//
//  CISCPPH::ISCPWrite response data returned error status: 0x%1!08X! 
//
#define ITC_ISCPPH_ISCPWRITE_HRESULT_E   0xC156002FL

//
// MessageId: ITC_ISCPPH_SETCONFIG_INVBC_LENGTH_E
//
// MessageText:
//
//  CISCPPH::SetCodeXX Invalid Bar Code length of %1!d! characters specified.
//
#define ITC_ISCPPH_SETCONFIG_INVBC_LENGTH_E 0xC1560030L

//
// MessageId: ITC_ISCPPH_SET_UPCEAN_DECODING_E
//
// MessageText:
//
//  CISCPPH::SetUpcEan eDecode value of %1!d! not supported.  Parameter must be set to ITC_UPCEAN_NO_CHANGE.
//
#define ITC_ISCPPH_SET_UPCEAN_DECODING_E 0xC1560031L

//
// MessageId: ITC_ISCPPH_GETSYMIDXMIT_COMMAND_PROCESSED_E
//
// MessageText:
//
//  CISCPPH::GetSymIdXmit. Cannot find the expected parameter: *peSymIdXmit: 0x%1!08X!, hr: 0x%2!08X!  
//
#define ITC_ISCPPH_GETSYMIDXMIT_COMMAND_PROCESSED_E 0xC1560032L

//
// MessageId: ITC_ISCPPH_CUSTOMSYMIDS_BUEER_E
//
// MessageText:
//
//  CISCPPH::GetCustomSymIds. Allocated buffer too small. dwMaxNumElement: %1!d!, expected: %2!d!
//
#define ITC_ISCPPH_CUSTOMSYMIDS_BUEER_E  0xC1560033L

//
// MessageId: ITC_ISCPPH_GETXXX_INVALID_OPTION_E
//
// MessageText:
//
//  CISCPPH::GetXXX. Invalid option.
//
#define ITC_ISCPPH_GETXXX_INVALID_OPTION_E 0xC1560034L

//
// MessageId: ITC_ISCPPH_SETGLOBALAMBLE_INVALID_SIZE_E
//
// MessageText:
//
//  CISCPPH::SetGlobalAmble. Invalid buffer size. dwBufferSize: %1!d!, expected: %2!d!
//
#define ITC_ISCPPH_SETGLOBALAMBLE_INVALID_SIZE_E 0xC1560035L

//
// MessageId: ITC_ISCPPH_SETXXX_INVALID_OPTION_E
//
// MessageText:
//
//  CISCPPH::SetXXX. Invalid option.
//
#define ITC_ISCPPH_SETXXX_INVALID_OPTION_E 0xC1560036L

//
// MessageId: ITC_ISCPPH_GETBEEPLED_INVALID_OPTION_E
//
// MessageText:
//
//  CISCPPH::GetBeepLED. Invalid eAttrID: 0x%1!08X!
//
#define ITC_ISCPPH_GETBEEPLED_INVALID_OPTION_E 0xC1560037L

//
// MessageId: ITC_ISCPPH_SETBEEPLED_INVALID_OPTION_E
//
// MessageText:
//
//  CISCPPH::SetBeepLED. Invalid eAttrID: 0x%1!08X!, value: %2!d!
//
#define ITC_ISCPPH_SETBEEPLED_INVALID_OPTION_E 0xC1560038L

//
// MessageId: ITC_ISCPPH_SETBEEPLED_INVALID_VALUE_E
//
// MessageText:
//
//  CISCPPH::SetBeepLED. eAttrID: 0x%1!08X!, Invalid Value: %2!d!
//
#define ITC_ISCPPH_SETBEEPLED_INVALID_VALUE_E 0xC1560039L

//
// MessageId: ITC_ISCPPH_SETBEEPLEDWORDFMT_INVALID_VALUE_E
//
// MessageText:
//
//  CISCPPH::SetBeepLED. eAttrID: 0x%1!08X!, Invalid Value: %2!d!
//
#define ITC_ISCPPH_SETBEEPLEDWORDFMT_INVALID_VALUE_E 0xC156003AL

//
// MessageId: ITC_ISCPPH_GETCONFIG_CALLERSBUFF_TOO_SMALL_E
//
// MessageText:
//
//  CISCPPH::GetConfig().  Caller's buffer of %1!d! bytes is too small. Must >= %2!d!
//
#define ITC_ISCPPH_GETCONFIG_CALLERSBUFF_TOO_SMALL_E 0xC156003BL

//
// MessageId: ITC_ISCPPH_SETCONFIG_CALLERSBUFF_TOO_SMALL_E
//
// MessageText:
//
//  CISCPPH::SetConfig().  Caller's buffer of %1!d! bytes is too small. Must >= %2!d!
//
#define ITC_ISCPPH_SETCONFIG_CALLERSBUFF_TOO_SMALL_E 0xC156003CL

//
// MessageId: ITC_ISCPPH_OPEN_CREATEMUX_E
//
// MessageText:
//
//  CISCPPH::Open(). CreateMutex error: 0x%1!08X!
//
#define ITC_ISCPPH_OPEN_CREATEMUX_E      0xC156003DL

//
// MessageId: ITC_ISCPPH_OPEN_IMAGEALEADYOWNED_E
//
// MessageText:
//
//  CISCPPH::Open(). The imager device drive is already owned.
//
#define ITC_ISCPPH_OPEN_IMAGEALEADYOWNED_E 0xC156003EL

//
// MessageId: ITC_ISCPPH_OPEN_CREATEFILE_E
//
// MessageText:
//
//  CISCPPH::Open(). CreateFile() on the imager device driver error: 0x%1!08X!
//
#define ITC_ISCPPH_OPEN_CREATEFILE_E     0xC156003FL

//
// MessageId: ITC_ISCPPH_GETSIGCAP_IOCTL_E
//
// MessageText:
//
//  CISCPPH::ReadSigCapBuffer() error from Device Driver: 0x%1!08X!
//
#define ITC_ISCPPH_GETSIGCAP_IOCTL_E     0xC1560040L

//
// MessageId: ITC_ISCPPH_GETSIGCAP_OPEN_E
//
// MessageText:
//
//  CISCPPH::ReadSigCapBuffer().  Imager device not opened.
//
#define ITC_ISCPPH_GETSIGCAP_OPEN_E      0xC1560041L

//
// MessageId: ITC_ISCPPH_GETSIGCAP_INVPARM_E
//
// MessageText:
//
//  CISCPPH::ReadSigCapBuffer(). Function called with an invalid parameter.
//
#define ITC_ISCPPH_GETSIGCAP_INVPARM_E   0xC1560042L

//
// MessageId: ITC_ISCPPH_GETIMAGE_OPEN_E
//
// MessageText:
//
//  CISCPPH::ReadImager().  Imager device not opened.
//
#define ITC_ISCPPH_GETIMAGE_OPEN_E       0xC1560043L

//
// MessageId: ITC_ISCPPH_GETIMAGE_INVPARM_E
//
// MessageText:
//
//  CISCPPH::ReadImage(). Function called with an invalid parameter.
//
#define ITC_ISCPPH_GETIMAGE_INVPARM_E    0xC1560044L

//
// MessageId: ITC_ISCPPH_GETIMAGE_IOCTL_E
//
// MessageText:
//
//  CISCPPH::ReadImage(). DeviceIoControl returned false.  GetLastError = 0x%1!08X! 
//
#define ITC_ISCPPH_GETIMAGE_IOCTL_E      0xC1560045L

//
// MessageId: ITC_ISCPPH_GETIMAGE_TIMEOUT_E
//
// MessageText:
//
//  CISCPPH::ReadImage(). Timeout waiting for image. Time waiting: %1!d! msecs  
//
#define ITC_ISCPPH_GETIMAGE_TIMEOUT_E    0xC1560046L

//
// MessageId: ITC_ISCPPH_STARTIMGCAP_OPEN_E
//
// MessageText:
//
//  CISCPPH::Start().  Imager device not opened.
//
#define ITC_ISCPPH_STARTIMGCAP_OPEN_E    0xC1560047L

//
// MessageId: ITC_ISCPPH_STOPIMGCAP_OPEN_E
//
// MessageText:
//
//  CISCPPH::Stop().  Imager device not opened.
//
#define ITC_ISCPPH_STOPIMGCAP_OPEN_E     0xC1560048L

//
// MessageId: ITC_ISCPPH_STARTIMGCAP_IOCTL_E
//
// MessageText:
//
//  CISCPPH::Start(). DeviceIoControl returned false.  GetLastError = 0x%1!08X! 
//
#define ITC_ISCPPH_STARTIMGCAP_IOCTL_E   0xC1560049L

//
// MessageId: ITC_ISCPPH_STOPIMGCAP_IOCTL_E
//
// MessageText:
//
//  CISCPPH::Stop(). DeviceIoControl returned false.  GetLastError = 0x%1!08X! 
//
#define ITC_ISCPPH_STOPIMGCAP_IOCTL_E    0xC156004AL

//
// MessageId: ITC_ISCPPH_SETIMAGINGMODE_IOCTL_E
//
// MessageText:
//
//  CISCPPH::Stop(). DeviceIoControl returned false.  GetLastError = 0x%1!08X! 
//
#define ITC_ISCPPH_SETIMAGINGMODE_IOCTL_E 0xC156004BL

//
// MessageId: ITC_ISCPPH_GETIMAGINGMODE_IOCTL_E
//
// MessageText:
//
//  CISCPPH::Stop(). DeviceIoControl returned false.  GetLastError = 0x%1!08X! 
//
#define ITC_ISCPPH_GETIMAGINGMODE_IOCTL_E 0xC156004CL

//
// MessageId: ITC_ISCPPH_SETCAMERAAPI_IOCTL_E
//
// MessageText:
//
//  CISCPPH::Stop(). DeviceIoControl returned false.  GetLastError = 0x%1!08X! 
//
#define ITC_ISCPPH_SETCAMERAAPI_IOCTL_E  0xC156004DL

//
// MessageId: ITC_ISCPPH_GETCAMERAAPI_IOCTL_E
//
// MessageText:
//
//  CISCPPH::Stop(). DeviceIoControl returned false.  GetLastError = 0x%1!08X! 
//
#define ITC_ISCPPH_GETCAMERAAPI_IOCTL_E  0xC156004EL

#endif
////////////////////////////////////////////////////////////////////
// END OF FILE:  S9CISCPPH.mcs
//  COPYRIGHT (c) 2000 INTERMEC TECHNOLOGIES CORPORATION, ALL RIGHTS RESERVED
////////////////////////////////////////////////////////////////////
